@@ -403,11 +403,12 @@ jmake () {
       ;;
   esac;
 
-  if [ -n "${ncpu:-}" ] && [[ "${ncpu}" =~ ^[0-9]+$ ]]; then
-    make -j "${ncpu}" "$@";
-  else
-    make "$@";
-  fi;
+  case "${ncpu}" in
+    ''|*[!0-9]*)
+      make "$@" ;;
+    *)
+      make -j "${ncpu}" "$@" ;;
+  esac;
 }
 
 # Declare a dependency on a C project built with autotools.
@@ -777,7 +778,9 @@ macos_oracle () {
 
 bootstrap_virtualenv () {
   mkdir -p "${py_ve_tools}";
-  export PYTHONUSERBASE="${py_ve_tools}"
+  export PYTHONUSERBASE="${py_ve_tools}";
+  # If we're already in a venv, don't use --user flag for pip install
+  if [ -z ${VIRTUAL_ENV:-} ]; then NESTED="--user" ; else NESTED=""; fi
 
   for pkg in             \
       setuptools==18.5    \
@@ -785,7 +788,7 @@ bootstrap_virtualenv () {
       virtualenv==15.0.2  \
   ; do
       ruler "Installing ${pkg}";
-      "${bootstrap_python}" -m pip install -I --user "${pkg}";
+      "${bootstrap_python}" -m pip install -I ${NESTED} "${pkg}";
   done;
 }
 
