@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 
 ##
-# Copyright (c) 2006-2015 Apple Inc. All rights reserved.
+# Copyright (c) 2006-2017 Apple Inc. All rights reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -35,16 +35,14 @@ from calendarserver.tools.config import (
     WRITABLE_CONFIG_KEYS, setKeyPath, getKeyPath, flattenDictionary,
     WritableConfig
 )
-from calendarserver.tools.principals import (
-    getProxies, setProxies
-)
 from calendarserver.tools.purge import (
     WorkerService, PurgeOldEventsService,
     DEFAULT_BATCH_SIZE, DEFAULT_RETAIN_DAYS,
     PrincipalPurgeWork
 )
 from calendarserver.tools.util import (
-    recordForPrincipalID, autoDisableMemcached
+    recordForPrincipalID, autoDisableMemcached,
+    getProxies, setProxies
 )
 from pycalendar.datetime import DateTime
 from twext.who.directory import DirectoryRecord
@@ -99,7 +97,6 @@ def usage(e=None):
         sys.exit(0)
 
 
-
 class RunnerService(WorkerService):
     """
     A wrapper around Runner which uses utilityMain to get the store
@@ -116,13 +113,11 @@ class RunnerService(WorkerService):
         if runner.validate():
             yield runner.run()
 
-
     def doWorkWithoutStore(self):
         respondWithError("Database is not available")
         return succeed(None)
 
 
-
 def main():
 
     try:
@@ -161,7 +156,7 @@ def main():
     rawInput = sys.stdin.read()
     try:
         plist = readPlistFromString(rawInput)
-    except xml.parsers.expat.ExpatError, e:
+    except xml.parsers.expat.ExpatError, e:  # @UndefinedVariable
         respondWithError(str(e))
         return
 
@@ -176,7 +171,6 @@ def main():
     utilityMain(configFileName, RunnerService, verbose=debug)
 
 
-
 class Runner(object):
 
     def __init__(self, store, commands, output=None):
@@ -187,7 +181,6 @@ class Runner(object):
             output = sys.stdout
         self.output = output
 
-
     def validate(self):
         # Make sure commands are valid
         for command in self.commands:
@@ -201,7 +194,6 @@ class Runner(object):
                 return False
         return True
 
-
     @inlineCallbacks
     def run(self):
 
@@ -226,14 +218,12 @@ class Runner(object):
             self.respondWithError("Command failed: '%s'" % (str(e),))
             raise
 
-
     # Locations
 
     # deferred
     def command_getLocationList(self, command):
         return self.respondWithRecordsOfTypes(self.dir, command, ["locations"])
 
-
     @inlineCallbacks
     def _saveRecord(self, typeName, recordType, command, oldFields=None):
         """
@@ -327,19 +317,15 @@ class Runner(object):
 
         yield self.respondWithRecordsOfTypes(self.dir, command, [typeName])
 
-
     def command_createLocation(self, command):
         return self._saveRecord("locations", CalRecordType.location, command)
 
-
     def command_createResource(self, command):
         return self._saveRecord("resources", CalRecordType.resource, command)
 
-
     def command_createAddress(self, command):
         return self._saveRecord("addresses", CalRecordType.address, command)
 
-
     @inlineCallbacks
     def command_setLocationAttributes(self, command):
         uid = command['GeneratedUID']
@@ -351,7 +337,6 @@ class Runner(object):
             oldFields=record.fields
         )
 
-
     @inlineCallbacks
     def command_setResourceAttributes(self, command):
         uid = command['GeneratedUID']
@@ -363,7 +348,6 @@ class Runner(object):
             oldFields=record.fields
         )
 
-
     @inlineCallbacks
     def command_setAddressAttributes(self, command):
         uid = command['GeneratedUID']
@@ -375,7 +359,6 @@ class Runner(object):
             oldFields=record.fields
         )
 
-
     @inlineCallbacks
     def command_getLocationAttributes(self, command):
         uid = command['GeneratedUID']
@@ -398,31 +381,26 @@ class Runner(object):
     command_getResourceAttributes = command_getLocationAttributes
     command_getAddressAttributes = command_getLocationAttributes
 
-
     # Resources
 
     def command_getResourceList(self, command):
         return self.respondWithRecordsOfTypes(self.dir, command, ["resources"])
 
-
     # deferred
     def command_getLocationAndResourceList(self, command):
         return self.respondWithRecordsOfTypes(self.dir, command, ["locations", "resources"])
 
-
     # Addresses
 
     def command_getAddressList(self, command):
         return self.respondWithRecordsOfTypes(self.dir, command, ["addresses"])
 
-
     @inlineCallbacks
     def _delete(self, typeName, command):
         uid = command['GeneratedUID']
         yield self.dir.removeRecords([uid])
         yield self.respondWithRecordsOfTypes(self.dir, command, [typeName])
 
-
     @inlineCallbacks
     def command_deleteLocation(self, command):
         txn = self.store.newTransaction()
@@ -432,7 +410,6 @@ class Runner(object):
 
         yield self._delete("locations", command)
 
-
     @inlineCallbacks
     def command_deleteResource(self, command):
         txn = self.store.newTransaction()
@@ -442,11 +419,9 @@ class Runner(object):
 
         yield self._delete("resources", command)
 
-
     def command_deleteAddress(self, command):
         return self._delete("addresses", command)
 
-
     # Config
 
     def command_readConfig(self, command):
@@ -470,7 +445,6 @@ class Runner(object):
                 setKeyPath(result, keyPath, value)
         self.respond(command, result)
 
-
     def command_writeConfig(self, command):
         """
         Write config to secondary, writable plist
@@ -492,17 +466,14 @@ class Runner(object):
         else:
             self.command_readConfig(command)
 
-
     # Proxies
 
     def command_listWriteProxies(self, command):
         return self._listProxies(command, "write")
 
-
     def command_listReadProxies(self, command):
         return self._listProxies(command, "read")
 
-
     @inlineCallbacks
     def _listProxies(self, command, proxyType):
         record = yield recordForPrincipalID(self.dir, command['Principal'])
@@ -511,15 +482,12 @@ class Runner(object):
             returnValue(None)
         yield self.respondWithProxies(command, record, proxyType)
 
-
     def command_addReadProxy(self, command):
         return self._addProxy(command, "read")
 
-
     def command_addWriteProxy(self, command):
         return self._addProxy(command, "write")
 
-
     @inlineCallbacks
     def _addProxy(self, command, proxyType):
         record = yield recordForPrincipalID(self.dir, command['Principal'])
@@ -537,15 +505,12 @@ class Runner(object):
         yield txn.commit()
         yield self.respondWithProxies(command, record, proxyType)
 
-
     def command_removeReadProxy(self, command):
         return self._removeProxy(command, "read")
 
-
     def command_removeWriteProxy(self, command):
         return self._removeProxy(command, "write")
 
-
     @inlineCallbacks
     def _removeProxy(self, command, proxyType):
         record = yield recordForPrincipalID(self.dir, command['Principal'])
@@ -563,7 +528,6 @@ class Runner(object):
         yield txn.commit()
         yield self.respondWithProxies(command, record, proxyType)
 
-
     @inlineCallbacks
     def command_purgeOldEvents(self, command):
         """
@@ -580,7 +544,6 @@ class Runner(object):
         eventCount = (yield PurgeOldEventsService.purgeOldEvents(self.store, None, cutoff, DEFAULT_BATCH_SIZE))
         self.respond(command, {'EventsRemoved': eventCount, "RetainDays": retainDays})
 
-
     @inlineCallbacks
     def respondWithProxies(self, command, record, proxyType):
         proxies = []
@@ -596,7 +559,6 @@ class Runner(object):
             'Principal': record.uid, 'Proxies': proxies
         })
 
-
     @inlineCallbacks
     def respondWithRecordsOfTypes(self, directory, command, recordTypes):
         result = []
@@ -607,16 +569,13 @@ class Runner(object):
                 result.append(recordDict)
         self.respond(command, result)
 
-
     def respond(self, command, result):
         self.output.write(writePlistToString({'command': command['command'], 'result': result}))
 
-
     def respondWithError(self, msg, status=1):
         self.output.write(writePlistToString({'error': msg, }))
 
 
-
 def recordToDict(record):
     recordDict = {}
     for key, info in attrMap.iteritems():
@@ -638,11 +597,9 @@ def recordToDict(record):
     return recordDict
 
 
-
 def respondWithError(msg, status=1):
     sys.stdout.write(writePlistToString({'error': msg, }))
 
 
-
 if __name__ == "__main__":
     main()
