@@ -1,5 +1,5 @@
 ##
-# Copyright (c) 2005-2015 Apple Inc. All rights reserved.
+# Copyright (c) 2005-2017 Apple Inc. All rights reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -35,7 +35,6 @@ from txdav.who.idirectory import AutoScheduleMode
 from txdav.who.util import directoryFromConfig
 
 
-
 class RunCommandTestCase(TestCase):
 
     @inlineCallbacks
@@ -69,9 +68,8 @@ class RunCommandTestCase(TestCase):
 
         testRoot = os.path.join(os.path.dirname(__file__), "gateway")
         templateName = os.path.join(testRoot, "caldavd.plist")
-        templateFile = open(templateName)
-        template = templateFile.read()
-        templateFile.close()
+        with open(templateName) as templateFile:
+            template = templateFile.read()
 
         databaseRoot = os.path.abspath("_spawned_scripts_db" + str(os.getpid()))
         newConfig = template % {
@@ -141,7 +139,6 @@ class RunCommandTestCase(TestCase):
         self.store = yield theStoreBuilder.buildStore(self, self.notifierFactory)
         self.directory = directoryFromConfig(config, self.store)
 
-
     @inlineCallbacks
     def runCommand(
         self, command, error=False, script="calendarserver_command_gateway",
@@ -176,15 +173,13 @@ class RunCommandTestCase(TestCase):
             try:
                 plist = readPlistFromString(output)
                 returnValue(plist)
-            except xml.parsers.expat.ExpatError, e:
+            except xml.parsers.expat.ExpatError, e:  # @UndefinedVariable
                 print("Error (%s) parsing (%s)" % (e, output))
                 raise
         else:
             returnValue(output)
 
 
-
-
 class GatewayTestCase(RunCommandTestCase):
 
     def _flush(self):
@@ -192,19 +187,16 @@ class GatewayTestCase(RunCommandTestCase):
         self.directory._directory.services[1].flush()
         self.directory._directory.services[2].flush()
 
-
     @inlineCallbacks
     def test_getLocationAndResourceList(self):
         results = yield self.runCommand(command_getLocationAndResourceList)
         self.assertEquals(len(results["result"]), 20)
 
-
     @inlineCallbacks
     def test_getLocationList(self):
         results = yield self.runCommand(command_getLocationList)
         self.assertEquals(len(results["result"]), 10)
 
-
     @inlineCallbacks
     def test_getLocationAttributes(self):
         yield self.runCommand(command_createLocation)
@@ -225,13 +217,11 @@ class GatewayTestCase(RunCommandTestCase):
         self.assertEquals(set(results["result"]["ReadProxies"]), set(['user03', 'user04']))
         self.assertEquals(set(results["result"]["WriteProxies"]), set(['user05', 'user06']))
 
-
     @inlineCallbacks
     def test_getResourceList(self):
         results = yield self.runCommand(command_getResourceList)
         self.assertEquals(len(results["result"]), 10)
 
-
     @inlineCallbacks
     def test_getResourceAttributes(self):
         yield self.runCommand(command_createResource)
@@ -245,7 +235,6 @@ class GatewayTestCase(RunCommandTestCase):
         self.assertEquals(set(results["result"]["ReadProxies"]), set(['user03', 'user04']))
         self.assertEquals(set(results["result"]["WriteProxies"]), set(['user05', 'user06']))
 
-
     @inlineCallbacks
     def test_createAddress(self):
 
@@ -284,7 +273,6 @@ class GatewayTestCase(RunCommandTestCase):
         results = yield self.runCommand(command_getAddressList)
         self.assertEquals(len(results["result"]), 0)
 
-
     @inlineCallbacks
     def test_createLocation(self):
 
@@ -310,7 +298,6 @@ class GatewayTestCase(RunCommandTestCase):
         self.assertEquals(set(results["result"]["ReadProxies"]), set(['user03', 'user04']))
         self.assertEquals(set(results["result"]["WriteProxies"]), set(['user05', 'user06']))
 
-
     @inlineCallbacks
     def test_createLocationMinimal(self):
         """
@@ -330,7 +317,6 @@ class GatewayTestCase(RunCommandTestCase):
         else:
             self.fail("We did not find the Minimal record")
 
-
     @inlineCallbacks
     def test_setLocationAttributes(self):
 
@@ -354,7 +340,6 @@ class GatewayTestCase(RunCommandTestCase):
         self.assertEquals(set(results["result"]["ReadProxies"]), set(['user03']))
         self.assertEquals(set(results["result"]["WriteProxies"]), set(['user05', 'user06', 'user07']))
 
-
     @inlineCallbacks
     def test_setAddressOnLocation(self):
         yield self.runCommand(command_createLocation)
@@ -372,7 +357,6 @@ class GatewayTestCase(RunCommandTestCase):
         record = yield self.directory.recordWithUID("836B1B66-2E9A-4F46-8B1C-3DD6772C20B2")
         self.assertEquals(record.associatedAddress, u"")
 
-
     @inlineCallbacks
     def test_destroyLocation(self):
 
@@ -387,7 +371,6 @@ class GatewayTestCase(RunCommandTestCase):
         record = yield self.directory.recordWithUID("location01")
         self.assertEquals(record, None)
 
-
     @inlineCallbacks
     def test_createResource(self):
 
@@ -402,11 +385,14 @@ class GatewayTestCase(RunCommandTestCase):
         record = yield self.directory.recordWithUID("AF575A61-CFA6-49E1-A0F6-B5662C9D9801")
         self.assertNotEquals(record, None)
 
-
     @inlineCallbacks
     def test_setResourceAttributes(self):
 
         yield self.runCommand(command_createResource)
+
+        # Tell the resources services to flush its cache and re-read XML
+        self._flush()
+
         record = yield self.directory.recordWithUID("AF575A61-CFA6-49E1-A0F6-B5662C9D9801")
         self.assertEquals(record.displayName, "Laptop 1")
 
@@ -418,7 +404,6 @@ class GatewayTestCase(RunCommandTestCase):
         record = yield self.directory.recordWithUID("AF575A61-CFA6-49E1-A0F6-B5662C9D9801")
         self.assertEquals(record.displayName, "Updated Laptop 1")
 
-
     @inlineCallbacks
     def test_destroyResource(self):
 
@@ -433,20 +418,17 @@ class GatewayTestCase(RunCommandTestCase):
         record = yield self.directory.recordWithUID("resource01")
         self.assertEquals(record, None)
 
-
     @inlineCallbacks
     def test_addWriteProxy(self):
         results = yield self.runCommand(command_addWriteProxy)
         self.assertEquals(len(results["result"]["Proxies"]), 1)
 
-
     @inlineCallbacks
     def test_removeWriteProxy(self):
         yield self.runCommand(command_addWriteProxy)
         results = yield self.runCommand(command_removeWriteProxy)
         self.assertEquals(len(results["result"]["Proxies"]), 0)
 
-
     @inlineCallbacks
     def test_purgeOldEvents(self):
         results = yield self.runCommand(command_purgeOldEvents)
@@ -455,7 +437,6 @@ class GatewayTestCase(RunCommandTestCase):
         results = yield self.runCommand(command_purgeOldEventsNoDays)
         self.assertEquals(results["result"]["RetainDays"], 365)
 
-
     @inlineCallbacks
     def test_readConfig(self):
         """
@@ -480,7 +461,6 @@ class GatewayTestCase(RunCommandTestCase):
         # Verify other non-writeable keys are not present, such as DataRoot which is not writable
         self.assertFalse("DataRoot" in results["result"])
 
-
     @inlineCallbacks
     def test_writeConfig(self):
         """
