@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 ##
-# Copyright (c) 2009-2015 Apple Inc. All rights reserved.
+# Copyright (c) 2009-2017 Apple Inc. All rights reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -26,6 +26,14 @@ import sys
 import tables
 import traceback
 import glob
+from calendarserver.logAnalysis import getAdjustedMethodName, METHOD_PUT_ICS, \
+    METHOD_PUT_ORGANIZER, METHOD_PUT_ATTENDEE, METHOD_PROPFIND_CALENDAR, \
+    METHOD_POST_FREEBUSY, METHOD_POST_ORGANIZER, METHOD_POST_ISCHEDULE_FREEBUSY, \
+    METHOD_POST_ISCHEDULE, METHOD_GET_DROPBOX, METHOD_PROPFIND_CALENDAR_HOME, \
+    METHOD_PROPFIND_CACHED_CALENDAR_HOME, METHOD_PROPFIND_ADDRESSBOOK_HOME, \
+    METHOD_PROPFIND_CACHED_ADDRESSBOOK_HOME, METHOD_PROPFIND_PRINCIPALS, \
+    METHOD_PROPFIND_CACHED_PRINCIPALS
+
 
 def safePercent(x, y, multiplier=100):
     return ((multiplier * x) / y) if y else 0
@@ -114,82 +122,10 @@ httpMethods = set((
     "SEARCH",
 ))
 
-# Adjust method names
-
-# PROPFINDs
-METHOD_PROPFIND_CALENDAR_HOME = "PROPFIND Calendar Home"
-METHOD_PROPFIND_CACHED_CALENDAR_HOME = "PROPFIND cached Calendar Home"
-METHOD_PROPFIND_CALENDAR = "PROPFIND Calendar"
-METHOD_PROPFIND_INBOX = "PROPFIND Inbox"
-METHOD_PROPFIND_ADDRESSBOOK_HOME = "PROPFIND Adbk Home"
-METHOD_PROPFIND_CACHED_ADDRESSBOOK_HOME = "PROPFIND cached Adbk Home"
-METHOD_PROPFIND_ADDRESSBOOK = "PROPFIND Adbk"
-METHOD_PROPFIND_DIRECTORY = "PROPFIND Directory"
-METHOD_PROPFIND_PRINCIPALS = "PROPFIND Principals"
-METHOD_PROPFIND_CACHED_PRINCIPALS = "PROPFIND cached Principals"
-
-# PROPPATCHs
-METHOD_PROPPATCH_CALENDAR = "PROPPATCH Calendar"
-METHOD_PROPPATCH_ADDRESSBOOK = "PROPPATCH Adbk Home"
-
-# REPORTs
-METHOD_REPORT_CALENDAR_MULTIGET = "REPORT cal-multi"
-METHOD_REPORT_CALENDAR_QUERY = "REPORT cal-query"
-METHOD_REPORT_CALENDAR_FREEBUSY = "REPORT freebusy"
-METHOD_REPORT_CALENDAR_SYNC = "REPORT cal-sync"
-METHOD_REPORT_ADDRESSBOOK_MULTIGET = "REPORT adbk-multi"
-METHOD_REPORT_ADDRESSBOOK_QUERY = "REPORT adbk-query"
-METHOD_REPORT_DIRECTORY_QUERY = "REPORT dir-query"
-METHOD_REPORT_ADDRESSBOOK_SYNC = "REPORT adbk-sync"
-METHOD_REPORT_P_SEARCH_P_SET = "REPORT p-set"
-METHOD_REPORT_P_P_SEARCH = "REPORT p-search"
-METHOD_REPORT_EXPAND_P = "REPORT expand"
-
-# POSTs
-METHOD_POST_CALENDAR_HOME = "POST Calendar Home"
-METHOD_POST_CALENDAR = "POST Calendar"
-METHOD_POST_ADDRESSBOOK_HOME = "POST Adbk Home"
-METHOD_POST_ADDRESSBOOK = "POST Adbk"
-METHOD_POST_ISCHEDULE_FREEBUSY = "POST Freebusy iSchedule"
-METHOD_POST_ISCHEDULE = "POST iSchedule"
-METHOD_POST_TIMEZONES = "POST Timezones"
-METHOD_POST_FREEBUSY = "POST Freebusy"
-METHOD_POST_ORGANIZER = "POST Organizer"
-METHOD_POST_ATTENDEE = "POST Attendee"
-METHOD_POST_OUTBOX = "POST Outbox"
-METHOD_POST_APNS = "POST apns"
-
-# PUTs
-METHOD_PUT_ICS = "PUT ics"
-METHOD_PUT_ORGANIZER = "PUT Organizer"
-METHOD_PUT_ATTENDEE = "PUT Attendee"
-METHOD_PUT_DROPBOX = "PUT dropbox"
-METHOD_PUT_VCF = "PUT VCF"
-
-# GETs
-METHOD_GET_CALENDAR_HOME = "GET Calendar Home"
-METHOD_GET_CALENDAR = "GET Calendar"
-METHOD_GET_ICS = "GET ics"
-METHOD_GET_INBOX_ICS = "GET inbox ics"
-METHOD_GET_DROPBOX = "GET dropbox"
-METHOD_GET_ADDRESSBOOK_HOME = "GET Adbk Home"
-METHOD_GET_ADDRESSBOOK = "GET Adbk"
-METHOD_GET_VCF = "GET VCF"
-METHOD_GET_TIMEZONES = "GET Timezones"
-
-# DELETEs
-METHOD_DELETE_CALENDAR_HOME = "DELETE Calendar Home"
-METHOD_DELETE_CALENDAR = "DELETE Calendar"
-METHOD_DELETE_ICS = "DELETE ics"
-METHOD_DELETE_INBOX_ICS = "DELETE inbox ics"
-METHOD_DELETE_DROPBOX = "DELETE dropbox"
-METHOD_DELETE_ADDRESSBOOK_HOME = "DELETE Adbk Home"
-METHOD_DELETE_ADDRESSBOOK = "DELETE Adbk"
-METHOD_DELETE_VCF = "DELETE vcf"
-
 # 401s
 METHOD_401 = "Z 401s"
 
+
 class CalendarServerLogAnalyzer(object):
 
     """
@@ -222,7 +158,6 @@ class CalendarServerLogAnalyzer(object):
             self.client = client
             self.extended = extended
 
-
     def __init__(
         self,
         startHour=None,
@@ -304,7 +239,6 @@ class CalendarServerLogAnalyzer(object):
         self.currentLine = None
         self.linesRead = collections.defaultdict(int)
 
-
     def analyzeLogFile(self, logFilePath):
         fpath = os.path.expanduser(logFilePath)
         if fpath.endswith(".gz"):
@@ -332,7 +266,7 @@ class CalendarServerLogAnalyzer(object):
                     continue
 
                 # Filter method
-                if self.ignoreNonHTTPMethods and not self.currentLine.method.startswith("REPORT(") and self.currentLine.method not in httpMethods:
+                if self.ignoreNonHTTPMethods and not self.currentLine.method.startswith("REPORT(") and not self.currentLine.method.startswith("POST(") and self.currentLine.method not in httpMethods:
                     self.currentLine.method = "???"
 
                 # Do hour ranges
@@ -443,7 +377,7 @@ class CalendarServerLogAnalyzer(object):
 
                 # Scheduling analysis
                 if adjustedMethod == METHOD_POST_FREEBUSY:
-                    recipients = int(self.currentLine.extended.get("recipients", 0)) + int(self.currentLine.extended.get("freebusy", 0))
+                    recipients = int(self.currentLine.extended.get("recipients", 0))
                     self.hourlyByRecipientCount["Freebusy One Offs" if recipients == 1 else "Freebusy Average"][timeBucketIndex][0] += 1
                     self.hourlyByRecipientCount["Freebusy One Offs" if recipients == 1 else "Freebusy Average"][timeBucketIndex][1] += recipients
                     self.hourlyByRecipientCount["Freebusy Max."][timeBucketIndex][0] = max(self.hourlyByRecipientCount["Freebusy Max."][timeBucketIndex][0], recipients)
@@ -458,7 +392,7 @@ class CalendarServerLogAnalyzer(object):
                     self.hourlyByRecipientCount["iTIP Average"][timeBucketIndex][1] += recipients
                     self.hourlyByRecipientCount["iTIP Max."][timeBucketIndex][0] = max(self.hourlyByRecipientCount["iTIP Max."][timeBucketIndex][0], recipients)
                 elif adjustedMethod == METHOD_POST_ISCHEDULE_FREEBUSY:
-                    recipients = int(self.currentLine.extended.get("recipients", 0)) + int(self.currentLine.extended.get("freebusy", 0))
+                    recipients = int(self.currentLine.extended.get("recipients", 0))
                     self.hourlyByRecipientCount["iFreebusy One Offs" if recipients == 1 else "iFreebusy Average"][timeBucketIndex][0] += 1
                     self.hourlyByRecipientCount["iFreebusy One Offs" if recipients == 1 else "iFreebusy Average"][timeBucketIndex][1] += recipients
                     self.hourlyByRecipientCount["iFreebusy Max."][timeBucketIndex][0] = max(self.hourlyByRecipientCount["iFreebusy Max."][timeBucketIndex][0], recipients)
@@ -505,6 +439,9 @@ class CalendarServerLogAnalyzer(object):
             print("Failed to process line:\n%s" % (line,))
             raise
 
+        finally:
+            f.close()
+
         # Average various items
         self.averagedHourlyByMethodTime.clear()
         for method, hours in self.hourlyByMethodTime.iteritems():
@@ -549,13 +486,15 @@ class CalendarServerLogAnalyzer(object):
                 self.clientByMethodAveragedTime[client][method] = totaltime / count if count else 0
 
         self.clientIDMap = {}
-        for ctr, client in enumerate(sorted(self.clientByMethodCount.keys())):
-            self.clientIDMap[client] = "ID-%02d" % (ctr + 1,)
+        for ctr, client in enumerate(sorted(self.clientByMethodCount.keys(), key=lambda x: x.lower())):
+            if ctr == 0:
+                self.clientIDMap[client] = "Total"
+            else:
+                self.clientIDMap[client] = "ID-%02d" % (ctr,)
         self.clientIDByMethodCount = {}
         for client, data in self.clientByMethodCount.iteritems():
             self.clientIDByMethodCount[self.clientIDMap[client]] = data
 
-
     def parseLine(self, line):
 
         startPos = line.find("- ")
@@ -623,7 +562,6 @@ class CalendarServerLogAnalyzer(object):
 
         self.currentLine = CalendarServerLogAnalyzer.LogLine(ipaddr, userid, logDateTime, logTime, method, uri, status, reqbytes, referrer, client, extended)
 
-
     def getClientAdjustedName(self):
 
         versionClients = (
@@ -672,214 +610,8 @@ class CalendarServerLogAnalyzer(object):
 
         return self.currentLine.client[:20]
 
-
     def getAdjustedMethodName(self):
-
-        uribits = self.currentLine.uri.rstrip("/").split('/')[1:]
-        if len(uribits) == 0:
-            uribits = [self.currentLine.uri]
-
-        calendar_specials = ("dropbox", "notification", "freebusy", "outbox",)
-        adbk_specials = ("notification",)
-
-        if self.currentLine.method == "PROPFIND":
-
-            cached = "cached" in self.currentLine.extended
-
-            if uribits[0] == "calendars":
-
-                if len(uribits) == 3:
-                    return METHOD_PROPFIND_CACHED_CALENDAR_HOME if cached else METHOD_PROPFIND_CALENDAR_HOME
-                elif len(uribits) > 3:
-                    if uribits[3] in calendar_specials:
-                        return "PROPFIND %s" % (uribits[3],)
-                    elif len(uribits) == 4:
-                        if uribits[3] == "inbox":
-                            return METHOD_PROPFIND_INBOX
-                        else:
-                            return METHOD_PROPFIND_CALENDAR
-
-            elif uribits[0] == "addressbooks":
-
-                if len(uribits) == 3:
-                    return METHOD_PROPFIND_CACHED_ADDRESSBOOK_HOME if cached else METHOD_PROPFIND_ADDRESSBOOK_HOME
-                elif len(uribits) > 3:
-                    if uribits[3] in adbk_specials:
-                        return "PROPFIND %s" % (uribits[3],)
-                    elif len(uribits) == 4:
-                        return METHOD_PROPFIND_ADDRESSBOOK
-
-            elif uribits[0] == "directory":
-                return METHOD_PROPFIND_DIRECTORY
-
-            elif uribits[0] == "principals":
-                return METHOD_PROPFIND_CACHED_PRINCIPALS if cached else METHOD_PROPFIND_PRINCIPALS
-
-        elif self.currentLine.method.startswith("REPORT"):
-
-            if "(" in self.currentLine.method:
-                report_type = self.currentLine.method.split("}" if "}" in self.currentLine.method else ":")[1][:-1]
-                if report_type == "addressbook-query":
-                    if uribits[0] == "directory":
-                        report_type = "directory-query"
-                if report_type == "sync-collection":
-                    if uribits[0] == "calendars":
-                        report_type = "cal-sync"
-                    elif uribits[0] == "addressbooks":
-                        report_type = "adbk-sync"
-                mappedNames = {
-                    "calendar-multiget"             : METHOD_REPORT_CALENDAR_MULTIGET,
-                    "calendar-query"                : METHOD_REPORT_CALENDAR_QUERY,
-                    "free-busy-query"               : METHOD_REPORT_CALENDAR_FREEBUSY,
-                    "cal-sync"                      : METHOD_REPORT_CALENDAR_SYNC,
-                    "addressbook-multiget"          : METHOD_REPORT_ADDRESSBOOK_MULTIGET,
-                    "addressbook-query"             : METHOD_REPORT_ADDRESSBOOK_QUERY,
-                    "directory-query"               : METHOD_REPORT_DIRECTORY_QUERY,
-                    "adbk-sync"                     : METHOD_REPORT_ADDRESSBOOK_SYNC,
-                    "principal-search-property-set" : METHOD_REPORT_P_SEARCH_P_SET,
-                    "principal-property-search"     : METHOD_REPORT_P_P_SEARCH,
-                    "expand-property"               : METHOD_REPORT_EXPAND_P,
-                }
-                return mappedNames.get(report_type, "REPORT %s" % (report_type,))
-
-        elif self.currentLine.method == "PROPPATCH":
-
-            if uribits[0] == "calendars":
-                return METHOD_PROPPATCH_CALENDAR
-            elif uribits[0] == "addressbooks":
-                return METHOD_PROPPATCH_ADDRESSBOOK
-
-        elif self.currentLine.method == "POST":
-
-            if uribits[0] == "calendars":
-
-                if len(uribits) == 3:
-                    return METHOD_POST_CALENDAR_HOME
-                elif len(uribits) == 4:
-                    if uribits[3] == "outbox":
-                        if "recipients" in self.currentLine.extended:
-                            return METHOD_POST_FREEBUSY
-                        elif "freebusy" in self.currentLine.extended:
-                            return METHOD_POST_FREEBUSY
-                        elif "itip.request" in self.currentLine.extended or "itip.cancel" in self.currentLine.extended:
-                            return METHOD_POST_ORGANIZER
-                        elif "itip.reply" in self.currentLine.extended:
-                            return METHOD_POST_ATTENDEE
-                        else:
-                            return METHOD_POST_OUTBOX
-                    elif uribits[3] in calendar_specials:
-                        pass
-                    else:
-                        return METHOD_POST_CALENDAR
-
-            elif uribits[0] == "addressbooks":
-
-                if len(uribits) == 3:
-                    return METHOD_POST_ADDRESSBOOK_HOME
-                elif len(uribits) == 4:
-                    if uribits[3] in adbk_specials:
-                        pass
-                    else:
-                        return METHOD_POST_ADDRESSBOOK
-
-            elif uribits[0] == "ischedule":
-                if "fb-cached" in self.currentLine.extended or "fb-uncached" in self.currentLine.extended or "freebusy" in self.currentLine.extended:
-                    return METHOD_POST_ISCHEDULE_FREEBUSY
-                else:
-                    return METHOD_POST_ISCHEDULE
-
-            elif uribits[0].startswith("timezones"):
-                return METHOD_POST_TIMEZONES
-
-            elif uribits[0].startswith("apns"):
-                return METHOD_POST_APNS
-
-        elif self.currentLine.method == "PUT":
-
-            if uribits[0] == "calendars":
-                if len(uribits) > 3:
-                    if uribits[3] in calendar_specials:
-                        return "PUT %s" % (uribits[3],)
-                    elif len(uribits) == 4:
-                        pass
-                    else:
-                        if "itip.requests" in self.currentLine.extended:
-                            return METHOD_PUT_ORGANIZER
-                        elif "itip.reply" in self.currentLine.extended:
-                            return METHOD_PUT_ATTENDEE
-                        else:
-                            return METHOD_PUT_ICS
-
-            elif uribits[0] == "addressbooks":
-                if len(uribits) > 3:
-                    if uribits[3] in adbk_specials:
-                        return "PUT %s" % (uribits[3],)
-                    elif len(uribits) == 4:
-                        pass
-                    else:
-                        return METHOD_PUT_VCF
-
-        elif self.currentLine.method == "GET":
-
-            if uribits[0] == "calendars":
-
-                if len(uribits) == 3:
-                    return METHOD_GET_CALENDAR_HOME
-                elif len(uribits) > 3:
-                    if uribits[3] in calendar_specials:
-                        return "GET %s" % (uribits[3],)
-                    elif len(uribits) == 4:
-                        return METHOD_GET_CALENDAR
-                    elif uribits[3] == "inbox":
-                        return METHOD_GET_INBOX_ICS
-                    else:
-                        return METHOD_GET_ICS
-
-            elif uribits[0] == "addressbooks":
-
-                if len(uribits) == 3:
-                    return METHOD_GET_ADDRESSBOOK_HOME
-                elif len(uribits) > 3:
-                    if uribits[3] in adbk_specials:
-                        return "GET %s" % (uribits[3],)
-                    elif len(uribits) == 4:
-                        return METHOD_GET_ADDRESSBOOK
-                    else:
-                        return METHOD_GET_VCF
-
-            elif uribits[0].startswith("timezones"):
-                return METHOD_GET_TIMEZONES
-
-        elif self.currentLine.method == "DELETE":
-
-            if uribits[0] == "calendars":
-
-                if len(uribits) == 3:
-                    return METHOD_DELETE_CALENDAR_HOME
-                elif len(uribits) > 3:
-                    if uribits[3] in calendar_specials:
-                        return "DELETE %s" % (uribits[3],)
-                    elif len(uribits) == 4:
-                        return METHOD_DELETE_CALENDAR
-                    elif uribits[3] == "inbox":
-                        return METHOD_DELETE_INBOX_ICS
-                    else:
-                        return METHOD_DELETE_ICS
-
-            elif uribits[0] == "addressbooks":
-
-                if len(uribits) == 3:
-                    return METHOD_DELETE_ADDRESSBOOK_HOME
-                elif len(uribits) > 3:
-                    if uribits[3] in adbk_specials:
-                        return "DELETE %s" % (uribits[3],)
-                    elif len(uribits) == 4:
-                        return METHOD_DELETE_ADDRESSBOOK
-                    else:
-                        return METHOD_DELETE_VCF
-
-        return self.currentLine.method
-
+        return getAdjustedMethodName(self.currentLine.extended, self.currentLine.method, self.currentLine.uri)
 
     def getCountBucket(self, count, buckets):
 
@@ -939,7 +671,6 @@ class CalendarServerLogAnalyzer(object):
         self.userCounts["%s:%s" % (self.currentLine.userid, self.getClientAdjustedName(),)] += 1
         self.userResponseTimes["%s:%s" % (self.currentLine.userid, self.getClientAdjustedName(),)] += responseTime
 
-
     def summarizeUserInteraction(self, adjustedMethod):
         summary = {}
         otherData = self.otherUserCalendarRequests.get(adjustedMethod, {})
@@ -948,7 +679,6 @@ class CalendarServerLogAnalyzer(object):
             summary[bucket] = summary.get(bucket, 0) + 1
         return summary
 
-
     def userInteractionAnalysis(self, adjustedMethod):
         """
         If the current line is a record of one user accessing another
@@ -962,7 +692,6 @@ class CalendarServerLogAnalyzer(object):
             if segments[3:] != [self.currentLine.userid, '']:
                 others.add(segments[3])
 
-
     def printAll(self, doTabs, summary):
 
         self.printInfo(doTabs)
@@ -1051,7 +780,6 @@ class CalendarServerLogAnalyzer(object):
             print("Sim values")
             self.printSimStats(doTabs)
 
-
     def printInfo(self, doTabs):
 
         table = tables.Table()
@@ -1068,7 +796,6 @@ class CalendarServerLogAnalyzer(object):
         table.printTabDelimitedData() if doTabs else table.printTable()
         print("")
 
-
     def getHourFromIndex(self, index):
 
         if index >= self.maxIndex:
@@ -1082,7 +809,6 @@ class CalendarServerLogAnalyzer(object):
         # Clip to select hour range
         return "%02d:%02d (%02d:%02d)" % (localhour, minute, utchour, minute,)
 
-
     def printHourlyTotals(self, doTabs, summary):
 
         table = tables.Table()
@@ -1146,24 +872,25 @@ class CalendarServerLogAnalyzer(object):
         table.printTabDelimitedData() if doTabs else table.printTable()
         print("")
 
-
     def printClientTotals(self, doTabs):
 
         table = tables.Table()
 
         table.setDefaultColumnFormats((
+            tables.Table.ColumnFormat("%s", tables.Table.ColumnFormat.LEFT_JUSTIFY),
             tables.Table.ColumnFormat("%s", tables.Table.ColumnFormat.LEFT_JUSTIFY),
             tables.Table.ColumnFormat("%s", tables.Table.ColumnFormat.RIGHT_JUSTIFY),
             tables.Table.ColumnFormat("%s", tables.Table.ColumnFormat.RIGHT_JUSTIFY),
             tables.Table.ColumnFormat("%s", tables.Table.ColumnFormat.RIGHT_JUSTIFY),
         ))
 
-        table.addHeader(("Client", "Total", "Unique", "Unique"))
-        table.addHeader(("", "", "Users", "IP addrs"))
+        table.addHeader(("ID", "Client", "Total", "Unique", "Unique"))
+        table.addHeader(("", "", "", "Users", "IP addrs"))
         for title, clientData in sorted(self.clientTotals.iteritems(), key=lambda x: x[0].lower()):
             if title == " TOTAL":
                 continue
             table.addRow((
+                "%s" % (self.clientIDMap[title],),
                 title,
                 "%d (%2d%%)" % (clientData[0], safePercent(clientData[0], self.clientTotals[" TOTAL"][0]),),
                 "%d (%2d%%)" % (len(clientData[1]), safePercent(len(clientData[1]), len(self.clientTotals[" TOTAL"][1])),),
@@ -1172,6 +899,7 @@ class CalendarServerLogAnalyzer(object):
 
         table.addFooter((
             "All",
+            "",
             "%d      " % (self.clientTotals[" TOTAL"][0],),
             "%d      " % (len(self.clientTotals[" TOTAL"][1]),),
             "%d      " % (len(self.clientTotals[" TOTAL"][2]),),
@@ -1180,7 +908,6 @@ class CalendarServerLogAnalyzer(object):
         table.printTabDelimitedData() if doTabs else table.printTable()
         print("")
 
-
     def printHourlyByXXXDetails(self, hourlyByXXX, doTabs, showTotals=True, showAverages=False, showFloatPercent=False):
 
         totals = [(0, 0,)] * len(hourlyByXXX)
@@ -1271,7 +998,6 @@ class CalendarServerLogAnalyzer(object):
         table.printTabDelimitedData() if doTabs else table.printTable()
         print("")
 
-
     def printHourlyCacheDetails(self, doTabs):
 
         totals = [0, ] * 7
@@ -1362,7 +1088,6 @@ class CalendarServerLogAnalyzer(object):
         table.printTabDelimitedData() if doTabs else table.printTable()
         print("")
 
-
     def printQueueDepthResponseTime(self, doTabs):
 
         table = tables.Table()
@@ -1384,7 +1109,6 @@ class CalendarServerLogAnalyzer(object):
         table.printTabDelimitedData() if doTabs else table.printTable()
         print("")
 
-
     def printXXXMethodDetails(self, data, doTabs, verticalTotals=True):
 
         table = tables.Table()
@@ -1421,7 +1145,6 @@ class CalendarServerLogAnalyzer(object):
         table.printTabDelimitedData() if doTabs else table.printTable()
         print("")
 
-
     def printInstanceCount(self, doTabs):
 
         total = sum(self.instanceCount.values())
@@ -1451,7 +1174,6 @@ class CalendarServerLogAnalyzer(object):
         table.printTabDelimitedData() if doTabs else table.printTable()
         print("")
 
-
     def printURICounts(self, doTabs):
 
         total = sum(self.requestURI.values())
@@ -1475,7 +1197,6 @@ class CalendarServerLogAnalyzer(object):
         table.printTabDelimitedData() if doTabs else table.printTable()
         print("")
 
-
     def printUserWeights(self, doTabs):
 
         total = sum(self.userWeights.values())
@@ -1499,7 +1220,6 @@ class CalendarServerLogAnalyzer(object):
         table.printTabDelimitedData() if doTabs else table.printTable()
         print("")
 
-
     def printResponseCounts(self, doTabs):
 
         table = tables.Table()
@@ -1522,7 +1242,6 @@ class CalendarServerLogAnalyzer(object):
         table.printTabDelimitedData() if doTabs else table.printTable()
         print("")
 
-
     def printUserResponseTimes(self, doTabs):
 
         totalCount = 0
@@ -1551,7 +1270,6 @@ class CalendarServerLogAnalyzer(object):
         table.printTabDelimitedData() if doTabs else table.printTable()
         print("")
 
-
     def printUserInteractionCounts(self, doTabs):
         table = tables.Table()
         table.setDefaultColumnFormats((
@@ -1568,7 +1286,6 @@ class CalendarServerLogAnalyzer(object):
         table.printTabDelimitedData() if doTabs else table.printTable()
         print("")
 
-
     def printSimStats(self, doTabs):
         users = len(self.userCounts.keys())
         hours = self.timeCounts / self.resolutionMinutes / 60
@@ -1600,7 +1317,6 @@ class CalendarServerLogAnalyzer(object):
         print("")
 
 
-
 class TablePrinter(object):
 
     @classmethod
@@ -1660,14 +1376,12 @@ class TablePrinter(object):
         print("")
 
 
-
 class Differ(TablePrinter):
 
     def __init__(self, analyzers):
 
         self.analyzers = analyzers
 
-
     def printAll(self, doTabs, summary):
 
         self.printInfo(doTabs)
@@ -1692,7 +1406,6 @@ class Differ(TablePrinter):
             print("Average Response Count Differences")
             self.printResponseCountDetails(doTabs)
 
-
     def printInfo(self, doTabs):
 
         table = tables.Table()
@@ -1706,7 +1419,6 @@ class Differ(TablePrinter):
         table.printTabDelimitedData() if doTabs else table.printTable()
         print("")
 
-
     def printLoadAnalysisDetails(self, doTabs):
 
         # First gather all the data
@@ -1740,7 +1452,6 @@ class Differ(TablePrinter):
 
         self.printDictDictTable(byCategory, doTabs)
 
-
     def printHourlyTotals(self, doTabs):
 
         table = tables.Table()
@@ -1863,7 +1574,6 @@ class Differ(TablePrinter):
         table.printTabDelimitedData() if doTabs else table.printTable()
         print("")
 
-
     def printClientTotals(self, doTabs):
 
         table = tables.Table()
@@ -1946,7 +1656,6 @@ class Differ(TablePrinter):
         table.printTabDelimitedData() if doTabs else table.printTable()
         print("")
 
-
     def printMethodCountDetails(self, doTabs):
 
         # First gather all the data
@@ -1973,7 +1682,6 @@ class Differ(TablePrinter):
 
         self.printDictDictTable(byMethod, doTabs)
 
-
     def printMethodTimingDetails(self, timingType, doTabs):
 
         # First gather all the data
@@ -2010,7 +1718,6 @@ class Differ(TablePrinter):
 
         self.printDictDictTable(byMethod, doTabs)
 
-
     def printResponseCountDetails(self, doTabs):
 
         # First gather all the data
@@ -2036,7 +1743,6 @@ class Differ(TablePrinter):
         self.printDictDictTable(byMethod, doTabs)
 
 
-
 def usage(error_msg=None):
     if error_msg:
         print(error_msg)
