@@ -1,5 +1,5 @@
 ##
-# Copyright (c) 2006-2015 Apple Inc. All rights reserved.
+# Copyright (c) 2006-2017 Apple Inc. All rights reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -33,6 +33,7 @@ from twistedcaldav.config import config
 
 log = Logger()
 
+
 def accountingEnabled(category, record):
     """
     Determine if accounting is enabled for the given category and record.
@@ -43,7 +44,6 @@ def accountingEnabled(category, record):
     )
 
 
-
 def accountingEnabledForCategory(category):
     """
     Determine if accounting is enabled for the given category.
@@ -54,7 +54,6 @@ def accountingEnabledForCategory(category):
     return AccountingCategories.get(category, False)
 
 
-
 def accountingEnabledForRecord(record):
     """
     Determine if accounting is enabled for the given record.
@@ -67,7 +66,6 @@ def accountingEnabledForRecord(record):
     return record.uid in enabledRecordGUIDs
 
 
-
 def emitAccounting(category, record, data, tag=None, filename=None):
     """
     Write the supplied data to the appropriate location for the given
@@ -127,22 +125,19 @@ def emitAccounting(category, record, data, tag=None, filename=None):
                         logFilename = path
                         break
                     if index == 1000:
-                        log.error("Too many %s accounting files for %s" % (category, record))
+                        log.error("Too many {cat} accounting files for {rec}", cat=category, rec=record)
                         return None
                     index += 1
 
         #
         # Now write out the data to the log file
         #
-        logFile = open(os.path.join(logRoot, logFilename), "a")
-        try:
+        with open(os.path.join(logRoot, logFilename), "a") as logFile:
             logFile.write(data)
-        finally:
-            logFile.close()
 
         return logFilename
 
     except OSError, e:
         # No failures in accounting should propagate out
-        log.error("Failed to write accounting data due to: %s" % (str(e),))
+        log.error("Failed to write accounting data due to: {ex}", ex=str(e))
         return None
