@@ -1,5 +1,5 @@
 ##
-# Copyright (c) 2008-2015 Apple Inc. All rights reserved.
+# Copyright (c) 2008-2017 Apple Inc. All rights reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -71,37 +71,34 @@ is making the request (including proxy state changes etc).
 
 
 class DisabledCacheNotifier(object):
+
     def __init__(self, *args, **kwargs):
         pass
 
-
-    def changed(self):
+    def changed(self, url=None):
         return succeed(None)
 
 
-
 class DisabledCache(object):
+
     def getResponseForRequest(self, request):
         return succeed(None)
 
-
     def cacheResponseForRequest(self, request, response):
         return succeed(response)
 
 
-
 class URINotFoundException(Exception):
+
     def __init__(self, uri):
         self.uri = uri
 
-
     def __repr__(self):
         return "%s: Could not find URI %r" % (
             self.__class__.__name__,
             self.uri)
 
 
-
 class MemcacheChangeNotifier(CachePoolUserMixIn):
     """
     A change notifier used by resources (not store objects).
@@ -113,20 +110,23 @@ class MemcacheChangeNotifier(CachePoolUserMixIn):
         self._cachePool = cachePool
         self._cachePoolHandle = cacheHandle
 
-
     def _newCacheToken(self):
         return str(uuid.uuid4())
 
-
-    def changed(self):
+    def changed(self, url=None):
         """
         Change the cache token for a resource
 
+        @param url: the url whose token is being changed, or C{None} to determine
+            the URL from the supplied resource
+        @type: L{str}
+
         return: A L{Deferred} that fires when the token has been changed.
         """
 
         # For shared resources we use the owner URL as the cache key
-        url = self._resource.url()
+        if url is None:
+            url = self._resource.url()
 
         self.log.debug("Changing Cache Token for {url}", url=url)
         return self.getCachePool().set(
@@ -134,7 +134,6 @@ class MemcacheChangeNotifier(CachePoolUserMixIn):
             self._newCacheToken(), expireTime=config.ResponseCacheTimeout * 60)
 
 
-
 class MemcacheURLPatternChangeNotifier(CachePoolUserMixIn):
     """
     A change notifier used to target arbitrary tokens.
@@ -146,11 +145,9 @@ class MemcacheURLPatternChangeNotifier(CachePoolUserMixIn):
         self._cachePool = cachePool
         self._cachePoolHandle = cacheHandle
 
-
     def _newCacheToken(self):
         return str(uuid.uuid4())
 
-
     def changed(self, token):
         """
         Change the cache token for a resource
@@ -168,7 +165,6 @@ class MemcacheURLPatternChangeNotifier(CachePoolUserMixIn):
         )
 
 
-
 class BaseResponseCache(object):
     """
     A base class which provides some common operations
@@ -178,12 +174,10 @@ class BaseResponseCache(object):
     def _principalURI(self, principal):
         return principal.principalURL() if principal is not None else "unauthenticated"
 
-
     def _uriNotFound(self, f, uri):
         f.trap(AttributeError)
         raise URINotFoundException(uri)
 
-
     def _getRecordForURI(self, uri, request):
         """
         Return the directory record for the specified principal uri.
@@ -198,7 +192,6 @@ class BaseResponseCache(object):
         except AssertionError:
             raise URINotFoundException(uri)
 
-
     @inlineCallbacks
     def _canonicalizeURIForRequest(self, uri, request):
         """
@@ -231,7 +224,6 @@ class BaseResponseCache(object):
         except AssertionError:
             raise URINotFoundException(uri)
 
-
     def _getURIs(self, request):
         """
         Get principal and resource URIs from the request.
@@ -246,7 +238,6 @@ class BaseResponseCache(object):
 
         return d
 
-
     @inlineCallbacks
     def _requestKey(self, request):
         """
@@ -272,20 +263,18 @@ class BaseResponseCache(object):
 
         returnValue(request.cacheKey)
 
-
     def _getResponseBody(self, key, response):
         d1 = allDataFromStream(response.stream)
         d1.addCallback(lambda responseBody: (key, responseBody))
         return d1
 
 
-
 class MemcacheResponseCache(BaseResponseCache, CachePoolUserMixIn):
+
     def __init__(self, docroot, cachePool=None):
         self._docroot = docroot
         self._cachePool = cachePool
 
-
     @inlineCallbacks
     def _tokenForURI(self, uri, cachePoolHandle=None):
         """
@@ -301,7 +290,6 @@ class MemcacheResponseCache(BaseResponseCache, CachePoolUserMixIn):
             _ignore_flags, result = result
         returnValue(result)
 
-
     @inlineCallbacks
     def _tokenForRecord(self, uri, request):
         """
@@ -311,7 +299,6 @@ class MemcacheResponseCache(BaseResponseCache, CachePoolUserMixIn):
         record = (yield self._getRecordForURI(uri, request))
         returnValue(record.cacheToken())
 
-
     @inlineCallbacks
     def _tokensForChildren(self, rURI, request):
         """
@@ -324,7 +311,6 @@ class MemcacheResponseCache(BaseResponseCache, CachePoolUserMixIn):
         else:
             returnValue({})
 
-
     @inlineCallbacks
     def _getTokens(self, request):
         """
@@ -339,7 +325,6 @@ class MemcacheResponseCache(BaseResponseCache, CachePoolUserMixIn):
         tokens.append((yield self._tokensForChildren(rURI, request)))
         returnValue(tokens)
 
-
     @inlineCallbacks
     def _hashedRequestKey(self, request):
         """
@@ -352,7 +337,6 @@ class MemcacheResponseCache(BaseResponseCache, CachePoolUserMixIn):
         self.log.debug("hashing key for get: {old!r} to {new!r}", old=oldkey, new=key)
         returnValue(request.cacheKey)
 
-
     @inlineCallbacks
     def getResponseForRequest(self, request):
         """
@@ -435,7 +419,6 @@ class MemcacheResponseCache(BaseResponseCache, CachePoolUserMixIn):
             self.log.debug("Could not locate URI: {e!r}", e=e)
             returnValue(None)
 
-
     @inlineCallbacks
     def cacheResponseForRequest(self, request, response):
         """
@@ -486,26 +469,22 @@ class MemcacheResponseCache(BaseResponseCache, CachePoolUserMixIn):
         returnValue(response)
 
 
-
 class _CachedResponseResource(object):
     implements(IResource)
 
     def __init__(self, response):
         self._response = response
 
-
     def renderHTTP(self, request):
         if not hasattr(request, "extendedLogItems"):
             request.extendedLogItems = {}
         request.extendedLogItems["cached"] = "1"
         return self._response
 
-
     def locateChild(self, request, segments):
         return self, []
 
 
-
 class PropfindCacheMixin(object):
     """
     A mixin that causes a resource's PROPFIND response to be cached. It also adds an api to change the
@@ -526,7 +505,6 @@ class PropfindCacheMixin(object):
         returnValue(response)
 
 
-
 class CacheStoreNotifierFactory(CachePoolUserMixIn):
     """
     A notifier factory specifically for store object notifications. This is handed of to
@@ -543,11 +521,9 @@ class CacheStoreNotifierFactory(CachePoolUserMixIn):
     def newNotifier(self, storeObject):
         return CacheStoreNotifier(self, storeObject)
 
-
     def _newCacheToken(self):
         return str(uuid.uuid4())
 
-
     def changed(self, cache_id):
         """
         Change the cache token for a store object.
@@ -561,7 +537,6 @@ class CacheStoreNotifierFactory(CachePoolUserMixIn):
             self._newCacheToken(), expireTime=config.ResponseCacheTimeout * 60)
 
 
-
 class CacheStoreNotifier(object):
     """
     A notifier for store objects. Store objects will call .notify() when they change.
@@ -573,7 +548,6 @@ class CacheStoreNotifier(object):
         self._notifierFactory = notifierFactory
         self._storeObject = storeObject
 
-
     @inlineCallbacks
     def notify(self):
         """
@@ -601,6 +575,5 @@ class CacheStoreNotifier(object):
         for uri in uris:
             yield self._notifierFactory.changed(uri)
 
-
     def clone(self, storeObject):
         return self.__class__(self._notifierFactory, storeObject)
