@@ -1,6 +1,6 @@
 # -*- test-case-name: twistedcaldav.directory.test.test_principal -*-
 ##
-# Copyright (c) 2006-2015 Apple Inc. All rights reserved.
+# Copyright (c) 2006-2017 Apple Inc. All rights reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -76,10 +76,10 @@ log = Logger()
 
 
 class PermissionsMixIn (ReadOnlyResourceMixIn):
+
     def defaultAccessControlList(self):
         return succeed(authReadACL)
 
-
     @inlineCallbacks
     def accessControlList(self, request, inheritance=True, expanding=False, inherited_aces=None):
 
@@ -90,7 +90,7 @@ class PermissionsMixIn (ReadOnlyResourceMixIn):
 
         if wikiACL is not None:
             # ACL depends on wiki server...
-            log.debug("Wiki ACL: %s" % (wikiACL.toxml(),))
+            log.debug("Wiki ACL: {acl}", acl=wikiACL.toxml())
             returnValue(wikiACL)
         else:
             # ...otherwise permissions are fixed, and are not subject to
@@ -98,7 +98,6 @@ class PermissionsMixIn (ReadOnlyResourceMixIn):
             returnValue((yield self.defaultAccessControlList()))
 
 
-
 # Converter methods for recordsMatchingFields()
 #
 # A DAV property can be associated with one of these converter methods,
@@ -112,7 +111,6 @@ def cuTypeConverter(cuType):
     return "recordType", CalendarDirectoryRecordMixin.fromCUType(cuType)
 
 
-
 def cuAddressConverter(origCUAddr):
     """ Converts calendar user addresses to OD-compatible form """
 
@@ -141,11 +139,11 @@ def cuAddressConverter(origCUAddr):
         )
 
 
-
 class DirectoryProvisioningResource (
     PermissionsMixIn,
     CalendarPrincipalCollectionResource,
 ):
+
     def __init__(self, url, directory):
         """
         @param url: the canonical URL for the resource.
@@ -160,11 +158,9 @@ class DirectoryProvisioningResource (
         # self.directory = IDirectoryService(directory)
         self.directory = directory
 
-
     def __repr__(self):
         return "<%s: %s %s>" % (self.__class__.__name__, self.directory, self._url)
 
-
     @inlineCallbacks
     def locateChild(self, req, segments):
         child = (yield self.getChild(segments[0]))
@@ -172,27 +168,22 @@ class DirectoryProvisioningResource (
             returnValue((child, segments[1:]))
         returnValue((NotFoundResource(principalCollections=self.principalCollections()), ()))
 
-
     def deadProperties(self):
         if not hasattr(self, "_dead_properties"):
             self._dead_properties = NonePropertyStore(self)
         return self._dead_properties
 
-
     def etag(self):
         return succeed(None)
 
-
     @inlineCallbacks
     def principalForShortName(self, recordType, name):
         record = (yield self.directory.recordWithShortName(recordType, name))
         returnValue((yield self.principalForRecord(record)))
 
-
     def principalForUser(self, user):
         return self.principalForShortName(self.directory.recordType.lookupByName("user"), user)
 
-
     @inlineCallbacks
     def principalForAuthID(self, user):
         # Basic/Digest creds -> just lookup user name
@@ -212,15 +203,12 @@ class DirectoryProvisioningResource (
 
         returnValue(None)
 
-
     def principalForUID(self, uid):
         raise NotImplementedError("Subclass must implement principalForUID()")
 
-
     def principalForCalendarUserAddress(self, address):
         raise NotImplementedError("Subclass must implement principalForCalendarUserAddress()")
 
-
     def principalForRecord(self, record):
         if record is None or not record.enabled:
             return succeed(None)
@@ -232,18 +220,17 @@ class DirectoryProvisioningResource (
 
     _cs_ns = "http://calendarserver.org/ns/"
     _fieldMap = {
-        ("DAV:" , "displayname") :
+        ("DAV:", "displayname"):
             ("fullNames", None, "Display Name", davxml.DisplayName),
-        ("urn:ietf:params:xml:ns:caldav" , "calendar-user-type") :
+        ("urn:ietf:params:xml:ns:caldav", "calendar-user-type"):
             ("", cuTypeConverter, "Calendar User Type", caldavxml.CalendarUserType),
-        ("urn:ietf:params:xml:ns:caldav" , "calendar-user-address-set") :
+        ("urn:ietf:params:xml:ns:caldav", "calendar-user-address-set"):
             ("", cuAddressConverter, "Calendar User Address Set", caldavxml.CalendarUserAddressSet),
-        (_cs_ns, "email-address-set") :
+        (_cs_ns, "email-address-set"):
             ("emailAddresses", None, "Email Addresses", customxml.EmailAddressSet),
     }
     _fieldList = [v for _ignore_k, v in sorted(_fieldMap.iteritems(), key=lambda x:x[0])]
 
-
     def propertyToField(self, property, match):
         """
         If property is a DAV property that maps to a directory field, return
@@ -257,7 +244,6 @@ class DirectoryProvisioningResource (
             field, match = converter(match)
         return (field, match)
 
-
     def principalSearchPropertySet(self):
         props = []
         for _ignore_field, _ignore_converter, description, xmlClass in self._fieldList:
@@ -276,11 +262,11 @@ class DirectoryProvisioningResource (
         return davxml.PrincipalSearchPropertySet(*props)
 
 
-
 class DirectoryPrincipalProvisioningResource (DirectoryProvisioningResource):
     """
     Collection resource which provisions directory principals as its children.
     """
+
     def __init__(self, url, directory):
         DirectoryProvisioningResource.__init__(self, url, directory)
 
@@ -319,13 +305,11 @@ class DirectoryPrincipalProvisioningResource (DirectoryProvisioningResource):
 
         self.putChild(uidsResourceName, DirectoryPrincipalUIDProvisioningResource(self))
 
-
     @inlineCallbacks
     def principalForUID(self, uid):
         child = (yield self.getChild(uidsResourceName))
         returnValue((yield child.getChild(uid)))
 
-
     @inlineCallbacks
     def _principalForURI(self, uri):
         scheme, netloc, path, _ignore_params, _ignore_query, _ignore_fragment = urlparse(uri)
@@ -353,7 +337,7 @@ class DirectoryPrincipalProvisioningResource (DirectoryProvisioningResource):
                 returnValue(None)
 
             if port != {
-                "http" : config.HTTPPort,
+                "http": config.HTTPPort,
                 "https": config.SSLPort,
             }[scheme]:
                 returnValue(None)
@@ -381,7 +365,6 @@ class DirectoryPrincipalProvisioningResource (DirectoryProvisioningResource):
 
         returnValue(None)
 
-
     @inlineCallbacks
     def principalForCalendarUserAddress(self, address):
         # First see if the address is a principal URI
@@ -398,39 +381,34 @@ class DirectoryPrincipalProvisioningResource (DirectoryProvisioningResource):
             if record is not None and record.hasCalendars:
                 returnValue((yield self.principalForRecord(record)))
 
-        log.debug("No principal for calendar user address: %r" % (address,))
+        log.debug("No principal for calendar user address: {addr}", addr=address)
         returnValue(None)
 
-
     @inlineCallbacks
     def principalForRecord(self, record):
         child = (yield self.getChild(uidsResourceName))
         returnValue((yield child.principalForRecord(record)))
 
-
     ##
     # Static
     ##
 
     def createSimilarFile(self, path):
-        log.error("Attempt to create clone %r of resource %r" % (path, self))
+        log.error("Attempt to create clone {path} of resource {rsrc!r}", path=path, rsrc=self)
         raise HTTPError(responsecode.NOT_FOUND)
 
-
     def getChild(self, name):
         if name == "":
             return succeed(self)
         else:
             return succeed(self.putChildren.get(name, None))
 
-
     def listChildren(self):
         return [
             self.directory.recordTypeToOldName(r) for r in
             self.supportedChildTypes
         ]
 
-
     ##
     # ACL
     ##
@@ -439,12 +417,12 @@ class DirectoryPrincipalProvisioningResource (DirectoryProvisioningResource):
         return (self,)
 
 
-
 class DirectoryPrincipalTypeProvisioningResource (DirectoryProvisioningResource):
     """
     Collection resource which provisions directory principals of a
     specific type as its children, indexed by short name.
     """
+
     def __init__(self, parent, name, recordType):
         """
         @param parent: the parent L{DirectoryPrincipalProvisioningResource}.
@@ -459,15 +437,12 @@ class DirectoryPrincipalTypeProvisioningResource (DirectoryProvisioningResource)
         self.recordType = recordType
         self.parent = parent
 
-
     def principalForUID(self, uid):
         return self.parent.principalForUID(uid)
 
-
     def principalForCalendarUserAddress(self, address):
         return self.parent.principalForCalendarUserAddress(address)
 
-
     def principalForRecord(self, record):
         return self.parent.principalForRecord(record)
 
@@ -475,19 +450,16 @@ class DirectoryPrincipalTypeProvisioningResource (DirectoryProvisioningResource)
     # Static
     ##
 
-
     def createSimilarFile(self, path):
-        log.error("Attempt to create clone %r of resource %r" % (path, self))
+        log.error("Attempt to create clone {path} of resource {rsrc!r}", path=path, rsrc=self)
         raise HTTPError(responsecode.NOT_FOUND)
 
-
     def getChild(self, name):
         if name == "":
             return succeed(self)
         else:
             return self.principalForShortName(self.recordType, name)
 
-
     @inlineCallbacks
     def listChildren(self):
         children = []
@@ -499,8 +471,10 @@ class DirectoryPrincipalTypeProvisioningResource (DirectoryProvisioningResource)
                     for shortName in getattr(record, "shortNames", []):
                         children.append(shortName)
             except AttributeError:
-                log.warn("Cannot list children of record type {rt}",
-                         rt=self.recordType.name)
+                log.warn(
+                    "Cannot list children of record type {rt}",
+                    rt=self.recordType.name
+                )
             returnValue(children)
 
         else:
@@ -511,17 +485,16 @@ class DirectoryPrincipalTypeProvisioningResource (DirectoryProvisioningResource)
     # ACL
     ##
 
-
     def principalCollections(self):
         return self.parent.principalCollections()
 
 
-
 class DirectoryPrincipalUIDProvisioningResource (DirectoryProvisioningResource):
     """
     Collection resource which provisions directory principals indexed
     by UID.
     """
+
     def __init__(self, parent):
         """
         @param directory: an L{IDirectoryService} to provision calendars from.
@@ -535,15 +508,12 @@ class DirectoryPrincipalUIDProvisioningResource (DirectoryProvisioningResource):
 
         self.parent = parent
 
-
     def principalForUID(self, uid):
         return self.parent.principalForUID(uid)
 
-
     def principalForCalendarUserAddress(self, address):
         return self.parent.principalForCalendarUserAddress(address)
 
-
     def principalForRecord(self, record):
         if record is None:
             return succeed(None)
@@ -560,12 +530,10 @@ class DirectoryPrincipalUIDProvisioningResource (DirectoryProvisioningResource):
     # Static
     ##
 
-
     def createSimilarFile(self, path):
-        log.error("Attempt to create clone %r of resource %r" % (path, self))
+        log.error("Attempt to create clone {path} of resource {rsrc!r}", path=path, rsrc=self)
         raise HTTPError(responsecode.NOT_FOUND)
 
-
     @inlineCallbacks
     def getChild(self, name):
         if name == "":
@@ -581,7 +549,7 @@ class DirectoryPrincipalUIDProvisioningResource (DirectoryProvisioningResource):
         record = (yield self.directory.recordWithUID(primaryUID))
         primaryPrincipal = (yield self.principalForRecord(record))
         if primaryPrincipal is None:
-            log.info("No principal found for UID: %s" % (name,))
+            log.info("No principal found for UID: {name}", name=name)
             returnValue(None)
 
         if subType is None:
@@ -589,7 +557,6 @@ class DirectoryPrincipalUIDProvisioningResource (DirectoryProvisioningResource):
         else:
             returnValue((yield primaryPrincipal.getChild(subType)))
 
-
     def listChildren(self):
         # Not a listable collection
         raise HTTPError(responsecode.FORBIDDEN)
@@ -598,12 +565,10 @@ class DirectoryPrincipalUIDProvisioningResource (DirectoryProvisioningResource):
     # ACL
     ##
 
-
     def principalCollections(self):
         return self.parent.principalCollections()
 
 
-
 class DirectoryPrincipalDetailElement(Element):
     """
     Element that can render the details of a
@@ -614,12 +579,10 @@ class DirectoryPrincipalDetailElement(Element):
         "directory-principal-resource.html")
     )
 
-
     def __init__(self, resource):
         super(DirectoryPrincipalDetailElement, self).__init__()
         self.resource = resource
 
-
     @renderer
     def serversEnabled(self, request, tag):
         """
@@ -632,7 +595,6 @@ class DirectoryPrincipalDetailElement(Element):
             hostedAt=str(record.serverURI()),
         )
 
-
     @renderer
     def principal(self, request, tag):
         """
@@ -679,7 +641,6 @@ class DirectoryPrincipalDetailElement(Element):
             ),
         )
 
-
     @renderer
     def extra(self, request, tag):
         """
@@ -687,7 +648,6 @@ class DirectoryPrincipalDetailElement(Element):
         """
         return ''
 
-
     @renderer
     def enabledForCalendaring(self, request, tag):
         """
@@ -695,7 +655,6 @@ class DirectoryPrincipalDetailElement(Element):
         """
         return ''
 
-
     @renderer
     def enabledForAddressBooks(self, request, tag):
         """
@@ -704,7 +663,6 @@ class DirectoryPrincipalDetailElement(Element):
         return ''
 
 
-
 class DirectoryPrincipalElement(DirectoryElement):
     """
     L{DirectoryPrincipalElement} is a renderer for directory details.
@@ -718,7 +676,6 @@ class DirectoryPrincipalElement(DirectoryElement):
         return DirectoryPrincipalDetailElement(self.resource)
 
 
-
 class DirectoryCalendarPrincipalDetailElement(DirectoryPrincipalDetailElement):
 
     @renderer
@@ -729,7 +686,6 @@ class DirectoryCalendarPrincipalDetailElement(DirectoryPrincipalDetailElement):
         """
         return tag
 
-
     @renderer
     def enabledForCalendaring(self, request, tag):
         """
@@ -747,7 +703,6 @@ class DirectoryCalendarPrincipalDetailElement(DirectoryPrincipalDetailElement):
             )
         return ''
 
-
     @renderer
     def enabledForAddressBooks(self, request, tag):
         """
@@ -763,7 +718,6 @@ class DirectoryCalendarPrincipalDetailElement(DirectoryPrincipalDetailElement):
         return ''
 
 
-
 class DirectoryCalendarPrincipalElement(DirectoryPrincipalElement):
     """
     L{DirectoryPrincipalElement} is a renderer for directory details, with
@@ -778,7 +732,6 @@ class DirectoryCalendarPrincipalElement(DirectoryPrincipalElement):
         return DirectoryCalendarPrincipalDetailElement(self.resource)
 
 
-
 class DirectoryPrincipalResource (
         PropfindCacheMixin, PermissionsMixIn, DAVPrincipalResource):
     """
@@ -794,7 +747,6 @@ class DirectoryPrincipalResource (
 
     cacheNotifierFactory = DisabledCacheNotifier
 
-
     def __init__(self, parent, record):
         """
         @param parent: the parent of this resource.
@@ -826,15 +778,12 @@ class DirectoryPrincipalResource (
             for shortName in getattr(record, "shortNames", [])
         ])
 
-
     def __repr__(self):
         return "<{}: {}>".format(self.__class__.__name__, str(self))
 
-
     def __str__(self):
         return "({}){}".format(self.record.recordType, self.record.uid)
 
-
     def __eq__(self, other):
         """
         Principals are the same if their principalURLs are the same.
@@ -844,15 +793,12 @@ class DirectoryPrincipalResource (
         else:
             return False
 
-
     def __ne__(self, other):
         return not self.__eq__(other)
 
-
     def __hash__(self):
         return hash(self.principalUID())
 
-
     @inlineCallbacks
     def readProperty(self, property, request):
         if type(property) is tuple:
@@ -878,13 +824,11 @@ class DirectoryPrincipalResource (
         result = (yield super(DirectoryPrincipalResource, self).readProperty(property, request))
         returnValue(result)
 
-
     def deadProperties(self):
         if not hasattr(self, "_dead_properties"):
             self._dead_properties = NonePropertyStore(self)
         return self._dead_properties
 
-
     def etag(self):
         return succeed(None)
 
@@ -892,7 +836,6 @@ class DirectoryPrincipalResource (
     # HTTP
     ##
 
-
     def htmlElement(self):
         """
         Customize HTML rendering for directory principals.
@@ -903,11 +846,9 @@ class DirectoryPrincipalResource (
     # DAV
     ##
 
-
     def isCollection(self):
         return True
 
-
     @inlineCallbacks
     def handleMissingTrailingSlash(self, request):
         try:
@@ -932,7 +873,6 @@ class DirectoryPrincipalResource (
             )
             returnValue(response)
 
-
     def displayName(self):
         return self.record.displayName
 
@@ -940,7 +880,6 @@ class DirectoryPrincipalResource (
     # ACL
     ##
 
-
     def _calendar_user_proxy_index(self):
         """
         Return the SQL database for calendar user proxies.
@@ -952,24 +891,19 @@ class DirectoryPrincipalResource (
         from twistedcaldav.directory.calendaruserproxy import ProxyDBService
         return ProxyDBService
 
-
     def alternateURIs(self):
         # FIXME: Add API to IDirectoryRecord for getting a record URI?
         return self._alternate_urls
 
-
     def principalURL(self):
         return self._url
 
-
     def url(self):
         return self.principalURL()
 
-
     def notifierID(self):
         return self.principalURL()
 
-
     def isProxyFor(self, principal):
         """
         Determine whether this principal is a read-only or read-write proxy for the
@@ -980,7 +914,6 @@ class DirectoryPrincipalResource (
         """
         return self.record.isProxyFor(principal.record)
 
-
     def proxyMode(self, principal):
         """
         Determine whether proxy mode this principal has in relation to the one specified.
@@ -990,7 +923,6 @@ class DirectoryPrincipalResource (
         """
         return self.record.proxyMode(principal.record)
 
-
     @inlineCallbacks
     def proxyFor(self, readWrite, ignoreDisabled=True):
         """
@@ -1019,7 +951,6 @@ class DirectoryPrincipalResource (
 
         returnValue(proxyFors)
 
-
     @inlineCallbacks
     def _getRelatives(self, method, record=None, relatives=None, records=None, proxy=None, infinity=False):
         if record is None:
@@ -1035,7 +966,7 @@ class DirectoryPrincipalResource (
                 if relative not in records:
                     found = (yield self.parent.principalForRecord(relative))
                     if found is None:
-                        log.error("No principal found for directory record: %r" % (relative,))
+                        log.error("No principal found for directory record: {rec!r}", rec=relative)
                     else:
                         if proxy:
                             if proxy == "read-write":
@@ -1051,15 +982,12 @@ class DirectoryPrincipalResource (
 
         returnValue(relatives)
 
-
     def groupMembers(self):
         return self._getRelatives("members")
 
-
     def expandedGroupMembers(self):
         return self._getRelatives("members", infinity=True)
 
-
     @inlineCallbacks
     def groupMemberships(self, infinity=False):
 
@@ -1079,11 +1007,9 @@ class DirectoryPrincipalResource (
 
         returnValue(groups)
 
-
     def expandedGroupMemberships(self):
         return self.groupMemberships(infinity=True)
 
-
     def groupsChanged(self):
         """
         A callback indicating the directory group membership for this principal
@@ -1092,27 +1018,21 @@ class DirectoryPrincipalResource (
         """
         return self.cacheNotifier.changed()
 
-
     def principalCollections(self):
         return self.parent.principalCollections()
 
-
     def principalUID(self):
         return self.record.uid
 
-
     def serverURI(self):
         return self.record.serverURI()
 
-
     def server(self):
         return self.record.server()
 
-
     def thisServer(self):
         return self.record.thisServer()
 
-
     def canAutoSchedule(self, organizer=None):
         """
         Determine the auto-schedule state based on record state, type and config settings.
@@ -1123,7 +1043,6 @@ class DirectoryPrincipalResource (
         """
         return self.record.canAutoSchedule(organizer)
 
-
     @inlineCallbacks
     def setAutoScheduleMode(self, autoScheduleMode):
         self.record.autoScheduleMode = autoScheduleMode if autoScheduleMode in allowedAutoScheduleModes else "default"
@@ -1131,7 +1050,6 @@ class DirectoryPrincipalResource (
         augmentRecord.autoScheduleMode = autoScheduleMode
         (yield self.record.service.augmentService.addAugmentRecords([augmentRecord]))
 
-
     def getAutoScheduleMode(self, organizer=None):
         """
         Return the auto schedule mode value for the principal.  If the optional
@@ -1148,7 +1066,6 @@ class DirectoryPrincipalResource (
         """
         return self.record.getAutoScheduleMode(organizer)
 
-
     @inlineCallbacks
     def setAutoAcceptGroup(self, autoAcceptGroup):
         """
@@ -1163,7 +1080,6 @@ class DirectoryPrincipalResource (
         augmentRecord.autoAcceptGroup = autoAcceptGroup
         (yield self.record.service.augmentService.addAugmentRecords([augmentRecord]))
 
-
     def getAutoAcceptGroup(self):
         """
         Returns the GUID of the auto accept group assigned to this principal, or empty
@@ -1171,7 +1087,6 @@ class DirectoryPrincipalResource (
         """
         return self.record.autoAcceptGroup
 
-
     def autoAcceptFromOrganizer(self, organizer):
         """
         Is the organizer a member of this principal's autoAcceptGroup?
@@ -1184,7 +1099,6 @@ class DirectoryPrincipalResource (
         """
         return self.record.autoAcceptFromOrganizer()
 
-
     def getCUType(self):
         return self.record.getCUType()
 
@@ -1192,12 +1106,10 @@ class DirectoryPrincipalResource (
     # Static
     ##
 
-
     def createSimilarFile(self, path):
-        log.error("Attempt to create clone %r of resource %r" % (path, self))
+        log.error("Attempt to create clone {path} of resource {rsrc!r}", path=path, rsrc=self)
         raise HTTPError(responsecode.NOT_FOUND)
 
-
     @inlineCallbacks
     def locateChild(self, req, segments):
         child = (yield self.getChild(segments[0]))
@@ -1205,19 +1117,16 @@ class DirectoryPrincipalResource (
             returnValue((child, segments[1:]))
         returnValue((None, ()))
 
-
     def getChild(self, name):
         if name == "":
             return succeed(self)
 
         return succeed(None)
 
-
     def listChildren(self):
         return ()
 
 
-
 class DirectoryCalendarPrincipalResource(DirectoryPrincipalResource,
                                          CalendarPrincipalResource):
     """
@@ -1227,15 +1136,12 @@ class DirectoryCalendarPrincipalResource(DirectoryPrincipalResource,
     def liveProperties(self):
         return DirectoryPrincipalResource.liveProperties(self) + CalendarPrincipalResource.liveProperties(self)
 
-
     def calendarsEnabled(self):
         return self.record.calendarsEnabled()
 
-
     def addressBooksEnabled(self):
         return config.EnableCardDAV and self.record.hasContacts
 
-
     @inlineCallbacks
     def readProperty(self, property, request):
         # Ouch, multiple inheritance.
@@ -1244,34 +1150,28 @@ class DirectoryCalendarPrincipalResource(DirectoryPrincipalResource,
             result = (yield CalendarPrincipalResource.readProperty(self, property, request))
         returnValue(result)
 
-
     ##
     # CalDAV
     ##
 
-
     def calendarUserAddresses(self):
         return self.record.calendarUserAddresses
 
-
     def htmlElement(self):
         """
         Customize HTML generation for calendar principals.
         """
         return DirectoryCalendarPrincipalElement(self)
 
-
     def canonicalCalendarUserAddress(self):
         """
         Return a CUA for this principal
         """
         return self.record.canonicalCalendarUserAddress()
 
-
     def enabledAsOrganizer(self):
         return self.record.enabledAsOrganizer()
 
-
     @inlineCallbacks
     def scheduleInbox(self, request):
         home = yield self.calendarHome(request)
@@ -1284,7 +1184,6 @@ class DirectoryCalendarPrincipalResource(DirectoryPrincipalResource,
 
         returnValue(inbox)
 
-
     @inlineCallbacks
     def notificationCollection(self, request):
 
@@ -1295,7 +1194,6 @@ class DirectoryCalendarPrincipalResource(DirectoryPrincipalResource,
                 notification = yield home.getChild("notification")
         returnValue(notification)
 
-
     def calendarHomeURLs(self):
         if self.record.hasCalendars:
             homeURL = self._homeChildURL(None)
@@ -1303,29 +1201,24 @@ class DirectoryCalendarPrincipalResource(DirectoryPrincipalResource,
             homeURL = ""
         return (homeURL,) if homeURL else ()
 
-
     def scheduleInboxURL(self):
         return self._homeChildURL("inbox/")
 
-
     def scheduleOutboxURL(self):
         return self._homeChildURL("outbox/")
 
-
     def dropboxURL(self):
         if config.EnableDropBox or config.EnableManagedAttachments:
             return self._homeChildURL("dropbox/")
         else:
             return None
 
-
     def notificationURL(self):
         if config.Sharing.Enabled:
             return self._homeChildURL("notification/")
         else:
             return None
 
-
     def addressBookHomeURLs(self):
         if self.record.hasContacts:
             homeURL = self._addressBookHomeChildURL(None)
@@ -1333,7 +1226,6 @@ class DirectoryCalendarPrincipalResource(DirectoryPrincipalResource,
             homeURL = ""
         return (homeURL,) if homeURL else ()
 
-
     def _homeChildURL(self, name):
         if not hasattr(self, "calendarHomeURL"):
             if self.parent.parent.calendarCollection is None:
@@ -1354,14 +1246,12 @@ class DirectoryCalendarPrincipalResource(DirectoryPrincipalResource,
         else:
             return joinURL(url, name) if name else url
 
-
     def calendarHome(self, request):
         if self.parent.parent.calendarCollection is not None:
             return self.parent.parent.calendarCollection.homeForDirectoryRecord(self.record, request)
         else:
             return succeed(None)
 
-
     def _addressBookHomeChildURL(self, name):
         if not hasattr(self, "addressBookHomeURL"):
             if self.parent.parent.addressBookCollection is None:
@@ -1382,7 +1272,6 @@ class DirectoryCalendarPrincipalResource(DirectoryPrincipalResource,
         else:
             return joinURL(url, name) if name else url
 
-
     def addressBookHome(self, request):
         if self.parent.parent.addressBookCollection is not None:
             return self.parent.parent.addressBookCollection.homeForDirectoryRecord(self.record, request)
@@ -1393,7 +1282,6 @@ class DirectoryCalendarPrincipalResource(DirectoryPrincipalResource,
     # Static
     ##
 
-
     def getChild(self, name):
         if name == "":
             return succeed(self)
@@ -1410,7 +1298,6 @@ class DirectoryCalendarPrincipalResource(DirectoryPrincipalResource,
         else:
             return succeed(None)
 
-
     def listChildren(self):
         if config.EnableProxyPrincipals:
             return (
