@@ -1,6 +1,6 @@
 # -*- test-case-name: twistedcaldav.test.test_extensions -*-
 ##
-# Copyright (c) 2005-2015 Apple Inc. All rights reserved.
+# Copyright (c) 2005-2017 Apple Inc. All rights reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,6 +14,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 ##
+
 from __future__ import print_function
 
 """
@@ -70,12 +71,27 @@ from txdav.who.directory import CalendarDirectoryRecordMixin
 from twext.who.expression import Operand, MatchType, MatchFlags
 
 
-
 thisModule = getModule(__name__)
 
 log = Logger()
 
 
+class WebDAVServerInfoMixIn(object):
+
+    def renderHTTP(self, request):
+        def _addServerInfoURL(request, response):
+            # server-info-token processing
+            if config.EnableServerInfo and (
+                request.headers.hasHeader("server-info-token") and request.headers.getRawHeaders("server-info-token")[0] != config.ServerInfoToken or
+                not request.headers.hasHeader("server-info-token") and request.method == "OPTIONS"
+            ):
+                uri = request.unparseURL(path="/server-info")
+                response.headers.setRawHeaders("server-info-url", (uri,))
+            return response
+        request.addResponseFilter(_addServerInfoURL, onlyOnce=True)
+        return super(WebDAVServerInfoMixIn, self).renderHTTP(request)
+
+
 class DirectoryPrincipalPropertySearchMixIn(object):
 
     @inlineCallbacks
@@ -112,7 +128,7 @@ class DirectoryPrincipalPropertySearchMixIn(object):
         # Only handle Depth: 0
         depth = request.headers.getHeader("depth", "0")
         if depth != "0":
-            log.error("Error in principal-property-search REPORT, Depth set to %s" % (depth,))
+            log.error("Error in principal-property-search REPORT, Depth set to {depth}", depth=depth)
             raise HTTPError(StatusResponse(responsecode.BAD_REQUEST, "Depth %s not allowed" % (depth,)))
 
         # Get any limit value from xml
@@ -232,7 +248,7 @@ class DirectoryPrincipalPropertySearchMixIn(object):
                     operand=operand,
                     recordType=recordType,
                     limitResults=clientLimit,
-                    timeoutSeconds=10
+                    timeoutSeconds=config.PrincipalSearchReportTimeout
                 )
             )
 
@@ -265,7 +281,7 @@ class DirectoryPrincipalPropertySearchMixIn(object):
 
         if resultsWereLimited is not None:
             if resultsWereLimited[0] == "server":
-                log.error("Too many matching resources in principal-property-search report")
+                log.debug("Too many matching resources in principal-property-search report")
             responses.append(element.StatusResponse(
                 element.HRef.fromString(request.uri),
                 element.Status.fromResponseCode(
@@ -279,7 +295,6 @@ class DirectoryPrincipalPropertySearchMixIn(object):
             ))
         returnValue(MultiStatusResponse(responses))
 
-
     @inlineCallbacks
     def report_http___calendarserver_org_ns__calendarserver_principal_search(
         self, request,
@@ -301,7 +316,7 @@ class DirectoryPrincipalPropertySearchMixIn(object):
         # Only handle Depth: 0
         depth = request.headers.getHeader("depth", "0")
         if depth != "0":
-            log.error("Error in calendarserver-principal-search REPORT, Depth set to %s" % (depth,))
+            log.error("Error in calendarserver-principal-search REPORT, Depth set to {depth}", depth=depth)
             raise HTTPError(StatusResponse(responsecode.BAD_REQUEST, "Depth %s not allowed" % (depth,)))
 
         tokens, context, applyTo, clientLimit, propElement = extractCalendarServerPrincipalSearchData(calendarserver_principal_search)
@@ -339,7 +354,7 @@ class DirectoryPrincipalPropertySearchMixIn(object):
             tokens,
             context=context,
             limitResults=limitResults,
-            timeoutSeconds=10
+            timeoutSeconds=config.PrincipalSearchReportTimeout
         ))
 
         for record in records:
@@ -371,7 +386,7 @@ class DirectoryPrincipalPropertySearchMixIn(object):
 
         if resultsWereLimited is not None:
             if resultsWereLimited[0] == "server":
-                log.error("Too many matching resources in calendarserver-principal-search report")
+                log.debug("Too many matching resources in calendarserver-principal-search report")
             responses.append(element.StatusResponse(
                 element.HRef.fromString(request.uri),
                 element.Status.fromResponseCode(
@@ -386,7 +401,6 @@ class DirectoryPrincipalPropertySearchMixIn(object):
         returnValue(MultiStatusResponse(responses))
 
 
-
 class DirectoryElement(Element):
     """
     A L{DirectoryElement} is an L{Element} for rendering the contents of a
@@ -405,7 +419,6 @@ class DirectoryElement(Element):
         super(DirectoryElement, self).__init__()
         self.resource = resource
 
-
     @renderer
     def resourceDetail(self, request, tag):
         """
@@ -414,7 +427,6 @@ class DirectoryElement(Element):
         """
         return ''
 
-
     @renderer
     def children(self, request, tag):
         """
@@ -430,6 +442,7 @@ class DirectoryElement(Element):
                 .addCallback(lambda children: zip(children, names))
             )
         )
+
         @whenChildren.addCallback
         def gotChildren(children):
             for even, [child, name] in zip(cycle(["odd", "even"]), children):
@@ -443,7 +456,6 @@ class DirectoryElement(Element):
                 )
         return whenChildren
 
-
     @renderer
     def main(self, request, tag):
         """
@@ -451,13 +463,13 @@ class DirectoryElement(Element):
         """
         return tag.fillSlots(name=request.path)
 
-
     @renderer
     def properties(self, request, tag):
         """
         Renderer which yields all properties as table row tags.
         """
         whenPropertiesListed = self.resource.listProperties(request)
+
         @whenPropertiesListed.addCallback
         def gotProperties(qnames):
             accessDeniedValue = object()
@@ -466,9 +478,11 @@ class DirectoryElement(Element):
                 f.trap(HTTPError)
                 code = f.value.response.code
                 if code == responsecode.NOT_FOUND:
-                    log.error("Property {p} was returned by listProperties() "
-                              "but does not exist for resource {r}.",
-                              p=name, r=self.resource)
+                    log.error(
+                        "Property {name} was returned by listProperties() "
+                        "but does not exist for resource {rsrc!r}.",
+                        name=name, rsrc=self.resource
+                    )
                     return (name, None)
                 if code == responsecode.UNAUTHORIZED:
                     return (name, accessDeniedValue)
@@ -496,7 +510,6 @@ class DirectoryElement(Element):
         return whenPropertiesListed
 
 
-
 class DirectoryRenderingMixIn(object):
 
     def renderDirectory(self, request):
@@ -513,7 +526,6 @@ class DirectoryRenderingMixIn(object):
             return response
         return flattenString(request, self.htmlElement()).addCallback(gotBody)
 
-
     def htmlElement(self):
         """
         Create a L{DirectoryElement} or appropriate subclass for rendering this
@@ -521,7 +533,6 @@ class DirectoryRenderingMixIn(object):
         """
         return DirectoryElement(self)
 
-
     def getChildDirectoryEntry(self, child, name, request):
         def orNone(value, default="?", f=None):
             if value is None:
@@ -582,10 +593,13 @@ class DirectoryRenderingMixIn(object):
         )
 
 
-
-class DAVResource (DirectoryPrincipalPropertySearchMixIn,
-                   SuperDAVResource,
-                   DirectoryRenderingMixIn, StaticRenderMixin):
+class DAVResource (
+    WebDAVServerInfoMixIn,
+    DirectoryPrincipalPropertySearchMixIn,
+    SuperDAVResource,
+    DirectoryRenderingMixIn,
+    StaticRenderMixin
+):
     """
     Extended L{txweb2.dav.resource.DAVResource} implementation.
 
@@ -597,8 +611,7 @@ class DAVResource (DirectoryPrincipalPropertySearchMixIn,
     http_REPORT = http_REPORT
 
     def davComplianceClasses(self):
-        return ("1", "access-control") # Add "2" when we have locking
-
+        return ("1", "access-control")  # Add "2" when we have locking
 
     def render(self, request):
         if not self.exists():
@@ -608,19 +621,16 @@ class DAVResource (DirectoryPrincipalPropertySearchMixIn,
             return self.renderDirectory(request)
         return super(DAVResource, self).render(request)
 
-
     def resourceType(self):
         # Allow live property to be overridden by dead property
         if self.deadProperties().contains((dav_namespace, "resourcetype")):
             return self.deadProperties().get((dav_namespace, "resourcetype"))
         return element.ResourceType(element.Collection()) if self.isCollection() else element.ResourceType()
 
-
     def contentType(self):
         return MimeType("httpd", "unix-directory") if self.isCollection() else None
 
 
-
 class DAVResourceWithChildrenMixin (object):
     """
     Bits needed from txweb2.static
@@ -630,7 +640,6 @@ class DAVResourceWithChildrenMixin (object):
         self.putChildren = {}
         super(DAVResourceWithChildrenMixin, self).__init__(principalCollections=principalCollections)
 
-
     def putChild(self, name, child):
         """
         Register a child with the given name with this resource.
@@ -639,7 +648,6 @@ class DAVResourceWithChildrenMixin (object):
         """
         self.putChildren[name] = child
 
-
     def getChild(self, name):
         """
         Look up a child resource.  First check C{self.putChildren}, then call
@@ -655,7 +663,6 @@ class DAVResourceWithChildrenMixin (object):
             result = self.makeChild(name)
         return result
 
-
     def makeChild(self, name):
         """
         Called by L{DAVResourceWithChildrenMixin.getChild} to dynamically
@@ -663,21 +670,18 @@ class DAVResourceWithChildrenMixin (object):
         """
         return None
 
-
     def listChildren(self):
         """
         @return: a sequence of the names of all known children of this resource.
         """
         return self.putChildren.keys()
 
-
     def countChildren(self):
         """
         @return: the number of all known children of this resource.
         """
         return len(self.putChildren.keys())
 
-
     def locateChild(self, req, segments):
         """
         See L{IResource.locateChild}.
@@ -689,7 +693,6 @@ class DAVResourceWithChildrenMixin (object):
         )
 
 
-
 class DAVResourceWithoutChildrenMixin (object):
     """
     Bits needed from txweb2.static
@@ -699,22 +702,22 @@ class DAVResourceWithoutChildrenMixin (object):
         self.putChildren = {}
         super(DAVResourceWithChildrenMixin, self).__init__(principalCollections=principalCollections)
 
-
     def findChildren(
         self, depth, request, callback,
         privileges=None, inherited_aces=None
     ):
         return succeed(None)
 
-
     def locateChild(self, request, segments):
         return self, server.StopTraversal
 
 
-
-class DAVPrincipalResource (DirectoryPrincipalPropertySearchMixIn,
-                            SuperDAVPrincipalResource,
-                            DirectoryRenderingMixIn):
+class DAVPrincipalResource (
+    WebDAVServerInfoMixIn,
+    DirectoryPrincipalPropertySearchMixIn,
+    SuperDAVPrincipalResource,
+    DirectoryRenderingMixIn
+):
     """
     Extended L{txweb2.dav.static.DAVFile} implementation.
     """
@@ -737,7 +740,6 @@ class DAVPrincipalResource (DirectoryPrincipalPropertySearchMixIn,
             return self.renderDirectory(request)
         return super(DAVResource, self).render(request)
 
-
     @inlineCallbacks
     def readProperty(self, property, request):
         if type(property) is tuple:
@@ -783,23 +785,18 @@ class DAVPrincipalResource (DirectoryPrincipalPropertySearchMixIn,
         result = (yield super(DAVPrincipalResource, self).readProperty(property, request))
         returnValue(result)
 
-
     def groupMembers(self):
         return succeed(())
 
-
     def expandedGroupMembers(self):
         return succeed(())
 
-
     def groupMemberships(self):
         return succeed(())
 
-
     def expandedGroupMemberships(self):
         return succeed(())
 
-
     def resourceType(self):
         # Allow live property to be overridden by dead property
         if self.deadProperties().contains((dav_namespace, "resourcetype")):
@@ -810,8 +807,7 @@ class DAVPrincipalResource (DirectoryPrincipalPropertySearchMixIn,
             return element.ResourceType(element.Principal())
 
 
-
-class DAVFile (SuperDAVFile, DirectoryRenderingMixIn):
+class DAVFile (WebDAVServerInfoMixIn, SuperDAVFile, DirectoryRenderingMixIn):
     """
     Extended L{txweb2.dav.static.DAVFile} implementation.
     """
@@ -822,9 +818,8 @@ class DAVFile (SuperDAVFile, DirectoryRenderingMixIn):
         if self.deadProperties().contains((dav_namespace, "resourcetype")):
             return self.deadProperties().get((dav_namespace, "resourcetype"))
         if self.isCollection():
-            return element.ResourceType.collection #@UndefinedVariable
-        return element.ResourceType.empty #@UndefinedVariable
-
+            return element.ResourceType.collection  # @UndefinedVariable
+        return element.ResourceType.empty  # @UndefinedVariable
 
     def render(self, request):
         if not self.fp.exists():
@@ -866,7 +861,6 @@ class DAVFile (SuperDAVFile, DirectoryRenderingMixIn):
         return response
 
 
-
 class ReadOnlyWritePropertiesResourceMixIn (object):
     """
     Read only that will allow writing of properties resource.
@@ -884,7 +878,6 @@ class ReadOnlyWritePropertiesResourceMixIn (object):
     http_PUT = _forbidden
 
 
-
 class ReadOnlyResourceMixIn (ReadOnlyWritePropertiesResourceMixIn):
     """
     Read only resource.
@@ -894,7 +887,6 @@ class ReadOnlyResourceMixIn (ReadOnlyWritePropertiesResourceMixIn):
     def writeProperty(self, property, request):
         raise HTTPError(self.readOnlyResponse)
 
-
     def accessControlList(
         self, request, inheritance=True, expanding=False, inherited_aces=None
     ):
@@ -903,8 +895,8 @@ class ReadOnlyResourceMixIn (ReadOnlyWritePropertiesResourceMixIn):
         return self.defaultAccessControlList()
 
 
-
 class PropertyNotFoundError (HTTPError):
+
     def __init__(self, qname):
         HTTPError.__init__(
             self,
@@ -915,7 +907,6 @@ class PropertyNotFoundError (HTTPError):
         )
 
 
-
 class CachingPropertyStore (object):
     """
     DAV property store using a dict in memory on top of another
@@ -927,9 +918,8 @@ class CachingPropertyStore (object):
         self.propertyStore = propertyStore
         self.resource = propertyStore.resource
 
-
     def get(self, qname, uid=None):
-        # self.log.debug("Get: %r, %r" % (self.resource.fp.path, qname))
+        # self.log.debug("Get: {p}, {n}", p=self.resource.fp.path, n=qname)
 
         cache = self._cache()
 
@@ -938,7 +928,7 @@ class CachingPropertyStore (object):
         if cachedQname in cache:
             property = cache.get(cachedQname, None)
             if property is None:
-                self.log.debug("Cache miss: %r, %r, %r" % (self, self.resource.fp.path, qname))
+                self.log.debug("Cache miss: {s!r}, {p}, {n}", s=self, p=self.resource.fp.path, n=qname)
                 try:
                     property = self.propertyStore.get(qname, uid)
                 except HTTPError:
@@ -950,9 +940,8 @@ class CachingPropertyStore (object):
         else:
             raise PropertyNotFoundError(qname)
 
-
     def set(self, property, uid=None):
-        # self.log.debug("Set: %r, %r" % (self.resource.fp.path, property))
+        # self.log.debug("Set: {p}, {prop!r}", p=self.resource.fp.path, prop=property)
 
         cache = self._cache()
 
@@ -962,9 +951,8 @@ class CachingPropertyStore (object):
         self.propertyStore.set(property, uid)
         cache[cachedQname] = property
 
-
     def contains(self, qname, uid=None):
-        # self.log.debug("Contains: %r, %r" % (self.resource.fp.path, qname))
+        # self.log.debug("Contains: {p}, {n}", p=self.resource.fp.path, n=qname)
 
         cachedQname = qname + (uid,)
 
@@ -977,14 +965,13 @@ class CachingPropertyStore (object):
                 raise
 
         if cachedQname in cache:
-            # self.log.debug("Contains cache hit: %r, %r, %r" % (self, self.resource.fp.path, qname))
+            # self.log.debug("Contains cache hit: {s!r}, {p}, {n}", s=self, p=self.resource.fp.path, n=qname)
             return True
         else:
             return False
 
-
     def delete(self, qname, uid=None):
-        # self.log.debug("Delete: %r, %r" % (self.resource.fp.path, qname))
+        # self.log.debug("Delete: {p}, {n}", p=self.resource.fp.path, n=qname)
 
         cachedQname = qname + (uid,)
 
@@ -993,9 +980,8 @@ class CachingPropertyStore (object):
 
         self.propertyStore.delete(qname, uid)
 
-
     def list(self, uid=None, filterByUID=True):
-        # self.log.debug("List: %r" % (self.resource.fp.path,))
+        # self.log.debug("List: {p}", p=self.resource.fp.path)
         keys = self._cache().iterkeys()
         if filterByUID:
             return [
@@ -1006,10 +992,9 @@ class CachingPropertyStore (object):
         else:
             return keys
 
-
     def _cache(self):
         if not hasattr(self, "_data"):
-            # self.log.debug("Cache init: %r" % (self.resource.fp.path,))
+            # self.log.debug("Cache init: {p}", p=self.resource.fp.path)
             self._data = dict(
                 (name, None)
                 for name in self.propertyStore.list(filterByUID=False)
@@ -1017,7 +1002,6 @@ class CachingPropertyStore (object):
         return self._data
 
 
-
 def extractCalendarServerPrincipalSearchData(doc):
     """
     Extract relevant info from a CalendarServerPrincipalSearch document
@@ -1061,7 +1045,6 @@ def extractCalendarServerPrincipalSearchData(doc):
     return tokens, context, applyTo, clientLimit, propElement
 
 
-
 def validateTokens(tokens):
     """
     Make sure there is at least one token longer than one character
