@@ -1,6 +1,6 @@
 # -*- test-case-name: twistedcaldav.directory.test.test_calendar -*-
 ##
-# Copyright (c) 2005-2015 Apple Inc. All rights reserved.
+# Copyright (c) 2005-2017 Apple Inc. All rights reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -31,7 +31,7 @@ from twistedcaldav.config import config
 # following line is wrong because _schedulePrivilegeSet won't actually use the
 # config file, it will pick up stdconfig whenever it is imported, so this works
 # around that for now.
-__import__("twistedcaldav.stdconfig") # FIXME
+__import__("twistedcaldav.stdconfig")  # FIXME
 
 from txweb2 import responsecode
 from txweb2.dav.http import ErrorResponse, MultiStatusResponse
@@ -54,6 +54,7 @@ from txdav.caldav.icalendarstore import InvalidDefaultCalendar
 from txdav.xml import element as davxml
 from txdav.xml.rfc2518 import HRef
 
+
 def _schedulePrivilegeSet(deliver):
     edited = False
 
@@ -91,6 +92,7 @@ def _schedulePrivilegeSet(deliver):
 deliverSchedulePrivilegeSet = _schedulePrivilegeSet(True)
 sendSchedulePrivilegeSet = _schedulePrivilegeSet(False)
 
+
 class CalendarSchedulingCollectionResource (CalDAVResource):
     """
     CalDAV principal resource.
@@ -98,6 +100,7 @@ class CalendarSchedulingCollectionResource (CalDAVResource):
     Extends L{DAVResource} to provide CalDAV scheduling collection
     functionality.
     """
+
     def __init__(self, parent):
         """
         @param parent: the parent resource of this one.
@@ -108,19 +111,15 @@ class CalendarSchedulingCollectionResource (CalDAVResource):
 
         self.parent = parent
 
-
     def isCollection(self):
         return True
 
-
     def isCalendarCollection(self):
         return False
 
-
     def isPseudoCalendarCollection(self):
         return True
 
-
     def supportedReports(self):
         result = super(CalDAVResource, self).supportedReports()
         result.append(davxml.Report(caldavxml.CalendarQuery(),))
@@ -132,7 +131,6 @@ class CalendarSchedulingCollectionResource (CalDAVResource):
         return result
 
 
-
 class ScheduleInboxResource (CalendarSchedulingCollectionResource):
     """
     CalDAV schedule Inbox resource.
@@ -148,17 +146,14 @@ class ScheduleInboxResource (CalendarSchedulingCollectionResource):
             customxml.ScheduleDefaultTasksURL.qname(),
         )
 
-
     def dynamicProperties(self):
         return super(ScheduleInboxResource, self).dynamicProperties() + (
             customxml.CalendarAvailability.qname(),
         )
 
-
     def resourceType(self):
         return davxml.ResourceType.scheduleInbox
 
-
     def hasProperty(self, property, request):
         """
         Need to special case calendar-free-busy-set for backwards compatibility.
@@ -179,7 +174,6 @@ class ScheduleInboxResource (CalendarSchedulingCollectionResource):
         else:
             return super(ScheduleInboxResource, self).hasProperty(property, request)
 
-
     @inlineCallbacks
     def readProperty(self, property, request):
         if type(property) is tuple:
@@ -207,7 +201,6 @@ class ScheduleInboxResource (CalendarSchedulingCollectionResource):
         result = (yield super(ScheduleInboxResource, self).readProperty(property, request))
         returnValue(result)
 
-
     @inlineCallbacks
     def writeProperty(self, property, request):
         assert isinstance(property, davxml.WebDAVElement)
@@ -266,7 +259,6 @@ class ScheduleInboxResource (CalendarSchedulingCollectionResource):
 
         yield super(ScheduleInboxResource, self).writeProperty(property, request)
 
-
     @inlineCallbacks
     def removeProperty(self, property, request):
         if type(property) is tuple:
@@ -281,7 +273,6 @@ class ScheduleInboxResource (CalendarSchedulingCollectionResource):
         result = (yield super(ScheduleInboxResource, self).removeProperty(property, request))
         returnValue(result)
 
-
     @inlineCallbacks
     def readDefaultCalendarProperty(self, request, qname):
         """
@@ -300,7 +291,6 @@ class ScheduleInboxResource (CalendarSchedulingCollectionResource):
             defaultURL = joinURL(self.parent.url(), default.name())
             returnValue(prop_to_set(davxml.HRef(defaultURL)))
 
-
     @inlineCallbacks
     def writeDefaultCalendarProperty(self, request, property):
         """
@@ -345,7 +335,6 @@ class ScheduleInboxResource (CalendarSchedulingCollectionResource):
                 str(e),
             ))
 
-
     @inlineCallbacks
     def defaultCalendar(self, request, componentType):
         """
@@ -362,7 +351,6 @@ class ScheduleInboxResource (CalendarSchedulingCollectionResource):
 
         returnValue(default)
 
-
     ##
     # ACL
     ##
@@ -370,7 +358,6 @@ class ScheduleInboxResource (CalendarSchedulingCollectionResource):
     def supportedPrivileges(self, request):
         return succeed(deliverSchedulePrivilegeSet)
 
-
     def defaultAccessControlList(self):
 
         privs = (
@@ -390,7 +377,6 @@ class ScheduleInboxResource (CalendarSchedulingCollectionResource):
         )
 
 
-
 class ScheduleOutboxResource (CalendarSchedulingCollectionResource):
     """
     CalDAV schedule Outbox resource.
@@ -401,13 +387,11 @@ class ScheduleOutboxResource (CalendarSchedulingCollectionResource):
     def resourceType(self):
         return davxml.ResourceType.scheduleOutbox
 
-
     def getSupportedComponentSet(self):
         return caldavxml.SupportedCalendarComponentSet(
             *[caldavxml.CalendarComponent(name=item) for item in allowedSchedulingComponents]
         )
 
-
     @inlineCallbacks
     def http_POST(self, request):
         """
@@ -436,7 +420,6 @@ class ScheduleOutboxResource (CalendarSchedulingCollectionResource):
         result = (yield scheduler.doSchedulingViaPOST(originator, recipients, calendar))
         returnValue(result.response(format=format))
 
-
     def determineType(self, content_type):
         """
         Determine if the supplied content-type is valid for storing and return the matching PyCalendar type.
@@ -446,14 +429,13 @@ class ScheduleOutboxResource (CalendarSchedulingCollectionResource):
             format = "%s/%s" % (content_type.mediaType, content_type.mediaSubtype,)
         return format if format in Component.allowedTypes() else None
 
-
     @inlineCallbacks
     def loadCalendarFromRequest(self, request):
         # Must be content-type text/calendar
         contentType = request.headers.getHeader("content-type")
         format = self.determineType(contentType)
         if format is None:
-            self.log.error("MIME type %s not allowed in calendar collection" % (contentType,))
+            self.log.error("MIME type {t} not allowed in calendar collection", t=contentType)
             raise HTTPError(ErrorResponse(
                 responsecode.FORBIDDEN,
                 (caldav_namespace, "supported-calendar-data"),
@@ -465,7 +447,7 @@ class ScheduleOutboxResource (CalendarSchedulingCollectionResource):
             calendar = (yield Component.fromIStream(request.stream, format=format))
         except:
             # FIXME: Bare except
-            self.log.error("Error while handling POST: %s" % (Failure(),))
+            self.log.error("Error while handling POST: {f}", f=Failure())
             raise HTTPError(ErrorResponse(
                 responsecode.FORBIDDEN,
                 (caldav_namespace, "valid-calendar-data"),
@@ -474,7 +456,6 @@ class ScheduleOutboxResource (CalendarSchedulingCollectionResource):
 
         returnValue((calendar, format,))
 
-
     @inlineCallbacks
     def loadOriginatorFromRequestDetails(self, request):
         # The originator is the owner of the Outbox. We will have checked prior to this
@@ -486,7 +467,7 @@ class ScheduleOutboxResource (CalendarSchedulingCollectionResource):
             originator = originatorPrincipal.canonicalCalendarUserAddress()
 
         if not originator:
-            self.log.error("%s request must have Originator" % (self.method,))
+            self.log.error("{m} request must have Originator", m=self.method)
             raise HTTPError(ErrorResponse(
                 responsecode.FORBIDDEN,
                 (caldav_namespace, "originator-specified"),
@@ -495,7 +476,6 @@ class ScheduleOutboxResource (CalendarSchedulingCollectionResource):
         else:
             returnValue(originator)
 
-
     def loadRecipientsFromCalendarData(self, calendar):
 
         # Get the ATTENDEEs
@@ -516,7 +496,6 @@ class ScheduleOutboxResource (CalendarSchedulingCollectionResource):
         else:
             return(list(attendees))
 
-
     ##
     # ACL
     ##
@@ -524,7 +503,6 @@ class ScheduleOutboxResource (CalendarSchedulingCollectionResource):
     def supportedPrivileges(self, request):
         return succeed(sendSchedulePrivilegeSet)
 
-
     @inlineCallbacks
     def defaultAccessControlList(self):
         if config.EnableProxyPrincipals:
@@ -550,11 +528,9 @@ class ScheduleOutboxResource (CalendarSchedulingCollectionResource):
             result = yield super(ScheduleOutboxResource, self).defaultAccessControlList()
             returnValue(result)
 
-
     def report_urn_ietf_params_xml_ns_caldav_calendar_query(self, request, calendar_query):
         return succeed(MultiStatusResponse(()))
 
-
     def report_urn_ietf_params_xml_ns_caldav_calendar_multiget(self, request, multiget):
         responses = [davxml.StatusResponse(href, davxml.Status.fromResponseCode(responsecode.NOT_FOUND)) for href in multiget.resources]
         return succeed(MultiStatusResponse((responses)))
