@@ -1,5 +1,5 @@
 ##
-# Copyright (c) 2005-2015 Apple Inc. All rights reserved.
+# Copyright (c) 2005-2017 Apple Inc. All rights reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -63,25 +63,21 @@ class AbstractSQLDatabase (object):
         self.persistent = persistent
         self.autocommit = autocommit
 
-
     def __repr__(self):
         return "<%s %r>" % (self.__class__.__name__, self.dbpath)
 
-
     def _db_version(self):
         """
         @return: the schema version assigned to this index.
         """
         raise NotImplementedError
 
-
     def _db_type(self):
         """
         @return: the collection type assigned to this index.
         """
         raise NotImplementedError
 
-
     def _db(self):
         """
         Access the underlying database.
@@ -124,16 +120,20 @@ class AbstractSQLDatabase (object):
                         del(self._db_connection)
 
                         if dbtype != self._db_type():
-                            log.error("Database %s has different type (%s vs. %s)"
-                                      % (db_filename, dbtype, self._db_type()))
+                            log.error(
+                                "Database {f} has different type ({t1} vs. {t2})",
+                                f=db_filename, t1=dbtype, t2=self._db_type(),
+                            )
 
                             # Delete this index and start over
                             os.remove(db_filename)
                             return self._db()
 
                         if version != self._db_version():
-                            log.error("Database %s has different schema (v.%s vs. v.%s)"
-                                      % (db_filename, version, self._db_version()))
+                            log.error(
+                                "Database {f} has different schema (v.{v1} vs. v.{v2})",
+                                f=db_filename, v1=version, v2=self._db_version(),
+                            )
 
                             # Upgrade the DB
                             return self._db_upgrade(version)
@@ -147,7 +147,6 @@ class AbstractSQLDatabase (object):
                     q.close()
         return self._db_connection
 
-
     def _test_schema_table(self, q):
         q.execute("""
         select (1) from SQLITE_MASTER
@@ -155,7 +154,6 @@ class AbstractSQLDatabase (object):
         """)
         return q.fetchone()
 
-
     def _get_schema_version(self, q):
         q.execute(
             """
@@ -179,37 +177,35 @@ class AbstractSQLDatabase (object):
 
         return version, dbtype
 
-
     def _db_init(self, db_filename, q):
         """
         Initialise the underlying database tables.
         @param db_filename: the file name of the index database.
         @param q:           a database cursor to use.
         """
-        log.info("Initializing database %s" % (db_filename,))
+        log.info("Initializing database {f}", f=db_filename)
 
         # We need an exclusive lock here as we are making a big change to the database and we don't
         # want other processes to get stomped on or stomp on us.
         old_isolation = self._db_connection.isolation_level
         self._db_connection.isolation_level = None
-        q.execute("begin exclusive transaction")
-
-        # We re-check whether the schema table is present again AFTER we've got an exclusive
-        # lock as some other server process may have snuck in and already created it
-        # before we got the lock, or whilst we were waiting for it.
-        if not self._test_schema_table(q):
-            self._db_init_schema_table(q)
-            self._db_init_data_tables(q)
-            self._db_recreate(False)
-
         try:
+            q.execute("begin exclusive transaction")
+
+            # We re-check whether the schema table is present again AFTER we've got an exclusive
+            # lock as some other server process may have snuck in and already created it
+            # before we got the lock, or whilst we were waiting for it.
+            if not self._test_schema_table(q):
+                self._db_init_schema_table(q)
+                self._db_init_data_tables(q)
+                self._db_recreate(False)
+
             q.execute("commit")
         except DatabaseError:
             pass
 
         self._db_connection.isolation_level = old_isolation
 
-
     def _db_init_schema_table(self, q):
         """
         Initialise the underlying database tables.
@@ -240,7 +236,6 @@ class AbstractSQLDatabase (object):
             """, [self._db_type()]
         )
 
-
     def _db_init_data_tables(self, q):
         """
         Initialise the underlying database tables.
@@ -249,7 +244,6 @@ class AbstractSQLDatabase (object):
         """
         raise NotImplementedError
 
-
     def _db_recreate(self, do_commit=True):
         """
         Recreate the database tables.
@@ -259,12 +253,10 @@ class AbstractSQLDatabase (object):
         if do_commit:
             self._db_commit()
 
-
     def _db_can_upgrade(self, old_version):
 
         return self.persistent
 
-
     def _db_upgrade(self, old_version):
         """
         Upgrade the database tables.
@@ -293,7 +285,6 @@ class AbstractSQLDatabase (object):
 
         return self._db()
 
-
     def _db_upgrade_data_tables(self, q, old_version):
         """
         Upgrade the data from an older version of the DB.
@@ -302,7 +293,6 @@ class AbstractSQLDatabase (object):
         # cannot be thrown away.
         raise NotImplementedError("Persistent databases MUST support an upgrade method.")
 
-
     def _db_upgrade_schema(self, q):
         """
         Upgrade the stored schema version to the current one.
@@ -314,13 +304,11 @@ class AbstractSQLDatabase (object):
             """, [self._db_version()]
         )
 
-
     def _db_close(self):
         if hasattr(self, "_db_connection"):
             self._db_connection.close()
             del self._db_connection
 
-
     def _db_values_for_sql(self, sql, *query_params):
         """
         Execute an SQL query and obtain the resulting values.
@@ -332,7 +320,6 @@ class AbstractSQLDatabase (object):
         """
         return (row[0] for row in self._db_execute(sql, *query_params))
 
-
     def _db_value_for_sql(self, sql, *query_params):
         """
         Execute an SQL query and obtain a single value.
@@ -348,7 +335,6 @@ class AbstractSQLDatabase (object):
             value = row
         return value
 
-
     def _db_execute(self, sql, *query_params):
         """
         Execute an SQL query and obtain the resulting values.
@@ -363,15 +349,13 @@ class AbstractSQLDatabase (object):
             self.lastrowid = q.lastrowid
             return q.fetchall()
         except DatabaseError:
-            log.error("Exception while executing SQL on DB %s: %r %r" % (self, sql, query_params))
+            log.error("Exception while executing SQL on DB {s!r}: {q!r} {p!r}", s=self, q=sql, p=query_params)
             raise
         finally:
             q.close()
 
-
     def _db_commit(self):
         self._db_connection.commit()
 
-
     def _db_rollback(self):
         self._db_connection.rollback()
