@@ -1,5 +1,5 @@
 ##
-# Copyright (c) 2005-2015 Apple Inc. All rights reserved.
+# Copyright (c) 2005-2017 Apple Inc. All rights reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -67,7 +67,6 @@ def addEventsDir(testCase, eventsDir, uri):
     returnValue(count)
 
 
-
 class CalendarQuery (StoreTestCase):
     """
     calendar-query REPORT
@@ -85,11 +84,11 @@ class CalendarQuery (StoreTestCase):
         calendar = yield self.calendarUnderTest(name="calendar", home=record.uid)
         for f in os.listdir(self.holidays_dir):
             if f.endswith(".ics"):
-                component = Component.fromString(open(os.path.join(self.holidays_dir, f)).read())
+                with open(os.path.join(self.holidays_dir, f)) as fin:
+                    component = Component.fromString(fin.read())
                 yield calendar._createCalendarObjectWithNameInternal(f, component, internal_state=ComponentUpdateState.RAW)
         yield self.commit()
 
-
     def test_calendar_query_time_range(self):
         """
         Partial retrieval of events by time range.
@@ -174,7 +173,6 @@ class CalendarQuery (StoreTestCase):
 
         return self.calendar_query(query, got_xml)
 
-
     def test_calendar_query_timezone(self):
         """
         Partial retrieval of events by time range.
@@ -216,7 +214,6 @@ class CalendarQuery (StoreTestCase):
 
         return self.calendar_query(query, got_xml)
 
-
     def test_calendar_query_timezone_id(self):
         """
         Partial retrieval of events by time range.
@@ -257,7 +254,6 @@ class CalendarQuery (StoreTestCase):
 
         return self.calendar_query(query, got_xml)
 
-
     @inlineCallbacks
     def test_calendar_query_bogus_timezone_id(self):
         """
@@ -294,7 +290,6 @@ class CalendarQuery (StoreTestCase):
         result = yield self.calendar_query(query, got_xml=None, expected_code=responsecode.FORBIDDEN)
         self.assertTrue("valid-timezone" in result)
 
-
     @inlineCallbacks
     def test_calendar_query_wrong_timezone_elements(self):
         """
@@ -335,7 +330,6 @@ class CalendarQuery (StoreTestCase):
         result = yield self.calendar_query(query, got_xml=None, expected_code=responsecode.BAD_REQUEST)
         self.assertTrue("Only one of" in result)
 
-
     def test_calendar_query_partial_recurring(self):
         """
         Partial retrieval of recurring events.
@@ -343,7 +337,6 @@ class CalendarQuery (StoreTestCase):
         """
         raise SkipTest("test unimplemented")
 
-
     def test_calendar_query_expanded_recurring(self):
         """
         Expanded retrieval of recurring events.
@@ -351,7 +344,6 @@ class CalendarQuery (StoreTestCase):
         """
         raise SkipTest("test unimplemented")
 
-
     def test_calendar_query_partial_freebusy(self):
         """
         Partial retrieval of stored free busy components.
@@ -359,7 +351,6 @@ class CalendarQuery (StoreTestCase):
         """
         raise SkipTest("test unimplemented")
 
-
     def test_calendar_query_todo_alarm(self):
         """
         Retrieval of to-dos by alarm time range.
@@ -367,7 +358,6 @@ class CalendarQuery (StoreTestCase):
         """
         raise SkipTest("test unimplemented")
 
-
     def test_calendar_query_by_uid(self):
         """
         Event by UID.
@@ -383,7 +373,6 @@ class CalendarQuery (StoreTestCase):
             [uid]
         )
 
-
     def test_calendar_query_partstat(self):
         """
         Retrieval of events by participation status.
@@ -391,18 +380,16 @@ class CalendarQuery (StoreTestCase):
         """
         raise SkipTest("test unimplemented")
 
-
     def test_calendar_query_all_events(self):
         """
         All events.
         (CalDAV-access-09, section 7.6.8)
         """
         uids = [r[0] for r in (os.path.splitext(f) for f in
-                os.listdir(self.holidays_dir)) if r[1] == ".ics"]
+                               os.listdir(self.holidays_dir)) if r[1] == ".ics"]
 
         return self.simple_event_query(None, uids)
 
-
     def test_calendar_query_limited_with_data(self):
         """
         All events.
@@ -423,7 +410,6 @@ class CalendarQuery (StoreTestCase):
         d.addCallbacks(_restoreValueOK, _restoreValueError)
         return d
 
-
     def test_calendar_query_limited_without_data(self):
         """
         All events.
@@ -441,7 +427,6 @@ class CalendarQuery (StoreTestCase):
         d.addErrback(_restoreValueError)
         return d
 
-
     def simple_event_query(self, event_filter, uids, withData=True):
         props = (
             davxml.GETETag(),
@@ -503,7 +488,6 @@ class CalendarQuery (StoreTestCase):
 
         return self.calendar_query(query, got_xml)
 
-
     @inlineCallbacks
     def calendar_query(self, query, got_xml, expected_code=responsecode.MULTI_STATUS):
 
