@@ -1,5 +1,5 @@
 ##
-# Copyright (c) 2005-2015 Apple Inc. All rights reserved.
+# Copyright (c) 2005-2017 Apple Inc. All rights reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -19,6 +19,7 @@ from cStringIO import StringIO
 from twistedcaldav.xmlutil import readXML, writeXML, addSubElement, \
     changeSubElementText, createElement, elementToXML, readXMLString
 
+
 class XMLUtil(twistedcaldav.test.util.TestCase):
     """
     XML Util tests
@@ -85,10 +86,10 @@ class XMLUtil(twistedcaldav.test.util.TestCase):
     def _checkXML(self, node, data):
         xmlfile = self.mktemp()
         writeXML(xmlfile, node)
-        newdata = open(xmlfile).read()
+        with open(xmlfile) as f:
+            newdata = f.read()
         self.assertEqual(newdata, data)
 
-
     def test_readXML_noverify(self):
 
         io = StringIO(XMLUtil.data1)
@@ -96,7 +97,6 @@ class XMLUtil(twistedcaldav.test.util.TestCase):
         self.assertEqual(etree.getroot(), root)
         self.assertEqual(root.tag, "test")
 
-
     def test_readXML_verify_ok(self):
 
         io = StringIO(XMLUtil.data1)
@@ -104,26 +104,22 @@ class XMLUtil(twistedcaldav.test.util.TestCase):
         self.assertEqual(etree.getroot(), root)
         self.assertEqual(root.tag, "test")
 
-
     def test_readXML_verify_bad(self):
 
         io = StringIO(XMLUtil.data1)
         self.assertRaises(ValueError, readXML, io, "test1")
 
-
     def test_readXML_data_bad(self):
 
         io = StringIO(XMLUtil.data2)
         self.assertRaises(ValueError, readXML, io)
 
-
     def test_writeXML(self):
 
         io = StringIO(XMLUtil.data1)
         _ignore_etree, root = readXML(io)
         self._checkXML(root, XMLUtil.data3)
 
-
     def test_addElement(self):
 
         io = StringIO(XMLUtil.data1)
@@ -131,7 +127,6 @@ class XMLUtil(twistedcaldav.test.util.TestCase):
         addSubElement(root, "added", "added text")
         self._checkXML(root, XMLUtil.data4)
 
-
     def test_changeElement_existing(self):
 
         io = StringIO(XMLUtil.data1)
@@ -139,7 +134,6 @@ class XMLUtil(twistedcaldav.test.util.TestCase):
         changeSubElementText(root, "help", "changed text")
         self._checkXML(root, XMLUtil.data5)
 
-
     def test_changeElement_new(self):
 
         io = StringIO(XMLUtil.data1)
@@ -147,7 +141,6 @@ class XMLUtil(twistedcaldav.test.util.TestCase):
         changeSubElementText(root, "new", "new text")
         self._checkXML(root, XMLUtil.data6)
 
-
     def test_emoji(self):
         """
         Verify we can serialize and parse unicode values above 0xFFFF
