@@ -1,6 +1,6 @@
 # -*- test-case-name: txdav.base.datastore.test.test_subpostgres -*-
 # #
-# Copyright (c) 2010-2015 Apple Inc. All rights reserved.
+# Copyright (c) 2010-2017 Apple Inc. All rights reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -49,7 +49,6 @@ log = Logger()
 _MAGIC_READY_COOKIE = "database system is ready to accept connections"
 
 
-
 class PostgresMonitor(ProcessProtocol):
     """
     A monitoring protocol which watches the postgres subprocess.
@@ -64,7 +63,6 @@ class PostgresMonitor(ProcessProtocol):
         self.isReady = False
         self.completionDeferred = Deferred()
 
-
     def lineReceived(self, line):
         if self.svc is None:
             return
@@ -74,25 +72,21 @@ class PostgresMonitor(ProcessProtocol):
 
     disconnecting = False
 
-
     def connectionMade(self):
         self.lineReceiver.makeConnection(self)
 
-
     def outReceived(self, out):
         for line in out.split("\n"):
             if line:
-                self.log.info("{message}", message=line)
+                self.log.info("{msg}", msg=line)
         # self.lineReceiver.dataReceived(out)
 
-
     def errReceived(self, err):
         for line in err.split("\n"):
             if line:
-                self.log.error("{message}", message=line)
+                self.log.error("{msg}", msg=line)
         self.lineReceiver.dataReceived(err)
 
-
     def processEnded(self, reason):
         self.log.info(
             "pg_ctl process ended with status={status}",
@@ -109,7 +103,6 @@ class PostgresMonitor(ProcessProtocol):
             self.completionDeferred.errback(reason)
 
 
-
 class ErrorOutput(Exception):
     """
     The process produced some error output and exited with a non-zero exit
@@ -117,7 +110,6 @@ class ErrorOutput(Exception):
     """
 
 
-
 class CapturingProcessProtocol(ProcessProtocol):
     """
     A L{ProcessProtocol} that captures its output and error.
@@ -140,7 +132,6 @@ class CapturingProcessProtocol(ProcessProtocol):
         self.output = []
         self.error = []
 
-
     def connectionMade(self):
         """
         The process started; feed its input on stdin.
@@ -149,21 +140,18 @@ class CapturingProcessProtocol(ProcessProtocol):
             self.transport.write(self.input)
             self.transport.closeStdin()
 
-
     def outReceived(self, data):
         """
         Some output was received on stdout.
         """
         self.output.append(data)
 
-
     def errReceived(self, data):
         """
         Some output was received on stderr.
         """
         self.output.append(data)
 
-
     def processEnded(self, why):
         """
         The process is over, fire the Deferred with the output.
@@ -171,7 +159,6 @@ class CapturingProcessProtocol(ProcessProtocol):
         self.deferred.callback("".join(self.output))
 
 
-
 class PostgresService(MultiService):
 
     def __init__(
@@ -182,8 +169,11 @@ class PostgresService(MultiService):
         logDirectory="",
         socketDir="",
         socketName="",
-        listenAddresses=[], sharedBuffers=30,
-        maxConnections=20, options=[],
+        listenAddresses=[],
+        txnTimeoutSeconds=30,
+        sharedBuffers=30,
+        maxConnections=20,
+        options=[],
         testMode=False,
         uid=None, gid=None,
         spawnedDBUser="caldav",
@@ -259,8 +249,10 @@ class PostgresService(MultiService):
             self.port = None
             self.listenAddresses = []
 
+        self.txnTimeoutSeconds = txnTimeoutSeconds
+
         self.testMode = testMode
-        self.sharedBuffers = sharedBuffers if not testMode else 16
+        self.sharedBuffers = max(sharedBuffers if not testMode else 16, 16)
         self.maxConnections = maxConnections if not testMode else 8
         self.options = options
 
@@ -293,7 +285,6 @@ class PostgresService(MultiService):
         self._reactor = reactor
         self._postgresPid = None
 
-
     @property
     def reactor(self):
         if self._reactor is None:
@@ -301,7 +292,6 @@ class PostgresService(MultiService):
             self._reactor = reactor
         return self._reactor
 
-
     def activateDelayedShutdown(self):
         """
         Call this when starting database initialization code to
@@ -313,7 +303,6 @@ class PostgresService(MultiService):
         """
         self.delayedShutdown = True
 
-
     def deactivateDelayedShutdown(self):
         """
         Call this when database initialization code has completed so that the
@@ -323,7 +312,6 @@ class PostgresService(MultiService):
         if self.shutdownDeferred:
             self.shutdownDeferred.callback(None)
 
-
     def _connectorFor(self, databaseName=None):
         if databaseName is None:
             databaseName = self.databaseName
@@ -342,37 +330,15 @@ class PostgresService(MultiService):
             kwargs["user"] = self.spawnedDBUser
         elif self.uid is not None:
             kwargs["user"] = pwd.getpwuid(self.uid).pw_name
+        kwargs["txnTimeoutSeconds"] = self.txnTimeoutSeconds
 
         return DBAPIConnector.connectorFor("postgres", **kwargs)
 
-
     def produceConnection(self, label="<unlabeled>", databaseName=None):
         """
         Produce a DB-API 2.0 connection pointed at this database.
         """
-        connection = self._connectorFor(databaseName).connect(label)
-
-        if postgres.__name__ == "pg8000":
-            # Patch pg8000 behavior to match what we need wrt text processing
-
-            def my_text_out(v):
-                return v.encode("utf-8") if isinstance(v, unicode) else str(v)
-            connection.realConnection.py_types[str] = (705, postgres.core.FC_TEXT, my_text_out)
-            connection.realConnection.py_types[postgres.six.text_type] = (705, postgres.core.FC_TEXT, my_text_out)
-
-            def my_text_recv(data, offset, length):
-                return str(data[offset: offset + length])
-            connection.realConnection.default_factory = lambda: (postgres.core.FC_TEXT, my_text_recv)
-            connection.realConnection.pg_types[19] = (postgres.core.FC_BINARY, my_text_recv)
-            connection.realConnection.pg_types[25] = (postgres.core.FC_BINARY, my_text_recv)
-            connection.realConnection.pg_types[705] = (postgres.core.FC_BINARY, my_text_recv)
-            connection.realConnection.pg_types[829] = (postgres.core.FC_TEXT, my_text_recv)
-            connection.realConnection.pg_types[1042] = (postgres.core.FC_BINARY, my_text_recv)
-            connection.realConnection.pg_types[1043] = (postgres.core.FC_BINARY, my_text_recv)
-            connection.realConnection.pg_types[2275] = (postgres.core.FC_BINARY, my_text_recv)
-
-        return connection
-
+        return self._connectorFor(databaseName).connect(label)
 
     def ready(self, createDatabaseConn, createDatabaseCursor):
         """
@@ -418,7 +384,6 @@ class PostgresService(MultiService):
                 self.produceConnection, self
             ).setServiceParent(self)
 
-
     def pauseMonitor(self):
         """
         Pause monitoring.  This is a testing hook for when (if) we are
@@ -429,7 +394,6 @@ class PostgresService(MultiService):
 #            pipe.stopWriting()
         pass
 
-
     def unpauseMonitor(self):
         """
         Unpause monitoring.
@@ -441,7 +405,6 @@ class PostgresService(MultiService):
 #            pipe.startWriting()
         pass
 
-
     def startDatabase(self):
         """
         Start the database and initialize the subservice.
@@ -648,7 +611,6 @@ class PostgresService(MultiService):
             log.info("Cluster already exists at {dir}", dir=clusterDir.path.decode("utf-8"))
             self.startDatabase()
 
-
     def stopService(self):
         """
         Stop all child services, then stop the subprocess, if it's running.
@@ -702,7 +664,6 @@ class PostgresService(MultiService):
                     return monitor.completionDeferred
         return d.addCallback(superStopped)
 
-
     def hardStop(self):
         """
         Stop postgres quickly by sending it SIGQUIT
