@@ -1,6 +1,6 @@
 # -*- test-case-name: txdav.base.propertystore.test.test_xattr -*-
 ##
-# Copyright (c) 2010-2015 Apple Inc. All rights reserved.
+# Copyright (c) 2010-2017 Apple Inc. All rights reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -47,13 +47,12 @@ from txdav.idav import PropertyStoreError
 # expose.  Its value is 93.
 #
 
-if sys.platform in ("darwin", "freebsd8", "freebsd9"):
+if sys.platform == "darwin" or sys.platform[:7] == "freebsd":
     _ERRNO_NO_ATTR = getattr(errno, "ENOATTR", 93)
 else:
     _ERRNO_NO_ATTR = errno.ENODATA
 
 
-
 class PropertyStore(AbstractPropertyStore):
     """
     Property store using filesystem extended attributes.
@@ -98,21 +97,17 @@ class PropertyStore(AbstractPropertyStore):
         self.removed = set()
         self.modified = {}
 
-
     @property
     def path(self):
         return self._pathFactory()
 
-
     @property
     def attrs(self):
         return xattr(self.path.path)
 
-
     def __str__(self):
         return "<%s %s>" % (self.__class__.__name__, self.path.path)
 
-
     def _encodeKey(self, effective, compressNamespace=True):
 
         qname, uid = effective
@@ -127,7 +122,6 @@ class PropertyStore(AbstractPropertyStore):
         r = self.deadPropertyXattrPrefix + result
         return r
 
-
     def _decodeKey(self, name):
 
         name = urllib.unquote(name[len(self.deadPropertyXattrPrefix):])
@@ -147,7 +141,6 @@ class PropertyStore(AbstractPropertyStore):
 
         return PropertyName(propnamespace, propname), uid
 
-
     #
     # Required implementations
     #
@@ -232,7 +225,6 @@ class PropertyStore(AbstractPropertyStore):
 
         return doc.root_element
 
-
     def _setitem_uid(self, key, value, uid):
         validKey(key)
         effectiveKey = (key, uid)
@@ -241,7 +233,6 @@ class PropertyStore(AbstractPropertyStore):
             self.removed.remove(effectiveKey)
         self.modified[effectiveKey] = value
 
-
     def _delitem_uid(self, key, uid):
         validKey(key)
         effectiveKey = (key, uid)
@@ -253,7 +244,6 @@ class PropertyStore(AbstractPropertyStore):
 
         self.removed.add(effectiveKey)
 
-
     def _keys_uid(self, uid):
         seen = set()
 
@@ -276,14 +266,12 @@ class PropertyStore(AbstractPropertyStore):
             if effectivekey[1] == uid and effectivekey not in seen:
                 yield effectivekey[0]
 
-
     def _removeResource(self):
         # xattrs are removed when the underlying file is deleted so just clear
         # out cached changes
         self.removed.clear()
         self.modified.clear()
 
-
     #
     # I/O
     #
@@ -321,12 +309,10 @@ class PropertyStore(AbstractPropertyStore):
         self.removed.clear()
         self.modified.clear()
 
-
     def abort(self):
         self.removed.clear()
         self.modified.clear()
 
-
     def copyAllProperties(self, other):
         """
         Copy all the properties from another store into this one. This needs to be done
