@@ -1,5 +1,5 @@
 ##
-# Copyright (c) 2006-2015 Apple Inc. All rights reserved.
+# Copyright (c) 2006-2017 Apple Inc. All rights reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -33,7 +33,6 @@ __all__ = [
 log = Logger()
 
 
-
 class IScheduleServers(object):
 
     _fileInfo = None
@@ -46,7 +45,6 @@ class IScheduleServers(object):
         if IScheduleServers._servers is None:
             self._loadConfig()
 
-
     def _loadConfig(self):
         if config.Scheduling.iSchedule.RemoteServers:
             if IScheduleServers._servers is None:
@@ -72,14 +70,12 @@ class IScheduleServers(object):
             IScheduleServers._servers = ()
             IScheduleServers._domainMap = {}
 
-
     def _mapDomains(self):
         IScheduleServers._domainMap = {}
         for server in IScheduleServers._servers:
             for domain in server.domains:
                 IScheduleServers._domainMap[domain] = server
 
-
     def mapDomain(self, domain):
         """
         Map a calendar user address domain to a suitable server that can
@@ -103,15 +99,14 @@ ELEMENT_CLIENT_HOSTS = "hosts"
 ELEMENT_HOST = "host"
 
 
-
 class IScheduleServersParser(object):
     """
     Server-to-server configuration file parser.
     """
+
     def __repr__(self):
         return "<{} {}>".format(self.__class__.__name__, self.xmlFile)
 
-
     def __init__(self, xmlFile):
 
         self.servers = []
@@ -120,7 +115,6 @@ class IScheduleServersParser(object):
         _ignore_etree, servers_node = xmlutil.readXML(xmlFile.path, ELEMENT_SERVERS)
         self._parseXML(servers_node)
 
-
     def _parseXML(self, node):
         """
         Parse the XML root node from the server-to-server configuration document.
@@ -133,12 +127,12 @@ class IScheduleServersParser(object):
                 self.servers[-1].parseXML(child)
 
 
-
 class IScheduleServerRecord (object):
     """
     Contains server-to-server details.
     """
-    def __init__(self, uri=None, unNormalizeAddresses=True, moreHeaders=[], podding=False):
+
+    def __init__(self, uri=None, rewriteCUAddresses=True, moreHeaders=[], podding=False):
         """
         @param recordType: record type for directory entry.
         """
@@ -148,7 +142,7 @@ class IScheduleServerRecord (object):
         self.allow_to = True
         self.domains = []
         self.client_hosts = []
-        self.unNormalizeAddresses = unNormalizeAddresses
+        self.rewriteCUAddresses = rewriteCUAddresses
         self.moreHeaders = moreHeaders
         self._podding = podding
 
@@ -156,15 +150,12 @@ class IScheduleServerRecord (object):
             self.uri = uri
             self._parseDetails()
 
-
     def details(self):
         return (self.ssl, self.host, self.port, self.path,)
 
-
     def podding(self):
         return self._podding
 
-
     def redirect(self, location):
         """
         Permanent redirect for the lifetime of this record.
@@ -172,7 +163,6 @@ class IScheduleServerRecord (object):
         self.uri = location
         self._parseDetails()
 
-
     def parseXML(self, node):
         for child in node:
             if child.tag == ELEMENT_URI:
@@ -192,13 +182,11 @@ class IScheduleServerRecord (object):
 
         self._parseDetails()
 
-
     def _parseList(self, node, element_name, appendto):
         for child in node:
             if child.tag == element_name:
                 appendto.append(child.text)
 
-
     def _parseAuthentication(self, node):
         if node.get(ATTRIBUTE_TYPE) != ATTRIBUTE_BASICAUTH:
             return
@@ -211,7 +199,6 @@ class IScheduleServerRecord (object):
 
         self.authentication = ("basic", user, password,)
 
-
     def _parseDetails(self):
         # Extract scheme, host, port and path
         if self.uri.startswith("http://"):
