@@ -1,5 +1,5 @@
 ##
-# Copyright (c) 2013-2015 Apple Inc. All rights reserved.
+# Copyright (c) 2013-2017 Apple Inc. All rights reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -31,7 +31,6 @@ from txdav.caldav.datastore.scheduling.work import ScheduleOrganizerWork, \
 from txdav.common.datastore.test.util import populateCalendarsFrom, CommonCommonTests
 
 
-
 class BaseWorkTests(CommonCommonTests, unittest.TestCase):
     """
     Tests for scheduling work.
@@ -43,7 +42,6 @@ class BaseWorkTests(CommonCommonTests, unittest.TestCase):
         yield self.buildStoreAndDirectory()
         yield self.populate()
 
-
     @inlineCallbacks
     def populate(self):
         yield populateCalendarsFrom(self.requirements, self.storeUnderTest())
@@ -70,14 +68,12 @@ class BaseWorkTests(CommonCommonTests, unittest.TestCase):
         },
     }
 
-
     def storeUnderTest(self):
         """
         Create and return a L{CalendarStore} for testing.
         """
         return self._sqlCalendarStore
 
-
     @inlineCallbacks
     def _runAllJobs(self):
         """
@@ -91,20 +87,19 @@ class BaseWorkTests(CommonCommonTests, unittest.TestCase):
             jobs = yield JobItem.all(self.transactionUnderTest())
         yield self.commit()
 
-
     @inlineCallbacks
-    def _runOneJob(self):
+    def _runOneJob(self, work_type=None):
         """
         Run the first outstanding jobs.
         """
         # Run jobs
         jobs = yield JobItem.all(self.transactionUnderTest())
         for job in jobs:
-            yield job.run()
-            break
+            if work_type is None or job.workType == work_type:
+                yield job.run()
+                break
         yield self.commit()
 
-
     @inlineCallbacks
     def createOrganizerEvent(self, organizer, ical, run_jobs=True):
         """
@@ -117,7 +112,6 @@ class BaseWorkTests(CommonCommonTests, unittest.TestCase):
         if run_jobs:
             yield self._runAllJobs()
 
-
     @inlineCallbacks
     def getOrganizerResource(self, organizer):
         """
@@ -126,7 +120,6 @@ class BaseWorkTests(CommonCommonTests, unittest.TestCase):
         calobj = yield self.calendarObjectUnderTest(name="invite.ics", calendar_name="calendar", home=organizer)
         returnValue(calobj)
 
-
     @inlineCallbacks
     def setOrganizerEvent(self, organizer, ical, run_jobs=True):
         """
@@ -139,7 +132,6 @@ class BaseWorkTests(CommonCommonTests, unittest.TestCase):
         if run_jobs:
             yield self._runAllJobs()
 
-
     @inlineCallbacks
     def getOrganizerEvent(self, organizer):
         """
@@ -150,7 +142,6 @@ class BaseWorkTests(CommonCommonTests, unittest.TestCase):
         yield self.commit()
         returnValue(comp)
 
-
     @inlineCallbacks
     def getAttendeeResource(self, attendee):
         """
@@ -161,7 +152,6 @@ class BaseWorkTests(CommonCommonTests, unittest.TestCase):
         self.assertEqual(len(calobjs), 1)
         returnValue(calobjs[0])
 
-
     @inlineCallbacks
     def setAttendeeEvent(self, attendee, ical, run_jobs=True):
         """
@@ -174,7 +164,6 @@ class BaseWorkTests(CommonCommonTests, unittest.TestCase):
         if run_jobs:
             yield self._runAllJobs()
 
-
     @inlineCallbacks
     def getAttendeeEvent(self, attendee):
         """
@@ -186,7 +175,6 @@ class BaseWorkTests(CommonCommonTests, unittest.TestCase):
         returnValue(comp)
 
 
-
 class TestScheduleOrganizerWork(BaseWorkTests):
     """
     Test creation of L{ScheduleOrganizerWork} items.
@@ -220,7 +208,6 @@ END:VEVENT
 END:VCALENDAR
 """)
 
-
     @inlineCallbacks
     def test_create(self):
         """
@@ -265,7 +252,6 @@ END:VCALENDAR
         baseWork = yield ScheduleWork.all(self.transactionUnderTest())
         self.assertEqual(len(baseWork), 0)
 
-
     @inlineCallbacks
     def test_cascade_delete_cleanup(self):
         """
@@ -317,7 +303,6 @@ END:VCALENDAR
         self.assertEqual(len(baseWork), 0)
 
 
-
 class TestScheduleOrganizerSendWork(BaseWorkTests):
     """
     Test creation of L{ScheduleOrganizerSendWork} items.
@@ -337,7 +322,6 @@ END:VEVENT
 END:VCALENDAR
 """.format(attendees="\n".join(["ATTENDEE:urn:x-uid:user%02d" % i for i in range(1, 100)])))
 
-
     @inlineCallbacks
     def test_create(self):
         """
@@ -375,7 +359,6 @@ END:VCALENDAR
         yield self.commit()
 
 
-
 class TestScheduleWork(BaseWorkTests):
     """
     Test various scheduling work scenarios that are potential race conditions and could give rise to
@@ -395,7 +378,6 @@ class TestScheduleWork(BaseWorkTests):
         self.patch(JobItem, "failureRescheduleInterval", 1000)
         self.patch(JobItem, "lockRescheduleInterval", 1000)
 
-
     @inlineCallbacks
     def test_replyBeforeResourceDelete(self):
         """
@@ -482,7 +464,6 @@ END:VCALENDAR
         organizer = yield self.getOrganizerEvent("user01")
         self.assertEqual(organizer, organizer2, msg=diff_iCalStrs(organizer, organizer2))
 
-
     @inlineCallbacks
     def test_replyBeforeOrganizerEXDATE(self):
         """
@@ -602,7 +583,6 @@ END:VCALENDAR
         self.assertEqual(len(jobs), 0)
         yield self.commit()
 
-
     @inlineCallbacks
     def test_replyBeforeOrganizerInconsequentialChange(self):
         """
@@ -706,7 +686,6 @@ END:VEVENT
 END:VCALENDAR
 """)
 
-
         yield self.createOrganizerEvent("user01", organizer1)
         attendee = yield self.getAttendeeEvent("user02")
         self.assertEqual(attendee, attendee1, msg=diff_iCalStrs(attendee, attendee1))
@@ -726,7 +705,6 @@ END:VCALENDAR
         attendee = yield self.getAttendeeEvent("user02")
         self.assertEqual(normalize_iCalStr(attendee), normalize_iCalStr(attendee3), msg=diff_iCalStrs(attendee3, attendee))
 
-
     @inlineCallbacks
     def test_replyBeforeOrganizerConsequentialChange(self):
         """
@@ -831,7 +809,6 @@ END:VEVENT
 END:VCALENDAR
 """)
 
-
         yield self.createOrganizerEvent("user01", organizer1)
         attendee = yield self.getAttendeeEvent("user02")
         self.assertEqual(attendee, attendee1, msg=diff_iCalStrs(attendee, attendee1))
@@ -851,7 +828,6 @@ END:VCALENDAR
         attendee = yield self.getAttendeeEvent("user02")
         self.assertEqual(normalize_iCalStr(attendee), normalize_iCalStr(attendee3), msg=diff_iCalStrs(attendee3, attendee))
 
-
     @inlineCallbacks
     def test_needsActionOrganizerChange(self):
         """
@@ -954,7 +930,6 @@ END:VEVENT
 END:VCALENDAR
 """)
 
-
         yield self.createOrganizerEvent("user01", organizer1)
         attendee = yield self.getAttendeeEvent("user02")
         self.assertEqual(attendee, attendee1, msg=diff_iCalStrs(attendee, attendee1))
@@ -965,3 +940,66 @@ END:VCALENDAR
         yield self.setOrganizerEvent("user01", organizer3)
         attendee = yield self.getAttendeeEvent("user02")
         self.assertEqual(normalize_iCalStr(attendee), normalize_iCalStr(attendee3), msg=diff_iCalStrs(attendee3, attendee))
+
+    @inlineCallbacks
+    def test_refreshBeforeOrganizerRemoved(self):
+        """
+        Test that a refresh work runs even though the original event has had the Organizer removed.
+        """
+
+        organizer1 = Component.fromString("""BEGIN:VCALENDAR
+VERSION:2.0
+PRODID:-//CALENDARSERVER.ORG//NONSGML Version 1//EN
+BEGIN:VEVENT
+UID:12345-67890
+DTSTAMP:20080601T130000Z
+DTSTART:20080601T130000Z
+DURATION:PT1H
+ORGANIZER;CN=User 01;EMAIL=user01@example.com:urn:x-uid:user01
+ATTENDEE;CN=User 01;EMAIL=user01@example.com;PARTSTAT=ACCEPTED:urn:x-uid:user01
+ATTENDEE;CN=User 02;EMAIL=user02@example.com;PARTSTAT=NEEDS-ACTION:urn:x-uid:user02
+ATTENDEE;CN=User 03;EMAIL=user03@example.com;PARTSTAT=NEEDS-ACTION:urn:x-uid:user03
+END:VEVENT
+END:VCALENDAR
+""")
+
+        attendee1 = Component.fromString("""BEGIN:VCALENDAR
+VERSION:2.0
+PRODID:-//CALENDARSERVER.ORG//NONSGML Version 1//EN
+BEGIN:VEVENT
+UID:12345-67890
+DTSTAMP:20080601T130000Z
+DTSTART:20080601T130000Z
+DURATION:PT1H
+ORGANIZER;CN=User 01;EMAIL=user01@example.com:urn:x-uid:user01
+ATTENDEE;CN=User 01;EMAIL=user01@example.com;PARTSTAT=ACCEPTED:urn:x-uid:user01
+ATTENDEE;CN=User 02;EMAIL=user02@example.com;PARTSTAT=ACCEPTED;RSVP=TRUE:urn:x-uid:user02
+ATTENDEE;CN=User 03;EMAIL=user03@example.com;PARTSTAT=NEEDS-ACTION;RSVP=TRUE:urn:x-uid:user03
+TRANSP:TRANSPARENT
+END:VEVENT
+END:VCALENDAR
+""")
+
+        organizer2 = Component.fromString("""BEGIN:VCALENDAR
+VERSION:2.0
+PRODID:-//CALENDARSERVER.ORG//NONSGML Version 1//EN
+BEGIN:VEVENT
+UID:12345-67890
+DTSTAMP:20080601T130000Z
+DTSTART:20080601T130000Z
+DURATION:PT1H
+END:VEVENT
+END:VCALENDAR
+""")
+
+        yield self.createOrganizerEvent("user01", organizer1)
+        yield self.setAttendeeEvent("user02", attendee1, run_jobs=False)
+        yield self._runOneJob()
+        yield self.setOrganizerEvent("user01", organizer2, run_jobs=False)
+        yield self._runOneJob(work_type="SCHEDULE_ORGANIZER_WORK")
+
+        yield self._runAllJobs()
+
+        jobs = yield JobItem.all(self.transactionUnderTest())
+        self.assertEqual(len(jobs), 0)
+        yield self.commit()
