@@ -1,5 +1,5 @@
 ##
-# Copyright (c) 2010-2015 Apple Inc. All rights reserved.
+# Copyright (c) 2010-2017 Apple Inc. All rights reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -23,6 +23,7 @@ File calendar store tests.
 # FileStorageTests, or implementation-agnostic methods on CommonTests.
 
 from pycalendar.datetime import DateTime
+from twext.enterprise.ienterprise import AlreadyFinishedError
 from twext.python.filepath import CachingFilePath as FilePath
 from twisted.internet.defer import inlineCallbacks
 from twisted.trial import unittest
@@ -48,13 +49,11 @@ def _todo(f, why):
     return f
 
 
-
 featureUnimplemented = lambda f: _todo(f, "Feature unimplemented")
 testUnimplemented = lambda f: _todo(f, "Test unimplemented")
 todo = lambda why: lambda f: _todo(f, why)
 
 
-
 def setUpCalendarStore(test):
     test.root = FilePath(test.mktemp())
     test.root.createDirectory()
@@ -93,7 +92,6 @@ def setUpCalendarStore(test):
     assert test.calendarStore is not None, "No calendar store?"
 
 
-
 @inlineCallbacks
 def setUpHome1(test):
     setUpCalendarStore(test)
@@ -101,7 +99,6 @@ def setUpHome1(test):
     assert test.home1 is not None, "No calendar home?"
 
 
-
 @inlineCallbacks
 def setUpCalendar1(test):
     yield setUpHome1(test)
@@ -109,7 +106,6 @@ def setUpCalendar1(test):
     assert test.calendar1 is not None, "No calendar?"
 
 
-
 class CalendarStoreTest(unittest.TestCase):
     """
     Test cases for L{CalendarStore}.
@@ -120,6 +116,13 @@ class CalendarStoreTest(unittest.TestCase):
     def setUp(self):
         setUpCalendarStore(self)
 
+    @inlineCallbacks
+    def tearDown(self):
+        super(CalendarStoreTest, self).tearDown()
+        try:
+            yield self.txn.commit()
+        except AlreadyFinishedError:
+            pass
 
     def test_calendarHomeWithUID_dot(self):
         """
@@ -132,7 +135,6 @@ class CalendarStoreTest(unittest.TestCase):
         )
 
 
-
 class CalendarHomeTest(unittest.TestCase):
 
     notifierFactory = None
@@ -140,6 +142,13 @@ class CalendarHomeTest(unittest.TestCase):
     def setUp(self):
         return setUpHome1(self)
 
+    @inlineCallbacks
+    def tearDown(self):
+        super(CalendarHomeTest, self).tearDown()
+        try:
+            yield self.txn.commit()
+        except AlreadyFinishedError:
+            pass
 
     def test_init(self):
         """
@@ -155,7 +164,6 @@ class CalendarHomeTest(unittest.TestCase):
             self.calendarStore
         )
 
-
     def test_calendarWithName_dot(self):
         """
         Filenames starting with "." are reserved by this
@@ -165,7 +173,6 @@ class CalendarHomeTest(unittest.TestCase):
         self.home1._path.child(name).createDirectory()
         self.assertEquals(self.home1.calendarWithName(name), None)
 
-
     def test_createCalendarWithName_dot(self):
         """
         Filenames starting with "." are reserved by this
@@ -176,7 +183,6 @@ class CalendarHomeTest(unittest.TestCase):
             self.home1.createCalendarWithName, ".foo"
         )
 
-
     def test_removeCalendarWithName_dot(self):
         """
         Filenames starting with "." are reserved by this
@@ -190,7 +196,6 @@ class CalendarHomeTest(unittest.TestCase):
         )
 
 
-
 class CalendarTest(unittest.TestCase):
 
     notifierFactory = None
@@ -198,6 +203,13 @@ class CalendarTest(unittest.TestCase):
     def setUp(self):
         return setUpCalendar1(self)
 
+    @inlineCallbacks
+    def tearDown(self):
+        super(CalendarTest, self).tearDown()
+        try:
+            yield self.txn.commit()
+        except AlreadyFinishedError:
+            pass
 
     def test_init(self):
         """
@@ -213,7 +225,6 @@ class CalendarTest(unittest.TestCase):
             self.calendar1._calendarHome
         )
 
-
     @inlineCallbacks
     def test_useIndexImmediately(self):
         """
@@ -236,7 +247,7 @@ class CalendarTest(unittest.TestCase):
         index = calendar._index
         self.assertEquals(set((yield index.calendarObjects())),
                           set((yield calendar.calendarObjects())))
-
+        index._oldIndex._db_close()
 
     @inlineCallbacks
     def test_calendarObjectWithName_dot(self):
@@ -251,7 +262,6 @@ class CalendarTest(unittest.TestCase):
             (yield self.calendar1.calendarObjectWithName(name)),
             None)
 
-
     @featureUnimplemented
     @inlineCallbacks
     def test_calendarObjectWithUID_exists(self):
@@ -268,7 +278,6 @@ class CalendarTest(unittest.TestCase):
             (yield self.calendar1.calendarObjectWithName("1.ics")).component()
         )
 
-
     def test_createCalendarObjectWithName_dot(self):
         """
         Filenames starting with "." are reserved by this
@@ -281,7 +290,6 @@ class CalendarTest(unittest.TestCase):
             ".foo", VComponent.fromString(test_event_text)
         )
 
-
     @featureUnimplemented
     @inlineCallbacks
     def test_createCalendarObjectWithName_uidconflict(self):
@@ -298,7 +306,6 @@ class CalendarTest(unittest.TestCase):
             name, component
         )
 
-
     @inlineCallbacks
     def test_CalendarObject_remove_delayedEffect(self):
         """
@@ -326,7 +333,6 @@ class CalendarTest(unittest.TestCase):
         self.home1 = yield self.txn.calendarHomeWithUID("home1")
         self.calendar1 = yield self.home1.calendarWithName("calendar_1")
 
-
     @inlineCallbacks
     def test_undoCreateCalendarObject(self):
         """
@@ -349,7 +355,6 @@ class CalendarTest(unittest.TestCase):
         )
         yield self.txn.commit()
 
-
     @inlineCallbacks
     def doThenUndo(self):
         """
@@ -364,7 +369,6 @@ class CalendarTest(unittest.TestCase):
         self.assertRaises(RuntimeError, self.txn.commit)
         yield self._refresh()
 
-
     @inlineCallbacks
     def test_undoModifyCalendarObject(self):
         """
@@ -381,12 +385,13 @@ class CalendarTest(unittest.TestCase):
             (yield self.calendar1.calendarObjectWithName("1.ics")).component(),
             VComponent.fromString(event1modified_text)
         )
+        index = self.calendar1._index
         yield self.doThenUndo()
         self.assertEquals(
             (yield self.calendar1.calendarObjectWithName("1.ics")).component(),
             originalComponent
         )
-
+        index._oldIndex._db_close()
 
     @testUnimplemented
     def test_syncToken(self):
@@ -395,7 +400,6 @@ class CalendarTest(unittest.TestCase):
         """
         raise NotImplementedError()
 
-
     @testUnimplemented
     def test_calendarObjectsInTimeRange(self):
         """
@@ -403,7 +407,6 @@ class CalendarTest(unittest.TestCase):
         """
         raise NotImplementedError()
 
-
     @testUnimplemented
     def test_calendarObjectsSinceToken(self):
         """
@@ -413,7 +416,6 @@ class CalendarTest(unittest.TestCase):
         raise NotImplementedError()
 
 
-
 class CalendarObjectTest(unittest.TestCase):
     notifierFactory = None
 
@@ -422,6 +424,13 @@ class CalendarObjectTest(unittest.TestCase):
         yield setUpCalendar1(self)
         self.object1 = yield self.calendar1.calendarObjectWithName("1.ics")
 
+    @inlineCallbacks
+    def tearDown(self):
+        super(CalendarObjectTest, self).tearDown()
+        try:
+            yield self.txn.commit()
+        except AlreadyFinishedError:
+            pass
 
     def test_init(self):
         """
@@ -438,7 +447,6 @@ class CalendarObjectTest(unittest.TestCase):
             self.object1._calendar
         )
 
-
     def test_componentType(self):
         """
         Component type is correct.
@@ -446,7 +454,6 @@ class CalendarObjectTest(unittest.TestCase):
         self.assertEquals(self.object1.componentType(), "VEVENT")
 
 
-
 class FileStorageTests(CommonTests, unittest.TestCase):
     """
     File storage tests.
@@ -462,7 +469,6 @@ class FileStorageTests(CommonTests, unittest.TestCase):
             setUpCalendarStore(self)
         return self.calendarStore
 
-
     def test_shareWith(self):
         """
         Overridden to be skipped.
@@ -478,7 +484,6 @@ class FileStorageTests(CommonTests, unittest.TestCase):
     test_unshareShareeSide = test_shareWith
     test_sharedNotifierID = test_shareWith
 
-
     def test_init(self):
         """
         L{CalendarStore} has a C{_path} attribute which refers to its
@@ -487,7 +492,6 @@ class FileStorageTests(CommonTests, unittest.TestCase):
         self.assertEquals(self.storeUnderTest()._path,
                           self.storeRootPath)
 
-
     @inlineCallbacks
     def test_calendarObjectsWithDotFile(self):
         """
@@ -497,7 +501,6 @@ class FileStorageTests(CommonTests, unittest.TestCase):
         (yield self.homeUnderTest())._path.child(".foo").createDirectory()
         yield self.test_calendarObjects()
 
-
     @inlineCallbacks
     def test_calendarObjectsWithDirectory(self):
         """
@@ -508,7 +511,6 @@ class FileStorageTests(CommonTests, unittest.TestCase):
          .createDirectory())
         yield self.test_calendarObjects()
 
-
     def test_simpleHomeSyncToken(self):
         """
         File store doesn't have a functioning C{resourceNamesSinceToken} for
