@@ -1,5 +1,5 @@
 ##
-# Copyright (c) 2005-2015 Apple Inc. All rights reserved.
+# Copyright (c) 2005-2017 Apple Inc. All rights reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -44,15 +44,13 @@ class ImplicitRequests (CommonCommonTests, TestCase):
         yield self.buildStoreAndDirectory()
         yield self.populate()
 
-
     @inlineCallbacks
     def populate(self):
         yield populateCalendarsFrom(self.requirements, self.storeUnderTest())
         self.notifierFactory.reset()
 
-
     @classproperty(cache=False)
-    def requirements(cls): #@NoSelf
+    def requirements(cls):  # @NoSelf
         return {
             "user01": {
                 "calendar_1": {
@@ -68,14 +66,12 @@ class ImplicitRequests (CommonCommonTests, TestCase):
             },
         }
 
-
     def storeUnderTest(self):
         """
         Create and return a L{CalendarStore} for testing.
         """
         return self._sqlCalendarStore
 
-
     @inlineCallbacks
     def test_doCreateResource(self):
         """
@@ -110,7 +106,6 @@ END:VCALENDAR
         self.assertTrue("CN=" in calendar1)
         yield self.commit()
 
-
     @inlineCallbacks
     def test_validation_maxResourceSize(self):
         """
@@ -160,7 +155,6 @@ END:VCALENDAR
         yield self.failUnlessFailure(calendar_resource.setComponent(calendar2), ObjectResourceTooBigError)
         yield self.commit()
 
-
     @inlineCallbacks
     def test_validation_validCalendarDataCheck(self):
         """
@@ -203,7 +197,6 @@ END:VCALENDAR
             yield self.failUnlessFailure(calendar_collection.createCalendarObjectWithName("test.ics", calendar), InvalidObjectResourceError, InvalidComponentForStoreError)
             yield self.commit()
 
-
     @inlineCallbacks
     def test_validation_validSupportedComponentType(self):
         """
@@ -223,12 +216,11 @@ END:VCALENDAR
 """
 
         calendar_collection = (yield self.calendarUnderTest(home="user01"))
-        calendar_collection.setSupportedComponents("VTODO")
+        yield calendar_collection.setSupportedComponents("VTODO")
         calendar = Component.fromString(data1)
         yield self.failUnlessFailure(calendar_collection.createCalendarObjectWithName("test.ics", calendar), InvalidComponentTypeError)
         yield self.commit()
 
-
     @inlineCallbacks
     def test_validation_validAttendeeListSizeCheck(self):
         """
@@ -259,7 +251,6 @@ END:VCALENDAR
         yield self.failUnlessFailure(calendar_collection.createCalendarObjectWithName("test.ics", calendar), TooManyAttendeesError)
         yield self.commit()
 
-
     @inlineCallbacks
     def test_validation_validAccess_invalidValue(self):
         """
@@ -285,7 +276,6 @@ END:VCALENDAR
         yield self.failUnlessFailure(calendar_collection.createCalendarObjectWithName("test.ics", calendar), InvalidCalendarAccessError)
         yield self.commit()
 
-
     @inlineCallbacks
     def test_validation_validAccess_authzChangeNotAllowed(self):
         """
@@ -349,7 +339,6 @@ END:VCALENDAR
         self.assertTrue("SUMMARY:Changed" in calendar1)
         yield self.commit()
 
-
     @inlineCallbacks
     def test_validation_overwriteUID(self):
         """
@@ -391,7 +380,6 @@ END:VCALENDAR
         yield self.failUnlessFailure(calendar_resource.setComponent(calendar), InvalidUIDError)
         yield self.commit()
 
-
     @inlineCallbacks
     def test_validation_duplicateUIDSameCalendar(self):
         """
@@ -434,7 +422,6 @@ END:VCALENDAR
         yield self.failUnlessFailure(calendar_collection.createCalendarObjectWithName("test2.ics", calendar), UIDExistsError)
         yield self.commit()
 
-
     @inlineCallbacks
     def test_validation_duplicateUIDDifferentCalendar(self):
         """
@@ -478,7 +465,6 @@ END:VCALENDAR
         yield self.failUnlessFailure(calendar_collection_2.createCalendarObjectWithName("test2.ics", calendar), UIDExistsElsewhereError)
         yield self.commit()
 
-
     @inlineCallbacks
     def test_validation_noPreservePrivateComments(self):
         """
@@ -530,7 +516,6 @@ END:VCALENDAR
         self.assertTrue("SUMMARY:Changed" in calendar1)
         yield self.commit()
 
-
     @inlineCallbacks
     def test_validation_preserveOrganizerPrivateComments(self):
         """
@@ -583,7 +568,6 @@ END:VCALENDAR
         self.assertTrue("SUMMARY:Changed" in calendar1)
         yield self.commit()
 
-
     @inlineCallbacks
     def test_validation_replaceMissingToDoProperties_OrganizerAttendee(self):
         """
@@ -638,7 +622,6 @@ END:VCALENDAR
         self.assertTrue("SUMMARY:Changed" in calendar1)
         yield self.commit()
 
-
     @inlineCallbacks
     def test_validation_replaceMissingToDoProperties_Completed(self):
         """
@@ -698,7 +681,6 @@ END:VCALENDAR
         self.assertTrue("PARTSTAT=COMPLETED" in calendar1)
         yield self.commit()
 
-
     @inlineCallbacks
     def test_validation_dropboxPathNormalization(self):
         """
@@ -738,7 +720,6 @@ END:VCALENDAR
         self.assertTrue("ATTACH:https://example.org/attachments/2.txt" in calendar1)
         yield self.commit()
 
-
     @inlineCallbacks
     def test_validation_processAlarms_DuplicateRemoval(self):
         """
@@ -804,7 +785,6 @@ END:VCALENDAR
         self.assertTrue("SUMMARY:Changed" in calendar1)
         yield self.commit()
 
-
     @inlineCallbacks
     def test_validation_processAlarms_AddDefault(self):
         """
@@ -847,7 +827,6 @@ END:VCALENDAR
         self.assertEqual(calendar1.count("BEGIN:VALARM"), 1)
         yield self.commit()
 
-
     @inlineCallbacks
     def test_validation_processAlarms_NoDefaultShared(self):
         """
@@ -898,7 +877,6 @@ END:VCALENDAR
         self.assertEqual(calendar1.count("BEGIN:VALARM"), 0)
         yield self.commit()
 
-
     @inlineCallbacks
     def test_validation_mergePerUserData(self):
         """
@@ -1008,7 +986,6 @@ END:VCALENDAR
 
         yield self.commit()
 
-
     @inlineCallbacks
     def test_validation_processScheduleTags(self):
         """
@@ -1099,7 +1076,6 @@ END:VCALENDAR
         self.assertEqual(calendar_resource.scheduleTag, schedule_tag)
         yield self.commit()
 
-
     @inlineCallbacks
     def test_validation_duplicatePrivateCommentsOKWIthiTIP(self):
         """
@@ -1180,7 +1156,6 @@ END:VCALENDAR
         yield self.failUnlessFailure(calendar_resource.setComponent(calendar), DuplicatePrivateCommentsError)
         yield self.commit()
 
-
     @inlineCallbacks
     def test_validation_deleteWithDuplicatePrivateComments(self):
         """
@@ -1274,3 +1249,5 @@ END:VCALENDAR
         cobjs = (yield calendar2.calendarObjects())
         self.assertTrue(len(cobjs) == 0)
         yield self.commit()
+
+        self.flushLoggedErrors(ValueError)
