@@ -1,5 +1,5 @@
 ##
-# Copyright (c) 2005-2015 Apple Inc. All rights reserved.
+# Copyright (c) 2005-2017 Apple Inc. All rights reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -132,6 +132,22 @@ END:VEVENT
 END:VCALENDAR
 """.replace("\n", "\r\n").format(**nowYear)
 
+    inboxdata1 = """BEGIN:VCALENDAR
+VERSION:2.0
+CALSCALE:GREGORIAN
+PRODID:-//CALENDARSERVER.ORG//NONSGML Version 1//EN
+METHOD:REQUEST
+BEGIN:VEVENT
+UID:uid1-inbox
+DTSTART:{now:04d}0102T140000Z
+DURATION:PT1H
+CREATED:20060102T190000Z
+DTSTAMP:20051222T210507Z
+RRULE:FREQ=WEEKLY
+SUMMARY:instance
+END:VEVENT
+END:VCALENDAR
+""".replace("\n", "\r\n").format(**nowYear)
 
     @inlineCallbacks
     def test_remote_home(self):
@@ -150,7 +166,6 @@ END:VCALENDAR
         self.assertEqual(home.id(), home01.id())
         yield self.commitTransaction(1)
 
-
     @inlineCallbacks
     def test_prepare_home(self):
         """
@@ -172,7 +187,6 @@ END:VCALENDAR
         self.assertEqual(len(children), 0)
         yield self.commitTransaction(1)
 
-
     @inlineCallbacks
     def test_prepare_home_external_txn(self):
         """
@@ -195,7 +209,6 @@ END:VCALENDAR
         self.assertEqual(len(children), 0)
         yield self.commitTransaction(1)
 
-
     @inlineCallbacks
     def test_home_metadata(self):
         """
@@ -304,7 +317,6 @@ END:VCALENDAR
         self.assertEqual(normalize_iCalStr(home1.getAvailability()), normalize_iCalStr(availability))
         yield self.commitTransaction(1)
 
-
     @inlineCallbacks
     def test_get_calendar_sync_list(self):
         """
@@ -334,7 +346,6 @@ END:VCALENDAR
         results = yield syncer.getCalendarSyncList()
         self.assertEqual(results, results01)
 
-
     @inlineCallbacks
     def test_sync_calendar_initial_empty(self):
         """
@@ -380,7 +391,6 @@ END:VCALENDAR
         self.assertTrue(calendar1 is not None)
         yield self.commitTransaction(1)
 
-
     @inlineCallbacks
     def test_sync_calendar_initial_with_data(self):
         """
@@ -394,8 +404,11 @@ END:VCALENDAR
         o1 = yield calendar0.createCalendarObjectWithName("1.ics", Component.fromString(self.caldata1))
         o2 = yield calendar0.createCalendarObjectWithName("2.ics", Component.fromString(self.caldata2))
         o3 = yield calendar0.createCalendarObjectWithName("3.ics", Component.fromString(self.caldata3))
+        inbox0 = yield home0.childWithName("inbox")
+        inbox_o1 = yield inbox0.createCalendarObjectWithName("inbox1.ics", Component.fromString(self.inboxdata1))
         remote_id = calendar0.id()
-        mapping0 = dict([(o.name(), o.id()) for o in (o1, o2, o3)])
+        inbox_remote_id = inbox0.id()
+        mapping0 = dict([(o.name(), o.id()) for o in (o1, o2, o3, inbox_o1)])
         yield self.commitTransaction(0)
 
         syncer = CrossPodHomeSync(self.theStoreUnderTest(1), "user01")
@@ -419,6 +432,17 @@ END:VCALENDAR
         self.assertEqual(len(local_sync_state), 1)
         self.assertEqual(local_sync_state[remote_id].lastSyncToken, remote_sync_state[remote_id].lastSyncToken)
 
+        # Trigger sync of the one inbox
+        inbox_local_sync_state = {}
+        inbox_remote_sync_state = yield syncer.getCalendarSyncList()
+        yield syncer.syncCalendar(
+            inbox_remote_id,
+            inbox_local_sync_state,
+            inbox_remote_sync_state,
+        )
+        self.assertEqual(len(inbox_local_sync_state), 1)
+        self.assertEqual(inbox_local_sync_state[inbox_remote_id].lastSyncToken, inbox_remote_sync_state[inbox_remote_id].lastSyncToken)
+
         @inlineCallbacks
         def _checkCalendarObjectMigrationState(home, mapping1):
             com = schema.CALENDAR_OBJECT_MIGRATION
@@ -430,14 +454,18 @@ END:VCALENDAR
             expected_mappings = dict([(mapping0[name], mapping1[name]) for name in mapping0.keys()])
             self.assertEqual(dict(mappings), expected_mappings)
 
-
-        # Local calendar exists
+        # Local calendar/inbox exists
         home1 = yield self.homeUnderTest(txn=self.theTransactionUnderTest(1), name="user01", status=_HOME_STATUS_MIGRATING)
         calendar1 = yield home1.childWithName("calendar")
         self.assertTrue(calendar1 is not None)
         children = yield calendar1.objectResources()
         self.assertEqual(set([child.name() for child in children]), set(("1.ics", "2.ics", "3.ics",)))
         mapping1 = dict([(o.name(), o.id()) for o in children])
+        inbox1 = yield home1.childWithName("inbox")
+        self.assertTrue(inbox1 is not None)
+        children = yield inbox1.objectResources()
+        self.assertEqual(set([child.name() for child in children]), set(("inbox1.ics",)))
+        mapping1.update(dict([(o.name(), o.id()) for o in children]))
         yield _checkCalendarObjectMigrationState(home1, mapping1)
         yield self.commitTransaction(1)
 
@@ -481,6 +509,10 @@ END:VCALENDAR
         children = yield calendar1.objectResources()
         self.assertEqual(set([child.name() for child in children]), set(("1.ics", "3.ics",)))
         mapping1 = dict([(o.name(), o.id()) for o in children])
+        inbox1 = yield self.calendarUnderTest(txn=self.theTransactionUnderTest(1), home="user01", status=_HOME_STATUS_MIGRATING, name="inbox")
+        children = yield inbox1.objectResources()
+        self.assertEqual(set([child.name() for child in children]), set(("inbox1.ics",)))
+        mapping1.update(dict([(o.name(), o.id()) for o in children]))
         yield _checkCalendarObjectMigrationState(home1, mapping1)
         yield self.commitTransaction(1)
 
@@ -501,10 +533,13 @@ END:VCALENDAR
         children = yield calendar1.objectResources()
         self.assertEqual(set([child.name() for child in children]), set(("1.ics", "3.ics", "4.ics")))
         mapping1 = dict([(o.name(), o.id()) for o in children])
+        inbox1 = yield self.calendarUnderTest(txn=self.theTransactionUnderTest(1), home="user01", status=_HOME_STATUS_MIGRATING, name="inbox")
+        children = yield inbox1.objectResources()
+        self.assertEqual(set([child.name() for child in children]), set(("inbox1.ics",)))
+        mapping1.update(dict([(o.name(), o.id()) for o in children]))
         yield _checkCalendarObjectMigrationState(home1, mapping1)
         yield self.commitTransaction(1)
 
-
     @inlineCallbacks
     def test_sync_calendars_add_remove(self):
         """
@@ -567,7 +602,6 @@ END:VCALENDAR
         self.assertEqual(set(details1.values()), set(details0.values()))
         yield self.commitTransaction(1)
 
-
     @inlineCallbacks
     def test_sync_attachments_add_remove(self):
         """
@@ -575,7 +609,6 @@ END:VCALENDAR
         and finally a removal of the data.
         """
 
-
         home0 = yield self.homeUnderTest(txn=self.theTransactionUnderTest(0), name="user01", create=True)
         calendar0 = yield home0.childWithName("calendar")
         yield calendar0.createCalendarObjectWithName("1.ics", Component.fromString(self.caldata1))
@@ -626,7 +659,6 @@ END:VCALENDAR
             expected_mappings = dict([(mapping0[name], mapping1[name]) for name in mapping0.keys()])
             self.assertEqual(dict(mappings), expected_mappings)
 
-
         # Local calendar exists
         home1 = yield self.homeUnderTest(txn=self.theTransactionUnderTest(1), name="user01", status=_HOME_STATUS_MIGRATING)
         calendar1 = yield home1.childWithName("calendar")
@@ -740,7 +772,6 @@ END:VCALENDAR
         mapping1 = dict([(o.md5(), o.id()) for o in attachments])
         yield _checkAttachmentObjectMigrationState(home1, mapping1)
 
-
     @inlineCallbacks
     def test_link_attachments(self):
         """
@@ -850,7 +881,6 @@ END:VCALENDAR
         self.assertTrue(attachment is not None)
         self.assertEqual(attachment.md5(), md50_1)
 
-
     @inlineCallbacks
     def test_delegate_reconcile(self):
         """
@@ -879,12 +909,8 @@ END:VCALENDAR
         yield Delegates.addDelegate(txn, record01, group01, True)
         yield Delegates.addDelegate(txn, record01, group02, False)
 
-        # Add external delegates
-        yield txn.assignExternalDelegates(u"user01", None, None, u"external1", u"external2")
-
         yield self.commitTransaction(0)
 
-
         # Initially no local delegates
         txn = self.theTransactionUnderTest(1)
         delegates = yield txn.dumpIndividualDelegatesLocal(u"user01")
@@ -924,6 +950,34 @@ END:VCALENDAR
             )),
         )
 
+        yield self.commitTransaction(1)
+
+    @inlineCallbacks
+    def test_delegate_reconcile_directory_based(self):
+        """
+        Test that L{delegateReconcile} copies over the full set of delegates and caches associated groups..
+        """
+
+        # Create remote home
+        yield self.homeUnderTest(txn=self.theTransactionUnderTest(0), name="user01", create=True)
+        yield self.notificationCollectionUnderTest(txn=self.theTransactionUnderTest(0), name="user01", create=True)
+        yield self.commitTransaction(0)
+
+        # Add external delegates
+        txn = self.theTransactionUnderTest(0)
+        yield txn.assignExternalDelegates(u"user01", None, None, u"external1", u"external2")
+
+        yield self.commitTransaction(0)
+
+        # Sync from remote side
+        syncer = CrossPodHomeSync(self.theStoreUnderTest(1), "user01")
+        yield syncer.loadRecord()
+        yield syncer.disableRemoteHome()
+        yield syncer.delegateReconcile()
+
+        # Now have directory based delegates
+        txn = self.theTransactionUnderTest(1)
+
         externals = yield txn.dumpExternalDelegatesLocal(u"user01")
         self.assertEqual(
             set(externals),
@@ -938,7 +992,6 @@ END:VCALENDAR
 
         yield self.commitTransaction(1)
 
-
     @inlineCallbacks
     def test_notifications_reconcile(self):
         """
@@ -984,9 +1037,22 @@ END:VCALENDAR
                 self.fail("Notification uid {} not found".format(result.uid()))
         yield self.commitTransaction(1)
 
+    def test_disable_remote_home(self):
+        """
+        Test that L{disableRemoteHome} changes the remote status and prevents a normal state
+        home from being created. Assume remote notification collection exists.
+        """
+        return self._do_disable_remote_home(notification_exists=True)
+
+    def test_disable_remote_home_no_notifications(self):
+        """
+        Test that L{disableRemoteHome} changes the remote status and prevents a normal state
+        home from being created. Assume remote notification collection does not exist.
+        """
+        return self._do_disable_remote_home(notification_exists=False)
 
     @inlineCallbacks
-    def test_disable_remote_home(self):
+    def _do_disable_remote_home(self, notification_exists=True):
         """
         Test that L{disableRemoteHome} changes the remote status and prevents a normal state
         home from being created.
@@ -1036,7 +1102,8 @@ END:VCALENDAR
         )
 
         # Notifications
-        yield self.theTransactionUnderTest(0).notificationsWithUID("user01", create=True)
+        if notification_exists:
+            yield self.theTransactionUnderTest(0).notificationsWithUID("user01", create=True)
 
         yield self.commitTransaction(0)
 
@@ -1073,7 +1140,6 @@ END:VCALENDAR
 
         yield self.commitTransaction(0)
 
-
     @inlineCallbacks
     def test_work_items_sync(self):
         """
@@ -1185,7 +1251,6 @@ END:VCALENDAR
         self.assertEqual(pod0Data, pod1Data)
 
 
-
 class TestSharingSync(MultiStoreConduitTest):
     """
     Test that L{CrossPodHomeSync} sharing sync works.
@@ -1198,7 +1263,6 @@ class TestSharingSync(MultiStoreConduitTest):
         yield super(TestSharingSync, self).setUp()
         yield self.populate()
 
-
     def configure(self):
         super(TestSharingSync, self).configure()
         config.Sharing.Enabled = True
@@ -1206,22 +1270,20 @@ class TestSharingSync(MultiStoreConduitTest):
         config.Sharing.Calendars.Groups.Enabled = True
         config.Sharing.Calendars.Groups.ReconciliationDelaySeconds = 0
 
-
     @inlineCallbacks
     def populate(self):
         yield populateCalendarsFrom(self.requirements, self.theStoreUnderTest(0))
 
     requirements = {
-        "user01" : None,
-        "user02" : None,
-        "user06" : None,
-        "user07" : None,
-        "user08" : None,
-        "user09" : None,
-        "user10" : None,
+        "user01": None,
+        "user02": None,
+        "user06": None,
+        "user07": None,
+        "user08": None,
+        "user09": None,
+        "user10": None,
     }
 
-
     @inlineCallbacks
     def _createShare(self, shareFrom, shareTo, accept=True):
         # Invite
@@ -1244,7 +1306,6 @@ class TestSharingSync(MultiStoreConduitTest):
 
         returnValue(sharedName)
 
-
     @inlineCallbacks
     def test_shared_collections_reconcile(self):
         """
@@ -1317,7 +1378,6 @@ class TestSharingSync(MultiStoreConduitTest):
         self.assertEqual(invites[0].shareeHomeID, shareeHome1.id())
         yield self.commitTransaction(1)
 
-
     @inlineCallbacks
     def test_group_shared_collections_reconcile(self):
         """
@@ -1355,7 +1415,6 @@ class TestSharingSync(MultiStoreConduitTest):
         yield self.commitTransaction(1)
 
 
-
 class TestGroupAttendeeSync(MultiStoreConduitTest):
     """
     GroupAttendeeReconciliation tests
@@ -1417,26 +1476,24 @@ END:VCALENDAR""".format(**now)
         yield super(TestGroupAttendeeSync, self).setUp()
         yield self.populate()
 
-
     def configure(self):
         super(TestGroupAttendeeSync, self).configure()
         config.GroupAttendees.Enabled = True
         config.GroupAttendees.ReconciliationDelaySeconds = 0
         config.GroupAttendees.AutoUpdateSecondsFromNow = 0
 
-
     @inlineCallbacks
     def populate(self):
         yield populateCalendarsFrom(self.requirements, self.theStoreUnderTest(0))
 
     requirements = {
-        "user01" : None,
-        "user02" : None,
-        "user06" : None,
-        "user07" : None,
-        "user08" : None,
-        "user09" : None,
-        "user10" : None,
+        "user01": None,
+        "user02": None,
+        "user06": None,
+        "user07": None,
+        "user08": None,
+        "user09": None,
+        "user10": None,
     }
 
     @inlineCallbacks
@@ -1482,7 +1539,6 @@ END:VCALENDAR""".format(**now)
         self.assertEqual(record.membershipHash, group04.membershipHash)
 
 
-
 class TestiMIPTokensSync(MultiStoreConduitTest):
     """
     Test that L{CrossPodHomeSync} iMIP token sync works.
@@ -1495,22 +1551,20 @@ class TestiMIPTokensSync(MultiStoreConduitTest):
         yield super(TestiMIPTokensSync, self).setUp()
         yield self.populate()
 
-
     @inlineCallbacks
     def populate(self):
         yield populateCalendarsFrom(self.requirements, self.theStoreUnderTest(0))
 
     requirements = {
-        "user01" : None,
-        "user02" : None,
-        "user06" : None,
-        "user07" : None,
-        "user08" : None,
-        "user09" : None,
-        "user10" : None,
+        "user01": None,
+        "user02": None,
+        "user06": None,
+        "user07": None,
+        "user08": None,
+        "user09": None,
+        "user10": None,
     }
 
-
     @inlineCallbacks
     def _createTokens(self, txn, organizer, attendee_prefix, number):
 
@@ -1523,7 +1577,6 @@ class TestiMIPTokensSync(MultiStoreConduitTest):
                 icaluid=str(uuid4()),
             )
 
-
     @inlineCallbacks
     def test_token_sync(self):
         """
