@@ -1,6 +1,6 @@
 # -*- test-case-name: txdav.caldav.datastore.test.test_sql,txdav.carddav.datastore.test.test_sql -*-
 ##
-# Copyright (c) 2013-2015 Apple Inc. All rights reserved.
+# Copyright (c) 2013-2017 Apple Inc. All rights reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -30,10 +30,12 @@ from txdav.common.datastore.sql_notification import NotificationCollection, \
 from txdav.common.datastore.sql_tables import _HOME_STATUS_EXTERNAL
 from txdav.common.icommondatastore import NonExistentExternalShare, \
     ExternalShareFailed
+from txdav.idav import ChangeCategory
 
 
 log = Logger()
 
+
 class CommonHomeExternal(CommonHome):
     """
     A CommonHome for a user not hosted on this system, but on another pod. This is needed to provide a
@@ -63,17 +65,19 @@ class CommonHomeExternal(CommonHome):
         result._childClass = result._childClass._externalClass
         return result
 
-
     def __init__(self, transaction, homeData):
         super(CommonHomeExternal, self).__init__(transaction, homeData)
 
-
     def initFromStore(self):
         """
-        NoOp for an external share as there is no metadata or properties.
+        External share does not have metadata or properties so we skip those by by-passing
+        the super method, but we do need to add notifiers.
         """
-        return succeed(self)
 
+        for factory_type, factory in self._txn._notifierFactories.items():
+            self.addNotifier(factory_type, factory.newNotifier(self))
+
+        return succeed(self)
 
     @inlineCallbacks
     def readMetaData(self):
@@ -83,11 +87,9 @@ class CommonHomeExternal(CommonHome):
         mapping = yield self._txn.store().conduit.send_home_metadata(self)
         self.deserialize(mapping)
 
-
     def setStatus(self, newStatus):
         return self._txn.store().conduit.send_home_set_status(self, newStatus)
 
-
     def setLocalStatus(self, newStatus):
         """
         Set the status on the object in the local store not the remote one.
@@ -97,7 +99,6 @@ class CommonHomeExternal(CommonHome):
         """
         return super(CommonHomeExternal, self).setStatus(newStatus)
 
-
     def external(self):
         """
         Is this an external home.
@@ -106,21 +107,18 @@ class CommonHomeExternal(CommonHome):
         """
         return True
 
-
     def objectWithShareUID(self, shareUID):
         """
         No children.
         """
         raise AssertionError("CommonHomeExternal: not supported")
 
-
     def invitedObjectWithShareUID(self, shareUID):
         """
         No children.
         """
         raise AssertionError("CommonHomeExternal: not supported")
 
-
     @inlineCallbacks
     def createChildWithName(self, name, bindUID=None):
         """
@@ -131,14 +129,12 @@ class CommonHomeExternal(CommonHome):
         child = yield super(CommonHomeExternal, self).createChildWithName(name, bindUID)
         returnValue(child)
 
-
     def removeChildWithName(self, name, useTrash=True):
         """
         No children.
         """
         raise AssertionError("CommonHomeExternal: not supported")
 
-
     @inlineCallbacks
     def removeExternalChild(self, child):
         """
@@ -149,21 +145,18 @@ class CommonHomeExternal(CommonHome):
             raise AssertionError("CommonHomeExternal: not supported")
         yield super(CommonHomeExternal, self).removeChildWithName(child.name(), useTrash=False)
 
-
     def syncToken(self):
         """
         No children.
         """
         raise AssertionError("CommonHomeExternal: not supported")
 
-
     def resourceNamesSinceRevision(self, revision, depth):
         """
         No children.
         """
         raise AssertionError("CommonHomeExternal: not supported")
 
-
     @inlineCallbacks
     def _loadPropertyStore(self):
         """
@@ -179,46 +172,39 @@ class CommonHomeExternal(CommonHome):
         )
         self._propertyStore = props
 
-
     def properties(self):
         return self._propertyStore
 
-
     def objectResourcesWithUID(self, uid, ignore_children=[], allowShared=True):
         """
         No children.
         """
         raise AssertionError("CommonHomeExternal: not supported")
 
-
     def objectResourceWithID(self, rid):
         """
         No children.
         """
         raise AssertionError("CommonHomeExternal: not supported")
 
-
-    def notifyChanged(self):
+    def notifyChanged(self, category=ChangeCategory.default):
         """
         Notifications are not handled for external homes - make this a no-op.
         """
         return succeed(None)
 
-
     def bumpModified(self):
         """
         No changes recorded for external homes - make this a no-op.
         """
         return succeed(None)
 
-
     def removeUnacceptedShares(self):
         """
         No children.
         """
         raise AssertionError("CommonHomeExternal: not supported")
 
-
     @inlineCallbacks
     def sharedToBindRecords(self):
         results = yield self._txn.store().conduit.send_home_shared_to_records(self)
@@ -232,7 +218,6 @@ class CommonHomeExternal(CommonHome):
         ) for k, v in results.items()]))
 
 
-
 class CommonHomeChildExternal(CommonHomeChild):
     """
     A CommonHomeChild for a collection not hosted on this system, but on another pod. This will forward
@@ -249,7 +234,6 @@ class CommonHomeChildExternal(CommonHomeChild):
 
         return home._txn.store().conduit.send_homechild_listobjects(home)
 
-
     @classmethod
     @inlineCallbacks
     def loadAllObjects(cls, home):
@@ -261,7 +245,6 @@ class CommonHomeChildExternal(CommonHomeChild):
             results.append(child)
         returnValue(results)
 
-
     @classmethod
     @inlineCallbacks
     def objectWith(cls, home, name=None, resourceID=None, bindUID=None, accepted=True, onlyInTrash=False):
@@ -273,7 +256,6 @@ class CommonHomeChildExternal(CommonHomeChild):
         else:
             returnValue(None)
 
-
     def external(self):
         """
         Is this an external home.
@@ -282,7 +264,7 @@ class CommonHomeChildExternal(CommonHomeChild):
         """
         return True
 
-
+    @inlineCallbacks
     def fixNonExistentExternalShare(self):
         """
         An external request has returned and indicates the external share no longer exists. That
@@ -291,7 +273,7 @@ class CommonHomeChildExternal(CommonHomeChild):
         log.error("Non-existent share detected and removed for {share}", share=self)
         ownerView = yield self.ownerView()
         yield ownerView.removeShare(self)
-
+        yield ownerView.cleanExternalShare()
 
     @inlineCallbacks
     def remove(self):
@@ -304,7 +286,6 @@ class CommonHomeChildExternal(CommonHomeChild):
         else:
             raise AssertionError("CommonHomeChildExternal: not supported")
 
-
     @inlineCallbacks
     def moveObjectResource(self, child, newparent, newname=None):
         """
@@ -316,7 +297,6 @@ class CommonHomeChildExternal(CommonHomeChild):
         """
         raise NotImplementedError("TODO: external resource")
 
-
     @inlineCallbacks
     def moveObjectResourceHere(self, name, component):
         """
@@ -336,7 +316,6 @@ class CommonHomeChildExternal(CommonHomeChild):
             raise ExternalShareFailed("External share does not exist")
         returnValue(result)
 
-
     @inlineCallbacks
     def moveObjectResourceAway(self, rid, child=None):
         """
@@ -356,7 +335,6 @@ class CommonHomeChildExternal(CommonHomeChild):
             raise ExternalShareFailed("External share does not exist")
         returnValue(result)
 
-
     @inlineCallbacks
     def syncTokenRevision(self):
         if self._syncTokenRevision is None:
@@ -367,7 +345,6 @@ class CommonHomeChildExternal(CommonHomeChild):
                 raise ExternalShareFailed("External share does not exist")
         returnValue(revision)
 
-
     @inlineCallbacks
     def resourceNamesSinceRevision(self, revision):
         try:
@@ -378,7 +355,6 @@ class CommonHomeChildExternal(CommonHomeChild):
 
         returnValue(names)
 
-
     @inlineCallbacks
     def search(self, filter, **kwargs):
         try:
@@ -389,18 +365,15 @@ class CommonHomeChildExternal(CommonHomeChild):
 
         returnValue(results)
 
-
     @inlineCallbacks
     def sharingBindRecords(self):
         results = yield self._txn.store().conduit.send_homechild_sharing_records(self)
         returnValue(dict([(k, self._bindRecordClass.deserialize(v),) for k, v in results.items()]))
 
-
     def migrateBindRecords(self, bindUID):
         return self._txn.store().conduit.send_homechild_migrate_sharing_records(self, bindUID)
 
 
-
 class CommonObjectResourceExternal(CommonObjectResource):
     """
     A CommonObjectResource for a resource not hosted on this system, but on another pod. This will forward
@@ -419,7 +392,6 @@ class CommonObjectResourceExternal(CommonObjectResource):
                 results.append(child)
         returnValue(results)
 
-
     @classmethod
     @inlineCallbacks
     def loadAllObjectsWithNames(cls, parent, names):
@@ -432,17 +404,14 @@ class CommonObjectResourceExternal(CommonObjectResource):
                 results.append(child)
         returnValue(results)
 
-
     @classmethod
     def listObjects(cls, parent):
         return parent._txn.store().conduit.send_objectresource_listobjects(parent)
 
-
     @classmethod
     def countObjects(cls, parent):
         return parent._txn.store().conduit.send_objectresource_countobjects(parent)
 
-
     @classmethod
     @inlineCallbacks
     def objectWith(cls, parent, name=None, uid=None, resourceID=None):
@@ -454,17 +423,14 @@ class CommonObjectResourceExternal(CommonObjectResource):
         else:
             returnValue(None)
 
-
     @classmethod
     def resourceNameForUID(cls, parent, uid):
         return parent._txn.store().conduit.send_objectresource_resourcenameforuid(parent, uid)
 
-
     @classmethod
     def resourceUIDForName(cls, parent, name):
         return parent._txn.store().conduit.send_objectresource_resourceuidforname(parent, name)
 
-
     @classmethod
     @inlineCallbacks
     def create(cls, parent, name, component, options=None):
@@ -476,14 +442,12 @@ class CommonObjectResourceExternal(CommonObjectResource):
         else:
             returnValue(None)
 
-
     @inlineCallbacks
     def setComponent(self, component, **kwargs):
         self._componentChanged = yield self._txn.store().conduit.send_objectresource_setcomponent(self, str(component), **kwargs)
         self._cachedComponent = None
         returnValue(self._componentChanged)
 
-
     @inlineCallbacks
     def component(self):
         if self._cachedComponent is None:
@@ -492,12 +456,10 @@ class CommonObjectResourceExternal(CommonObjectResource):
 
         returnValue(self._cachedComponent)
 
-
     def remove(self):
         return self._txn.store().conduit.send_objectresource_remove(self)
 
 
-
 class NotificationCollectionExternal(NotificationCollection):
     """
     A NotificationCollection for a resource not hosted on this system, but on another pod. This will forward
@@ -508,24 +470,20 @@ class NotificationCollectionExternal(NotificationCollection):
     def notificationsWithUID(cls, txn, uid, create=False):
         return super(NotificationCollectionExternal, cls).notificationsWithUID(txn, uid, status=_HOME_STATUS_EXTERNAL, create=create)
 
-
     def initFromStore(self):
         """
         NoOp for an external share as there are no properties.
         """
         return succeed(self)
 
-
     @inlineCallbacks
     def notificationObjectRecords(self):
         results = yield self._txn.store().conduit.send_notification_all_records(self)
         returnValue(map(NotificationObjectRecord.deserialize, results))
 
-
     def setStatus(self, newStatus):
         return self._txn.store().conduit.send_notification_set_status(self, newStatus)
 
-
     def setLocalStatus(self, newStatus):
         """
         Set the status on the object in the local store not the remote one.
