@@ -1,7 +1,7 @@
 -- -*- test-case-name: txdav.caldav.datastore.test.test_sql,txdav.carddav.datastore.test.test_sql -*-
 
 ----
--- Copyright (c) 2010-2015 Apple Inc. All rights reserved.
+-- Copyright (c) 2010-2017 Apple Inc. All rights reserved.
 --
 -- Licensed under the Apache License, Version 2.0 (the "License");
 -- you may not use this file except in compliance with the License.
@@ -40,15 +40,25 @@ create sequence JOB_SEQ;
 create table JOB (
   JOB_ID      integer primary key default nextval('JOB_SEQ'), --implicit index
   WORK_TYPE   varchar(255) not null,
-  PRIORITY    integer default 0,
-  WEIGHT      integer default 0,
+  PRIORITY    integer default 0 not null,
+  WEIGHT      integer default 0 not null,
   NOT_BEFORE  timestamp not null,
+  IS_ASSIGNED integer default 0 not null,
   ASSIGNED    timestamp default null,
   OVERDUE     timestamp default null,
-  FAILED      integer default 0,
-  PAUSE       integer default 0
+  FAILED      integer default 0 not null,
+  PAUSE       integer default 0 not null
 );
 
+create index JOB_PRIORITY_IS_ASSIGNED_PAUSE_NOT_BEFORE_JOB_ID on
+  JOB(PRIORITY, IS_ASSIGNED, PAUSE, NOT_BEFORE, JOB_ID);
+
+create index JOB_IS_ASSIGNED_PAUSE_NOT_BEFORE on
+  JOB(IS_ASSIGNED, PAUSE, NOT_BEFORE, JOB_ID);
+
+create index JOB_IS_ASSIGNED_OVERDUE_JOB_ID on
+  JOB(IS_ASSIGNED, OVERDUE, JOB_ID);
+
 -------------------
 -- Calendar Home --
 -------------------
@@ -58,7 +68,7 @@ create table CALENDAR_HOME (
   OWNER_UID        varchar(255) not null,                		                -- implicit index
   STATUS           integer      default 0 not null,                             -- enum HOME_STATUS
   DATAVERSION      integer      default 0 not null,
-  
+
   unique (OWNER_UID, STATUS)	-- implicit index
 );
 
@@ -150,7 +160,7 @@ create table CALENDAR_MIGRATION (
   REMOTE_RESOURCE_ID			integer not null,
   LOCAL_RESOURCE_ID				integer	references CALENDAR on delete cascade,
   LAST_SYNC_TOKEN				varchar(255),
-   
+
   primary key (CALENDAR_HOME_RESOURCE_ID, REMOTE_RESOURCE_ID) -- implicit index
 );
 
@@ -167,7 +177,7 @@ create table NOTIFICATION_HOME (
   OWNER_UID   varchar(255) not null,	                                   -- implicit index
   STATUS      integer      default 0 not null,                             -- enum HOME_STATUS
   DATAVERSION integer      default 0 not null,
-    
+
   unique (OWNER_UID, STATUS)	-- implicit index
 );
 
@@ -307,6 +317,9 @@ create index CALENDAR_OBJECT_ICALENDAR_UID on
 create index CALENDAR_OBJECT_DROPBOX_ID on
   CALENDAR_OBJECT(DROPBOX_ID);
 
+create index CALENDAR_OBJECT_ORIGINAL_COLLECTION_AND_TRASHED on
+  CALENDAR_OBJECT(ORIGINAL_COLLECTION, TRASHED);
+
 -- Enumeration of attachment modes
 
 create table CALENDAR_OBJ_ATTACHMENTS_MODE (
@@ -398,7 +411,7 @@ create table CALENDAR_OBJECT_MIGRATION (
   CALENDAR_HOME_RESOURCE_ID		integer references CALENDAR_HOME on delete cascade,
   REMOTE_RESOURCE_ID			integer not null,
   LOCAL_RESOURCE_ID				integer	references CALENDAR_OBJECT on delete cascade,
-   
+
   primary key (CALENDAR_HOME_RESOURCE_ID, REMOTE_RESOURCE_ID) -- implicit index
 );
 
@@ -453,7 +466,7 @@ create table ATTACHMENT_MIGRATION (
   CALENDAR_HOME_RESOURCE_ID		integer references CALENDAR_HOME on delete cascade,
   REMOTE_RESOURCE_ID			integer not null,
   LOCAL_RESOURCE_ID				integer	references ATTACHMENT on delete cascade,
-   
+
   primary key (CALENDAR_HOME_RESOURCE_ID, REMOTE_RESOURCE_ID) -- implicit index
 );
 
@@ -487,7 +500,7 @@ create table ADDRESSBOOK_HOME (
   OWNER_UID                     varchar(255)    not null,
   STATUS                        integer         default 0 not null,                             -- enum HOME_STATUS
   DATAVERSION                   integer         default 0 not null,
-    
+
   unique (OWNER_UID, STATUS)	-- implicit index
 );
 
@@ -649,9 +662,9 @@ create table CALENDAR_OBJECT_REVISIONS (
   RESOURCE_NAME             varchar(255),
   REVISION                  integer      default nextval('REVISION_SEQ') not null,
   DELETED                   boolean      not null,
-  MODIFIED                  timestamp    default timezone('UTC', CURRENT_TIMESTAMP),
+  MODIFIED                  timestamp    default timezone('UTC', CURRENT_TIMESTAMP) not null,
 
-  unique(CALENDAR_HOME_RESOURCE_ID, CALENDAR_RESOURCE_ID, CALENDAR_NAME, RESOURCE_NAME)    -- implicit index
+  unique (CALENDAR_HOME_RESOURCE_ID, CALENDAR_RESOURCE_ID, CALENDAR_NAME, RESOURCE_NAME)    -- implicit index
 );
 
 create index CALENDAR_OBJECT_REVISIONS_RESOURCE_ID_RESOURCE_NAME_DELETED_REVISION
@@ -663,6 +676,9 @@ create index CALENDAR_OBJECT_REVISIONS_RESOURCE_ID_REVISION
 create index CALENDAR_OBJECT_REVISIONS_HOME_RESOURCE_ID_REVISION
   on CALENDAR_OBJECT_REVISIONS(CALENDAR_HOME_RESOURCE_ID, REVISION);
 
+create index CALENDAR_OBJECT_REVISIONS_REVISION
+  on CALENDAR_OBJECT_REVISIONS(REVISION);
+
 
 ----------------------------------
 -- AddressBook Object Revisions --
@@ -676,9 +692,9 @@ create table ADDRESSBOOK_OBJECT_REVISIONS (
   RESOURCE_NAME                 varchar(255),
   REVISION                      integer      default nextval('REVISION_SEQ') not null,
   DELETED                       boolean      not null,
-  MODIFIED                      timestamp    default timezone('UTC', CURRENT_TIMESTAMP),
+  MODIFIED                      timestamp    default timezone('UTC', CURRENT_TIMESTAMP) not null,
 
-  unique(ADDRESSBOOK_HOME_RESOURCE_ID, OWNER_HOME_RESOURCE_ID, ADDRESSBOOK_NAME, RESOURCE_NAME)    -- implicit index
+  unique (ADDRESSBOOK_HOME_RESOURCE_ID, OWNER_HOME_RESOURCE_ID, ADDRESSBOOK_NAME, RESOURCE_NAME)    -- implicit index
 );
 
 create index ADDRESSBOOK_OBJECT_REVISIONS_OWNER_HOME_RESOURCE_ID_RESOURCE_NAME_DELETED_REVISION
@@ -687,6 +703,9 @@ create index ADDRESSBOOK_OBJECT_REVISIONS_OWNER_HOME_RESOURCE_ID_RESOURCE_NAME_D
 create index ADDRESSBOOK_OBJECT_REVISIONS_OWNER_HOME_RESOURCE_ID_REVISION
   on ADDRESSBOOK_OBJECT_REVISIONS(OWNER_HOME_RESOURCE_ID, REVISION);
 
+create index ADDRESSBOOK_OBJECT_REVISIONS_REVISION
+  on ADDRESSBOOK_OBJECT_REVISIONS(REVISION);
+
 
 -----------------------------------
 -- Notification Object Revisions --
@@ -697,7 +716,7 @@ create table NOTIFICATION_OBJECT_REVISIONS (
   RESOURCE_NAME                 varchar(255),
   REVISION                      integer      default nextval('REVISION_SEQ') not null,
   DELETED                       boolean      not null,
-  MODIFIED                      timestamp    default timezone('UTC', CURRENT_TIMESTAMP),
+  MODIFIED                      timestamp    default timezone('UTC', CURRENT_TIMESTAMP) not null,
 
   unique (NOTIFICATION_HOME_RESOURCE_ID, RESOURCE_NAME) -- implicit index
 );
@@ -705,6 +724,9 @@ create table NOTIFICATION_OBJECT_REVISIONS (
 create index NOTIFICATION_OBJECT_REVISIONS_RESOURCE_ID_REVISION
   on NOTIFICATION_OBJECT_REVISIONS(NOTIFICATION_HOME_RESOURCE_ID, REVISION);
 
+create index NOTIFICATION_OBJECT_REVISIONS_REVISION
+  on NOTIFICATION_OBJECT_REVISIONS(REVISION);
+
 
 -------------------------------------------
 -- Apple Push Notification Subscriptions --
@@ -724,6 +746,8 @@ create table APN_SUBSCRIPTIONS (
 create index APN_SUBSCRIPTIONS_RESOURCE_KEY
   on APN_SUBSCRIPTIONS(RESOURCE_KEY);
 
+create index APN_SUBSCRIPTIONS_MODIFIED
+  on APN_SUBSCRIPTIONS(MODIFIED);
 
 -----------------
 -- IMIP Tokens --
@@ -762,6 +786,18 @@ create table TEST_WORK (
 create index TEST_WORK_JOB_ID on
   TEST_WORK(JOB_ID);
 
+-------------------------------------
+-- Apple Push Notification Purging --
+-------------------------------------
+
+create table APN_PURGING_WORK (
+  WORK_ID                       integer      primary key default nextval('WORKITEM_SEQ'), -- implicit index
+  JOB_ID                        integer      references JOB not null
+);
+
+create index APN_PURGING_WORK_JOB_ID on
+  APN_PURGING_WORK(JOB_ID);
+
 
 ---------------------------
 -- IMIP Inivitation Work --
@@ -1035,6 +1071,18 @@ create table CLEANUP_ONE_INBOX_WORK (
 create index CLEANUP_ONE_INBOX_WORK_JOB_ID on
   CLEANUP_ONE_INBOX_WORK(JOB_ID);
 
+create table INBOX_REMOVE_WORK (
+  WORK_ID                       integer      primary key default nextval('WORKITEM_SEQ'), -- implicit index
+  JOB_ID                        integer      references JOB not null,
+  HOME_ID                       integer      not null references CALENDAR_HOME on delete cascade,
+  RESOURCE_NAME                 varchar(255) not null,
+
+  unique (HOME_ID, RESOURCE_NAME)    -- implicit index
+);
+
+create index INBOX_REMOVE_WORK_JOB_ID on
+  INBOX_REMOVE_WORK(JOB_ID);
+
 -------------------
 -- Schedule Work --
 -------------------
@@ -1266,7 +1314,7 @@ create table CALENDARSERVER (
   VALUE                         varchar(255)
 );
 
-insert into CALENDARSERVER values ('VERSION', '58');
+insert into CALENDARSERVER values ('VERSION', '65');
 insert into CALENDARSERVER values ('CALENDAR-DATAVERSION', '6');
 insert into CALENDARSERVER values ('ADDRESSBOOK-DATAVERSION', '2');
 insert into CALENDARSERVER values ('NOTIFICATION-DATAVERSION', '1');
