@@ -1,6 +1,6 @@
 # -*- test-case-name: txdav.common.datastore.upgrade.test.test_migrate -*-
 ##
-# Copyright (c) 2011-2015 Apple Inc. All rights reserved.
+# Copyright (c) 2011-2017 Apple Inc. All rights reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -41,7 +41,6 @@ from txdav.base.propertystore.xattr import PropertyStore as XattrPropertyStore
 from txdav.caldav.datastore.util import fixOneCalendarObject
 from txdav.caldav.datastore.util import migrateHome as migrateCalendarHome
 from txdav.carddav.datastore.util import migrateHome as migrateAddressbookHome
-from txdav.common.datastore.file import CommonDataStore as FileStore, TOPPATHS
 from txdav.common.datastore.sql import EADDRESSBOOKTYPE, ECALENDARTYPE
 
 from txdav.common.datastore.upgrade.sql.upgrades.calendar_upgrade_from_1_to_2 import doUpgrade as doCalendarUpgrade_1_to_2
@@ -69,7 +68,6 @@ def _getFixedComponent(cobj):
     returnValue(fixed)
 
 
-
 homeTypeLookup = {
     "calendar": (
         lambda inHome, outHome, getComponent=None, merge=False:
@@ -80,7 +78,6 @@ homeTypeLookup = {
 }
 
 
-
 def swapAMP(oldAMP, newAMP):
     """
     Swap delivery of messages from an old L{AMP} instance to a new one.
@@ -102,7 +99,6 @@ def swapAMP(oldAMP, newAMP):
     return newAMP
 
 
-
 class StoreSpawnerService(SpawnerService):
     """
     Abstract subclass of L{SpawnerService} that describes how to spawn a subclass.
@@ -116,7 +112,6 @@ class StoreSpawnerService(SpawnerService):
         """
         raise NotImplementedError("subclasses must implement the specifics")
 
-
     def spawnWithConfig(self, config, here, there):
         """
         Like L{SpawnerService.spawn}, but instead of instantiating C{there}
@@ -126,7 +121,6 @@ class StoreSpawnerService(SpawnerService):
         raise NotImplementedError("subclasses must implement the specifics")
 
 
-
 class Configure(Command):
     """
     Configure the upgrade helper process.
@@ -137,7 +131,6 @@ class Configure(Command):
                  ("merge", Boolean())]
 
 
-
 class OneUpgrade(Command):
     """
     Upgrade a single calendar home.
@@ -147,7 +140,6 @@ class OneUpgrade(Command):
                  ("homeType", String())]
 
 
-
 class LogIt(Command):
     """
     Log a message.
@@ -155,7 +147,6 @@ class LogIt(Command):
     arguments = [("message", String())]
 
 
-
 class UpgradeDriver(AMP):
     """
     Helper protocol which runs in the master process doing the upgrade.
@@ -165,7 +156,6 @@ class UpgradeDriver(AMP):
         super(UpgradeDriver, self).__init__()
         self.service = upgradeService
 
-
     def configure(self, filename, storeClass):
         """
         Configure the subprocess to examine the file store at the given path
@@ -175,7 +165,6 @@ class UpgradeDriver(AMP):
                                appropriateStoreClass=qual(storeClass),
                                merge=self.service.merge)
 
-
     def oneUpgrade(self, uid, homeType):
         """
         Upgrade one calendar or addressbook home, with the given uid of the
@@ -185,7 +174,6 @@ class UpgradeDriver(AMP):
         return self.callRemote(OneUpgrade, uid=uid, homeType=homeType)
 
 
-
 class UpgradeHelperProcess(AMP):
     """
     Helper protocol which runs in a subprocess to upgrade.
@@ -199,10 +187,10 @@ class UpgradeHelperProcess(AMP):
         self.store = store
         self.store.setMigrating(True)
 
-
     @Configure.responder
     def configure(self, filename, appropriateStoreClass, merge):
         subsvc = None
+        from txdav.common.datastore.file import CommonDataStore as FileStore
         self.upgrader = UpgradeToDatabaseStep(
             FileStore(
                 CachingFilePath(filename), None, None, True, True,
@@ -211,7 +199,6 @@ class UpgradeHelperProcess(AMP):
         )
         return {}
 
-
     @OneUpgrade.responder
     def oneUpgrade(self, uid, homeType):
         """
@@ -233,7 +220,6 @@ class UpgradeHelperProcess(AMP):
         )
 
 
-
 class UpgradeToDatabaseStep(object):
     """
     Upgrade resources from a filesystem store to a database store.
@@ -260,7 +246,6 @@ class UpgradeToDatabaseStep(object):
         self.gid = gid
         self.merge = merge
 
-
     @classmethod
     def fileStoreFromPath(cls, path):
         """
@@ -269,9 +254,8 @@ class UpgradeToDatabaseStep(object):
         @type path: L{CachingFilePath}
         """
 
-        # TODO: TOPPATHS should be computed based on enabled flags in 'store',
-        # not hard coded.
-        for homeType in TOPPATHS:
+        # Legacy: old file store only ever used these two top-level paths
+        for homeType in ("calendars", "addressbooks"):
             if path.child(homeType).exists():
                 if platform.isMacOSX():
                     appropriateStoreClass = XattrPropertyStore
@@ -303,12 +287,12 @@ class UpgradeToDatabaseStep(object):
 
                     appropriateStoreClass = AppleDoubleStore
 
+                from txdav.common.datastore.file import CommonDataStore as FileStore
                 return FileStore(
                     path, None, None, True, True,
                     propertyStoreClass=appropriateStoreClass)
         return None
 
-
     @inlineCallbacks
     def migrateOneHome(self, fileTxn, homeType, fileHome):
         """
@@ -316,15 +300,12 @@ class UpgradeToDatabaseStep(object):
         """
         migrateFunc, destFunc = homeTypeLookup.get(homeType)
         uid = normalizeUUIDOrNot(fileHome.uid())
-        self.log.warn("Starting migration transaction %s UID %r" %
-                      (homeType, uid))
+        self.log.warn("Starting migration transaction {type} UID {uid}", type=homeType, uid=uid)
         sqlTxn = self.sqlStore.newTransaction(label="UpgradeToDatabaseStep.migrateOneHome")
         homeGetter = destFunc(sqlTxn)
         sqlHome = yield homeGetter(uid, create=False)
         if sqlHome is not None and not self.merge:
-            self.log.warn(
-                "%s home %r already existed not migrating" % (
-                    homeType, uid))
+            self.log.warn("{ty[e} home {uid} already existed not migrating", type=homeType, uid=uid)
             yield sqlTxn.abort()
             returnValue(None)
         try:
@@ -348,7 +329,6 @@ class UpgradeToDatabaseStep(object):
             # filesystem-to-database upgrade.)
             fileHome._path.remove()
 
-
     @inlineCallbacks
     def doMigration(self):
         """
@@ -391,20 +371,17 @@ class UpgradeToDatabaseStep(object):
             "Filesystem upgrade complete, launching database service."
         )
 
-
     @inlineCallbacks
     def _upgradeAction(self, fileTxn, fileHome, homeType):
         uid = fileHome.uid()
-        self.log.warn("Migrating %s UID %r" % (homeType, uid))
+        self.log.warn("Migrating {type} UID {uid}", type=homeType, uid=uid)
         yield self.migrateOneHome(fileTxn, homeType, fileHome)
 
-
     def stepWithResult(self, result):
         if self.fileStore is None:
             return succeed(None)
         return self.doMigration()
 
-
     @inlineCallbacks
     def doDataUpgradeSteps(self):
         """
@@ -432,6 +409,6 @@ class UpgradeToDatabaseStep(object):
             (doCalendarUpgrade_4_to_5, "Calendar data upgrade from v4 to v5"),
             (doAddressbookUpgrade_1_to_2, "Addressbook data upgrade from v1 to v2"),
         ):
-            self.log.warn("Migration extra step: {}".format(description))
+            self.log.warn("Migration extra step: {desc}", desc=description)
             yield upgrade(self.sqlStore)
         self.sqlStore.setUpgrading(False)
