@@ -1,5 +1,5 @@
 ##
-# Copyright (c) 2005-2015 Apple Inc. All rights reserved.
+# Copyright (c) 2005-2017 Apple Inc. All rights reserved.
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -64,7 +64,6 @@ class ActiveLock (WebDAVElement):
     }
 
 
-
 @registerElement
 @registerElementClass
 class Depth (WebDAVTextElement):
@@ -81,7 +80,6 @@ class Depth (WebDAVTextElement):
             raise ValueError("Invalid depth: {0}".format(depth,))
 
 
-
 @registerElement
 @registerElementClass
 class LockToken (WebDAVElement):
@@ -93,7 +91,6 @@ class LockToken (WebDAVElement):
     allowed_children = {(dav_namespace, "href"): (1, None)}
 
 
-
 @registerElement
 @registerElementClass
 class Timeout (WebDAVTextElement):
@@ -103,7 +100,6 @@ class Timeout (WebDAVTextElement):
     name = "timeout"
 
 
-
 @registerElement
 @registerElementClass
 class Collection (WebDAVEmptyElement):
@@ -113,7 +109,6 @@ class Collection (WebDAVEmptyElement):
     name = "collection"
 
 
-
 @registerElement
 @registerElementClass
 class HRef (WebDAVTextElement):
@@ -123,7 +118,6 @@ class HRef (WebDAVTextElement):
     name = "href"
 
 
-
 @registerElement
 @registerElementClass
 class Link (WebDAVElement):
@@ -139,7 +133,6 @@ class Link (WebDAVElement):
     }
 
 
-
 @registerElement
 @registerElementClass
 class LinkDestination (WebDAVTextElement):
@@ -149,7 +142,6 @@ class LinkDestination (WebDAVTextElement):
     name = "dst"
 
 
-
 @registerElement
 @registerElementClass
 class LinkSource (WebDAVTextElement):
@@ -159,7 +151,6 @@ class LinkSource (WebDAVTextElement):
     name = "src"
 
 
-
 @registerElement
 @registerElementClass
 class LockEntry (WebDAVElement):
@@ -175,7 +166,6 @@ class LockEntry (WebDAVElement):
     }
 
 
-
 @registerElement
 @registerElementClass
 class LockInfo (WebDAVElement):
@@ -192,7 +182,6 @@ class LockInfo (WebDAVElement):
     }
 
 
-
 @registerElement
 @registerElementClass
 class LockScope (WebDAVOneShotElement):
@@ -208,7 +197,6 @@ class LockScope (WebDAVOneShotElement):
     }
 
 
-
 @registerElement
 @registerElementClass
 class Exclusive (WebDAVEmptyElement):
@@ -242,7 +230,6 @@ class LockType (WebDAVOneShotElement):
     allowed_children = {(dav_namespace, "write"): (0, 1)}
 
 
-
 @registerElement
 @registerElementClass
 class Write (WebDAVEmptyElement):
@@ -257,7 +244,6 @@ class Write (WebDAVEmptyElement):
 LockType.write = LockType(Write())
 
 
-
 @registerElement
 @registerElementClass
 class MultiStatus (WebDAVElement):
@@ -272,7 +258,6 @@ class MultiStatus (WebDAVElement):
     }
 
 
-
 @registerElement
 @registerElementClass
 class Response (WebDAVElement):
@@ -313,8 +298,8 @@ class Response (WebDAVElement):
                 )
             )
 
-        if status_count is 0:
-            if propstat_count is 0:
+        if status_count == 0:
+            if propstat_count == 0:
                 raise ValueError(
                     "{0} element must have one of {1} or {2}".format(
                         cls.sname(), Status.sname(), PropertyStatus.sname()
@@ -340,7 +325,6 @@ class Response (WebDAVElement):
         return StatusResponse.__new__(StatusResponse, *children)
 
 
-
 @registerElementClass
 class StatusResponse (Response):
     """
@@ -356,7 +340,6 @@ class StatusResponse (Response):
     }
 
 
-
 @registerElementClass
 class PropertyStatusResponse (Response):
     """
@@ -372,7 +355,6 @@ class PropertyStatusResponse (Response):
     }
 
 
-
 @registerElement
 @registerElementClass
 class PropertyStatus (WebDAVElement):
@@ -390,7 +372,6 @@ class PropertyStatus (WebDAVElement):
     }
 
 
-
 @registerElement
 @registerElementClass
 class Status (WebDAVTextElement):
@@ -410,7 +391,6 @@ class Status (WebDAVTextElement):
 
         return cls(PCDATAElement("HTTP/1.1 {0} {1}".format(code, responsecode.RESPONSES[code])))
 
-
     def __init__(self, *children, **attributes):
         super(Status, self).__init__(*children, **attributes)
 
@@ -425,7 +405,6 @@ class Status (WebDAVTextElement):
         self.code = code
 
 
-
 @registerElement
 @registerElementClass
 class ResponseDescription (WebDAVTextElement):
@@ -436,7 +415,6 @@ class ResponseDescription (WebDAVTextElement):
     name = "responsedescription"
 
 
-
 @registerElement
 @registerElementClass
 class Owner (WebDAVElement):
@@ -450,12 +428,11 @@ class Owner (WebDAVElement):
     """
     name = "owner"
     hidden = True
-    protected = True # may be protected, per RFC 3744, section 5.1
+    protected = True  # may be protected, per RFC 3744, section 5.1
 
     allowed_children = {WebDAVElement: (0, None)}
 
 
-
 @registerElement
 @registerElementClass
 class PropertyContainer (WebDAVElement):
@@ -467,7 +444,6 @@ class PropertyContainer (WebDAVElement):
     allowed_children = {WebDAVElement: (0, None)}
 
 
-
 @registerElement
 @registerElementClass
 class PropertyBehavior (WebDAVElement):
@@ -482,7 +458,6 @@ class PropertyBehavior (WebDAVElement):
         (dav_namespace, "keepalive"): (0, 1),
     }
 
-
     def __init__(self, *children, **attributes):
         super(PropertyBehavior, self).__init__(*children, **attributes)
 
@@ -496,7 +471,6 @@ class PropertyBehavior (WebDAVElement):
         self.behavior = children[0]
 
 
-
 @registerElement
 @registerElementClass
 class KeepAlive (WebDAVElement):
@@ -511,7 +485,6 @@ class KeepAlive (WebDAVElement):
         PCDATAElement: (0, 1),
     }
 
-
     def validate(self):
         super(KeepAlive, self).validate()
 
@@ -532,7 +505,6 @@ class KeepAlive (WebDAVElement):
                 raise ValueError("Invalid keepalive value: {0!r}".format(str(self),))
 
 
-
 @registerElement
 @registerElementClass
 class Omit (WebDAVEmptyElement):
@@ -543,7 +515,6 @@ class Omit (WebDAVEmptyElement):
     name = "omit"
 
 
-
 @registerElement
 @registerElementClass
 class PropertyUpdate (WebDAVElement):
@@ -559,7 +530,6 @@ class PropertyUpdate (WebDAVElement):
     }
 
 
-
 @registerElement
 @registerElementClass
 class Remove (WebDAVElement):
@@ -572,7 +542,6 @@ class Remove (WebDAVElement):
     allowed_children = {(dav_namespace, "prop"): (1, 1)}
 
 
-
 @registerElement
 @registerElementClass
 class Set (WebDAVElement):
@@ -585,7 +554,6 @@ class Set (WebDAVElement):
     allowed_children = {(dav_namespace, "prop"): (1, 1)}
 
 
-
 @registerElement
 @registerElementClass
 class PropertyFind (WebDAVElement):
@@ -601,7 +569,6 @@ class PropertyFind (WebDAVElement):
         (dav_namespace, "prop"): (0, 1),
     }
 
-
     def validate(self):
         super(PropertyFind, self).validate()
 
@@ -613,7 +580,6 @@ class PropertyFind (WebDAVElement):
             )
 
 
-
 @registerElement
 @registerElementClass
 class AllProperties (WebDAVEmptyElement):
@@ -624,7 +590,6 @@ class AllProperties (WebDAVEmptyElement):
     name = "allprop"
 
 
-
 @registerElement
 @registerElementClass
 class PropertyName (WebDAVEmptyElement):
@@ -635,7 +600,6 @@ class PropertyName (WebDAVEmptyElement):
     name = "propname"
 
 
-
 ##
 # Section 13
 ##
@@ -652,7 +616,6 @@ class CreationDate (WebDAVDateTimeElement):
     protected = True
 
 
-
 @registerElement
 @registerElementClass
 class DisplayName (WebDAVTextElement):
@@ -663,7 +626,6 @@ class DisplayName (WebDAVTextElement):
     name = "displayname"
 
 
-
 @registerElement
 @registerElementClass
 class GETContentLanguage (WebDAVTextElement):
@@ -674,7 +636,6 @@ class GETContentLanguage (WebDAVTextElement):
     name = "getcontentlanguage"
 
 
-
 @registerElement
 @registerElementClass
 class GETContentLength (WebDAVTextElement):
@@ -686,7 +647,6 @@ class GETContentLength (WebDAVTextElement):
     protected = True
 
 
-
 @registerElement
 @registerElementClass
 class GETContentType (WebDAVTextElement):
@@ -700,7 +660,6 @@ class GETContentType (WebDAVTextElement):
         return MimeType.fromString(str(self))
 
 
-
 @registerElement
 @registerElementClass
 class GETETag (WebDAVTextElement):
@@ -712,7 +671,6 @@ class GETETag (WebDAVTextElement):
     protected = True
 
 
-
 @registerElement
 @registerElementClass
 class GETLastModified (DateTimeHeaderElement):
@@ -724,7 +682,6 @@ class GETLastModified (DateTimeHeaderElement):
     protected = True
 
 
-
 @registerElement
 @registerElementClass
 class LockDiscovery (WebDAVElement):
@@ -737,7 +694,6 @@ class LockDiscovery (WebDAVElement):
     allowed_children = {(dav_namespace, "activelock"): (0, None)}
 
 
-
 @registerElement
 @registerElementClass
 class ResourceType (WebDAVElement):
@@ -766,7 +722,6 @@ class Source (WebDAVElement):
     allowed_children = {(dav_namespace, "link"): (0, None)}
 
 
-
 @registerElement
 @registerElementClass
 class SupportedLock (WebDAVElement):
@@ -780,7 +735,6 @@ class SupportedLock (WebDAVElement):
     allowed_children = {(dav_namespace, "lockentry"): (0, None)}
 
 
-
 # FIXME: Add preconditions codes defined in RFC4918
 
 @registerElement
